@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -49,12 +49,13 @@ require_once ('../include/form.php');
 extract (sane_import ('request', ['hash' => 'confirm_hash']));
 extract (sane_import ('post',
   [
-    'hash' => 'form_id',
     'true' => 'update',
     'pass' => ['form_pw', 'form_pw2']
   ]
 ));
 
+form_check ('update');
+
 $res_lostuser = db_execute (
   "SELECT * FROM user WHERE confirm_hash = ?", [$confirm_hash]
 );
@@ -70,14 +71,13 @@ $row_lostuser = db_fetch_array($res_lostuser);
 if ($update && $form_pw)
   {
     if (strcmp ($form_pw, $form_pw2))
-      fb(_("Passphrases do not match."), 1);
-    elseif (account_pwvalid ($form_pw) && form_check ($form_id))
+      fb (_("Passphrases do not match."), 1);
+    elseif (account_pwvalid ($form_pw))
       {
         db_autoexecute ('user',
           ['user_pw' => account_encryptpw ($form_pw), 'confirm_hash' => ''],
           DB_AUTOQUERY_UPDATE, "confirm_hash = ?", [$confirm_hash]
         );
-        form_clean ($form_id);
         session_redirect ($sys_home);
       }
   }
@@ -88,9 +88,7 @@ print '<h2>' . _("Lost Passphrase Login") . "</h2>\n";
 print '<p>';
 printf (_("Welcome, %s."), $row_lostuser['user_name']);
 print ' ' . _("You may now change your passphrase.") . "</p>\n";
-
-print form_header ($_SERVER['PHP_SELF']);
-
+print form_header ();
 print '<div>' . account_password_help () . "</div>\n";
 print '<div class="inputfield"><strong><label for="form_pw">'
   . _("New passphrase:")
@@ -101,7 +99,7 @@ print '<div class="inputfield"><strong><label for="form_pw2">'
   . _("New passphrase (repeat):") . '</label></strong>';
 print form_input ("password", "form_pw2") . "</div>\n";
 
-print form_input ("hidden", "confirm_hash", $confirm_hash);
+print form_hidden (["confirm_hash" => $confirm_hash]);
 print form_footer ();
 
 $HTML->footer ([]);
