@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -67,7 +67,7 @@ $message =
 # TRANSLATORS: the argument is the name of the system (like "Savannah").
 $message .= sprintf (_("-- the %s team."), $sys_name) . "\n";
 sendmail_mail (
-  ['from' => "$sys_mail_replyto@$sys_mail_domain", 'to' => $row_user['email']],
+  ['to' => $row_user['email']],
   ['subject' => "$sys_name " . _("Account Registration"), 'body' => $message]
 );
 
