@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -48,13 +48,12 @@ require_once ('../include/form.php');
 require_once ('../include/exit.php');
 
 extract (sane_import ('post',
-  [
-    'true' => 'update',
-    'hash' => ['form_id', 'confirm_hash'],
-    'name' => 'form_loginname',
-    'pass' => 'form_pw'
-  ]
+  ['true' => 'update', 'name' => 'form_loginname', 'pass' => 'form_pw']
 ));
+# Must accept all ways of providing confirm_hash because in the mail it is a GET
+# but if the form fails (wrong password, etc), it will be a POST.
+extract (sane_import ('request', ['hash' => 'confirm_hash']));
+form_check ('update');
 
 # Logged users have no business here.
 if (user_isloggedin ())
@@ -77,11 +76,7 @@ if (!empty ($update))
       exit_error (_("Invalid confirmation hash"));
 
     # Then check valid login.
-    if (
-      session_login_valid (
-        $form_loginname, $form_pw, 1, 0, 0, session_issecure ()
-      )
-    )
+    if (session_login_valid ($form_loginname, $form_pw, 0, 1))
       {
         $res = db_execute (
           "UPDATE user SET status = 'A' WHERE user_name = ?",
@@ -91,8 +86,8 @@ if (!empty ($update))
       }
   }
 site_header (['title' => _("Login")]);
-# TRANSLATORS: the argument is the name of the system (like "Savannah").
 print '<h2> ';
+# TRANSLATORS: the argument is the name of the system (like "Savannah").
 printf (_("%s Account Verification"), $sys_name);
 print "</h2>\n";
 print '<p>'
@@ -100,7 +95,7 @@ print '<p>'
      . "will then be activated for normal logins.")
  . "</p>\n";
 
-print form_header ($_SERVER["PHP_SELF"], $form_id);
+print form_header ();
 print '<p><span class="preinput">'
   . _("Login Name") . ":</span><br />\n&nbsp;&nbsp;";
 print form_input ("text", "form_loginname");
@@ -111,10 +106,6 @@ print '<p><span class="preinput">'
 print form_input ("password", "form_pw");
 print "</p>\n";
 
-# Must accept all ways of providing confirm_hash (POST & GET), because
-# in the mail it is a POST but if the form fail (wrong password, etc), it will
-# be a GET.
-extract (sane_import ('request', ['hash' => 'confirm_hash']));
 print form_hidden (["confirm_hash" => $confirm_hash]);
 print form_footer (_("Login"));
 
