@@ -6,7 +6,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -49,12 +49,10 @@ $is_admin_page = 'y';
 extract (sane_import ('request',
   ['name' => 'field', 'true' => 'update_field']
 ));
+$submits = ['post_changes', 'submit', 'reset'];
 extract (sane_import ('post',
   [
-    'true' =>
-      [
-        'post_changes', 'submit', 'reset'
-      ],
+    'true' => $submits,
     'specialchars' => ['label', 'description'],
     'digits' =>
       [
@@ -65,11 +63,12 @@ extract (sane_import ('post',
      'strings' =>
        [
          ['form_transition_default_auth', ['A', 'F']],
-         ['show_on_add','show_on_add_members',  ['1']],
-         ['show_on_add_logged', ['2']]
+         ['show_on_add_logged','show_on_add_mem',  ['1']],
+         ['show_on_add_anon', ['2']]
        ]
   ]
 ));
+form_check ($submits);
 
 if (!$group_id)
   exit_no_group ();
@@ -91,34 +90,31 @@ if ($post_changes)
           {
             # Do not let the user change these field settings
             # if the field is required.
-            $show_on_add_members =
+            $show_on_add_mem =
               trackers_data_is_showed_on_add_members ($field);
-            $show_on_add = trackers_data_is_showed_on_add ($field);
-            $show_on_add_logged =
+            $show_on_add_logged = trackers_data_is_showed_on_add ($field);
+            $show_on_add_anon =
               trackers_data_is_showed_on_add_nologin ($field);
           }
-        else
+        elseif ($field == "vote")
           {
-             # Vote must be possible for members.
-             # Vote cannot be possible for non-logged in.
-            if ($field == "vote")
-              {
-                $show_on_add_logged = 0;
-                $show_on_add_members = 1;
-              }
+            # Members always may vote.
+            $show_on_add_mem = 1;
+            # Anonymous visitors can't vote.
+            $show_on_add_anon = 0;
           }
 
-        # The additional possibility of differently treating non-project
+        # The additional possibility of differently treating non-group
         # members who have accounts and anonymous visitors demanded
-        # a new handling of the values of the show_on_add field:
-        # bit 1 set: show for logged in non project members
-        # bit 2 set: show for non logged in users.
-        $show_on_add = $show_on_add | $show_on_add_logged;
+        # a new handling of the values of the show_on_add_logged field:
+        # bit (1 << 0) set: show for logged-in non-group members
+        # bit (1 << 1) set: show for anonymous users.
+        $show_on_add_logged = $show_on_add_logged | $show_on_add_anon;
 
         trackers_data_update_usage (
           $field, $group_id, $label, $description, $status, $place,
-          $display_size, $mandatory_flag, $keep_history, $show_on_add_members,
-          $show_on_add, $form_transition_default_auth
+          $display_size, $mandatory_flag, $keep_history, $show_on_add_mem,
+          $show_on_add_logged, $form_transition_default_auth
         );
       }
     elseif ($reset)
@@ -158,11 +154,11 @@ if ($update_field)
       {
         print '<input type="text" title="' . _("Field Label")
           . '" name="label" value="'
-          . trackers_data_get_label( $field) . '" size="20" maxlength="85">'
+          . trackers_data_get_label ($field) . '" size="20" maxlength="85">'
           . $closetag;
-        print '<span class="preinput"><label for="description">'
-          . _("Description:") . '</label> </span>';
-        print "<br />\n&nbsp;&nbsp;&nbsp;<input type='text' id='description'> "
+        print '<span class="preinput">'
+          . html_label ("description", _("Description:")) . ' </span>';
+        print "<br />\n&nbsp;&nbsp;&nbsp;<input type='text' id='description' "
           . "name='description' value=\""
           . trackers_data_get_description ($field)
           . "\" size='70' maxlength='255' /><br />\n";
@@ -170,45 +166,39 @@ if ($update_field)
     else
       print trackers_data_get_label ($field) . $closetag;
 
-    print '<span class="preinput">' . _("Status:") . ' </span>&nbsp;&nbsp;';
+    print "<dl>";
+    print '<dt><span class="preinput">' . html_label ('status', _("Status:"))
+      . "</span></dt>\n<dd>";
 
     # Display the Usage box (Used, Unused select box  or hardcoded
     # "required").
-    $sel = ' selected="selected"';
     if (trackers_data_is_required ($field))
-      {
-        print "<br />\n&nbsp;&nbsp;&nbsp;" . _("Required");
-        print form_hidden (["status" => "1"]);
-      }
+      print _("Required") . form_hidden (["status" => "1"]);
     else
-      {
-        $ck = trackers_data_is_used ($field)? $sel: '';
-        print "<br />&nbsp;&nbsp;&nbsp;\n"
-          . ' <select title="' . _("Usage status") . "\" name='status'>\n"
-          . "<option value='1'$ck>" . _("Used") . "</option>\n";
-        $ck = trackers_data_is_used ($field)? '': $sel;
-        print "<option value='0'$ck>" . _("Unused")
-          . "</option>\n<select>\n";
-      }
+      print form_checkbox (
+        'status', trackers_data_is_used ($field), ['label'=> _("Used")]
+      );
+    print "</dd>\n";
 
     # Ask they want to save the history of the item.
     if (!trackers_data_is_special ($field))
       {
-        print "<br />\n<span class='preinput'>" . _("Item History:")
-          . "</span>\n<br />&nbsp;&nbsp;&nbsp;\n"
+        print "<dt>\n<span class='preinput'>" . _("Item History:")
+          . "</span>\n<dt>\n<dd>"
           . "<select title=\"" . _("whether to keep in history")
           . "\" name='keep_history'>\n";
-        $ck = trackers_data_do_keep_history ($field)? $sel: '';
-        print "<option value='1'$ck>"
-          . _("Keep field value changes in history") . "</option>\n";
-        $ck = trackers_data_do_keep_history ($field)? '': $sel;
-        print "<option value='0'$ck>"
-          . _("Ignore field value changes in history")
-          . "</option>\n</select>\n";
-        }
+        $cur = trackers_data_do_keep_history ($field);
+        print form_option ('1', $cur, _("Keep field value changes in history"));
+        print form_option (
+         '0', $cur, _("Ignore field value changes in history")
+        );
+        print "</select>\n";
+      }
+    print "</dd>\n</dl>\n";
 
-    print "\n\n<p>&nbsp;</p><h2>" . _("Access:") . "</h2>\n";
+    print "\n\n<h2>" . _("Access:") . "</h2>\n";
 
+    print "<dl>\n";
     # Set mandatory bit: if the field is special, meaning it is entered
     # by the system, or if it is "priority", assume the
     # admin is not entitled to modify this behavior.
@@ -217,37 +207,45 @@ if ($update_field)
         # "Mandatory" is not really 100% mandatory, only if it is possible
         # for a user to fill the entry.
         # It is "Mandatory whenever possible".
-        $mandatory_flag = trackers_data_mandatory_flag ($field);
-        print '<span class="preinput">' . _("This field is:")
-          . "</span>\n<br />&nbsp;&nbsp;&nbsp;\n"
+        $cur = trackers_data_mandatory_flag ($field);
+        print '<dt><span class="preinput">' . _("This field is:")
+          . "</span></dt>\n<dd>\n"
           . "<select title=\"" . _("whether the field is mandatory")
           . "\" name='mandatory_flag'>\n";
-        $ck =($mandatory_flag == 1)? $sel: '';
-        print "<option value='1'$sel>"
-          . _("Optional (empty values are accepted)") . "</option>\n";
-        $ck =($mandatory_flag == 3)? $sel: '';
-        print "<option value='3'$sel>" . _("Mandatory") . "</option>\n";
-        $ck =($mandatory_flag == 0)? $sel: '';
-        print "<option value='0'$sel>"
-          . _("Mandatory only if it was presented to the original submitter")
-          . "</option>\n</select><br />\n";
+        print form_option ('1', $cur,
+          _("Optional (empty values are accepted)")
+        );
+        print form_option ('3', $cur, _("Mandatory"));
+        print form_option ('0', $cur,
+          _("Mandatory only if it was presented to the original submitter")
+        );
+        print "</select>\n";
      }
 
-    print '<span class="preinput">'
-      . _("On new item submission, present this field to:") . '</span> ';
-    $checkbox_members = $checkbox_loggedin = $checkbox_anonymous = '';
+    print "</dd>\n<dt>";
+    print '<span class="preinput">' . _("On new item submission:") . '</span>';
+    print "</dt>\n";
     $sh_add_mem = trackers_data_is_showed_on_add_members ($field);
     $sh_add = trackers_data_is_showed_on_add ($field);
     $sh_anon = trackers_data_is_showed_on_add_nologin ($field);
+    $anon_label = _("Show field to anonymous users");
+    $logged_label = _("Show field to logged-in users");
+    $member_label = _("Show field to members");
+    $checkboxes = [];
     if (trackers_data_is_required ($field))
       {
-        # Do not let the user change these field settings.
-        if ($sh_add_mem)
-          $checkbox_members = '+';
-        if ($sh_add)
-          $checkbox_loggedin = '+';
-        if ($sh_anon)
-          $checkbox_anonymous = '+';
+        # Do not let the user change field settings.
+        $checkboxes[] = form_checkbox ('show_on_add_mem', $sh_add_mem,
+          ['label' => $member_label, 'disabled' => 'disabled']
+        );
+        $checkboxes[] = form_checkbox ('show_on_add_logged', $sh_add,
+          ['label' => $logged_label, 'disabled' => 'disabled']
+        );
+        $checkboxes[] = form_checkbox ('show_on_add_anon', $sh_anon,
+          ['value' => 2, 'label' => $anon_label, 'disabled' => 'disabled']
+        );
+        foreach (array_keys ($checkboxes) as $k)
+          $checkboxes[$k] = "<del class='preinput'>{$checkboxes[$k]}</del>";
       }
     else
       {
@@ -256,61 +254,52 @@ if ($update_field)
           {
             # Vote is always available for members.
             # Vote is impossible unless logged in.
-            $checkbox_members = '+';
-            $checkbox_anonymous = 0;
-            $checkbox_loggedin = form_checkbox ("show_on_add", $sh_add);
+            $checkboxes[] =
+              '<del class="preinput">'
+              . form_checkbox ('show_on_add_mem',
+                  1, ['label' => $member_label, 'disabled' => 'disabled']
+                )
+              . '</del>';
+            $checkboxes[] = form_checkbox ("show_on_add_logged",
+              $sh_add, ['label' => $logged_label]
+            );
           }
         elseif ($field == "originator_email")
           {
             # Originator email is, by the code, available only to anonymous.
-            $checkbox_members = 0;
-            $checkbox_loggedin = 0;
-            $checkbox_anonymous =
-              form_checkbox ("show_on_add_logged", $sh_anon, ['value' => "2"]);
+            $checkboxes[] =
+              form_checkbox ("show_on_add_anon", $sh_anon,
+                ['value' => "2", 'label' => $anon_label]
+              );
           }
         else
           {
-            $checkbox_members =
-              form_checkbox (
-                "show_on_add_members", $sh_add_mem,
-                ['title' => _("Show field to members")]
-              );
-            $checkbox_anonymous =
-              form_checkbox (
-                "show_on_add_logged", $sh_anon,
-                ['title' => _("Show field to logged-in users"), 'value' => "2"]
-              );
-            $checkbox_loggedin =
-              form_checkbox (
-                "show_on_add_members", $sh_add,
-                ['title' => _("Show field to anonymous users")]
-              );
+            $checkboxes[] = form_checkbox (
+              "show_on_add_mem", $sh_add_mem, ['label' => $member_label]
+            );
+            $checkboxes[] = form_checkbox (
+              "show_on_add_logged", $sh_add, ['label' => $logged_label]
+            );
+            $checkboxes[] = form_checkbox ("show_on_add_anon", $sh_anon,
+              ['label' => $anon_label, 'value' => "2"]
+            );
           }
       } # !trackers_data_is_required ($field)
 
-    if ($checkbox_members)
-      print "<br />\n&nbsp;&nbsp;&nbsp;$checkbox_members "
-        . _("<!-- present this field to --> Group Members");
-    if ($checkbox_loggedin)
-      print "<br />\n&nbsp;&nbsp;&nbsp;$checkbox_loggedin "
-        . _("<!-- present this field to --> Logged-in Users");
-    if ($checkbox_anonymous)
-      print "<br />\n&nbsp;&nbsp;&nbsp;$checkbox_anonymous "
-         . _("<!-- present this field to --> Anonymous Users");
+    print "<dd>" . join ("<br />", $checkboxes) . "</dd>\n</dl>\n";
 
     if (trackers_data_is_special ($field))
-      print '<input type="hidden" name="place" value="'
-        . trackers_data_get_place ($field) . '" />';
+      print form_hidden (['place' => trackers_data_get_place ($field)]);
     else
       {
-        print "\n\n<p>&nbsp;</p>\n<h2>" . _("Display:") . "</h2>\n";
+        print "\n\n<h2>" . _("Display:") . "</h2>\n";
 
-        print '<span class="preinput"><label for="place">'
-          . _("Rank on page:")
-          . "</label></span><br />\n&nbsp;&nbsp;&nbsp;";
+        print "<dl>\n<dt><span class='preinput'>"
+          . html_label ("place", _("Rank on page:"))
+          . "</span></dt>\n<dd>";
         print '<input type="text" id="place" name="place" value="'
           . trackers_data_get_place ($field)
-          . "\" size='6' maxlength='6' /><br />\n";
+          . "\" size='6' maxlength='6' /></dd>\n</dl>\n";
       }
 
     # Customize field size only for text fields and text areas.
@@ -318,31 +307,31 @@ if ($update_field)
       {
         list ($size, $maxlength) = trackers_data_get_display_size ($field);
 
-        print '<span class="preinput"><label for="n1">'
-          . _("Visible size of the field:")
-          . "</label> </span><br />&nbsp;&nbsp;&nbsp;\n";
+        print "<dl>\n<dt><span class='preinput'>"
+          . html_label ("n1", _("Visible size of the field:"))
+          . "</span></dt>\n<dd>";
         print '<input type="text" id="n1" name="n1" value="' . $size
-          . "\" size='3' maxlength='3' /><br />\n";
-        print '<span class="preinput"><label for="n2">'
-          . _("Maximum size of field text (up to 255):")
-          . "</label></span>\n<br />&nbsp;&nbsp;&nbsp;\n";
+          . "\" size='3' maxlength='3' /></dd>\n";
+        print "<dt><span class='preinput'>"
+          . html_label ("n2", _("Maximum size of field text (up to 255):"))
+          . "</span></dt>\n<dd>";
         print '<input type="text" id="n2" name="n2" value="' . $maxlength
-          . "\" size='3' maxlength='3' /><br />\n";
+          . "\" size='3' maxlength='3' /></dd>\n</dl>\n";
       }
-    else if (trackers_data_is_text_area($field))
+    elseif (trackers_data_is_text_area ($field))
       {
         list ($rows, $cols) = trackers_data_get_display_size ($field);
 
-        print '<span class="preinput"><label for="n1">'
-          ._ ("Number of columns of the field:")
-          . "</label></span>\n<br />&nbsp;&nbsp;&nbsp;\n";
+        print "<dl>\n<dt><span class='preinput'>"
+          . html_label ("n1", _("Number of columns of the field:"))
+          . "</span></dt>\n><dd>";
         print '<input type="text" id="n1" name="n1" value="' . $rows
-          . "\" size='3' maxlength='3' /><br />\n";
-        print '<span class="preinput"><label for="n2">'
-          . _("Number of rows  of the field:")
-          . "</label></span>\n<br />&nbsp;&nbsp;&nbsp;\n";
+          . "\" size='3' maxlength='3' /></dd>\n";
+        print "<dt><span class='preinput'>"
+          . html_label ("n2", _("Number of rows  of the field:"))
+          . "</span></dt>\n<dd>";
         print '<input type="text" id="n2" name="n2" value="' . $cols
-          . "\" size='3' maxlength='3' /><br />\n";
+          . "\" size='3' maxlength='3' /></dd>\n</dl>\n";
       }
 
     # Transitions.
@@ -360,29 +349,27 @@ if ($update_field)
         if (db_numrows ($result) > 0)
           $transition_default_auth =
             db_result ($result, 0, 'transition_default_auth');
-        $ck_str = ' checked="checked"';
         $ck = $transition_default_auth !='F';
-        $ck1 = $ck? $ck_str: '';
-        $ck2 = $ck? '': $ck_str;
         print "\n\n<p>&nbsp;</p>\n<h2>"
           . _("By default, transitions (from one value to another) are:")
           . "</h2>\n";
-        print '&nbsp;&nbsp;&nbsp;<input type="radio" '
-          . "name='form_transition_default_auth'\n"
-          . "id='form_transition_default_auth_allowed' value='A'$ck1"
-          . ' /><label for="form_transition_default_auth_allowed">'
-          . _("Allowed") . "</label><br />\n&nbsp;&nbsp;&nbsp;<input "
-          . "type='radio' id='form_transition_default_auth_forbidden'\n"
-          . "name='form_transition_default_auth' value='F'$ck2"
-          . ' /><label for="form_transition_default_auth_forbidden">'
-          . _("Forbidden") . "</label>\n";
+        print
+          form_radio ('form_transition_default_auth', 'A',
+            [ 'checked' => $ck, 'label' => _("Allowed"),
+              'id' => 'form_transition_default_auth_allowed']
+          )
+          . "<br />\n"
+          . form_radio ('form_transition_default_auth', 'F',
+              [ 'checked' => !$ck, 'label' => _("Forbidden"),
+                'id' => 'form_transition_default_auth_forbidden']
+            )
+          . "\n";
       }
     print "\n<p align='center'>"
-      . "<input type='submit' name='submit' value=\""
-      . _("Update") . "\" />\n&nbsp;&nbsp;\n<input type='submit' "
-      . "name='reset' value=\"" . _("Reset to defaults")
-      . "\" /></p>\n</form>\n";
-    trackers_footer ([]);
+      . form_submit (_("Update"), 'submit') . "\n&nbsp;&nbsp;\n"
+      . form_submit (_("Reset to defaults"), 'reset')
+      . "</p>\n</form>\n";
+    trackers_footer ();
     exit (0);
   } # if ($update_field)
 
@@ -427,8 +414,7 @@ while ($field_name = trackers_list_all_fields ())
       $is_required? _("Required"): ($is_used? _("Used"): _("Unused"));
 
     $scope_label  =
-      trackers_data_get_scope ($field_name) == 'S'?
-      _("System"): _("Project");
+      trackers_data_get_scope ($field_name) == 'S'? _("System"): _("Group");
     $place_label = $is_used? trackers_data_get_place ($field_name): '-';
 
     $html = "<td><a href=\"$php_self?group_id=$group_id"
@@ -436,41 +422,22 @@ while ($field_name = trackers_list_all_fields ())
       . trackers_data_get_label ($field_name) . "</a></td>\n"
       . "\n<td>" . trackers_data_get_display_type_in_clear ($field_name)
       . "</td>\n<td>" . trackers_data_get_description ($field_name)
-      . (($is_custom && $is_used)?
-         ' - <strong>[' . _("Custom Field") . ']</strong>':
-         '')
+      . (($is_custom && $is_used)? ' - <b>[' . _("Custom Field") . ']</b>': '')
       . "</td>\n"
       . "\n<td align =\"center\">$place_label</td>\n"
       . "\n<td align =\"center\">$scope_label</td>\n"
       . "\n<td align =\"center\">$status_label</td>\n";
 
     if ($is_used)
-      {
-        $html = '<tr class="' . utils_altrow ($iu) . "\">$html</tr>\n";
-        $iu++;
-        $hu .= $html;
-      }
+      $hu .= '<tr class="' . utils_altrow ($iu++) . "\">$html</tr>\n";
+    elseif ($is_custom)
+      $hnc .= '<tr class="' . utils_altrow ($inc++) . "\">$html</tr>\n";
     else
-      {
-        if ($is_custom)
-          {
-            $html = '<tr class="' . utils_altrow ($inc)
-              . "\">$html</tr>\n";
-            $inc++;
-            $hnc .= $html;
-          }
-        else
-          {
-            $html = '<tr class="'
-              . utils_altrow ($in) . "\">$html</tr>\n";
-            $in++;
-            $hn .= $html;
-          }
-      }
+      $hn .= '<tr class="' . utils_altrow ($in++) . "\">$html</tr>\n";
   } #  while ($field_name = trackers_list_all_fields())
 
-$rule0 = '<tr><td colspan="5"><center><strong>---- ';
-$rule1 = " ----</strong></center></tr>\n";
+$rule0 = '<tr><td colspan="5"><center><b>---- ';
+$rule1 = " ----</b></center></tr>\n";
 $tr = "<tr><td colspan='5'> &nbsp;</td></tr>\n$rule0";
 $hu =  $rule0 . _("USED FIELDS") . "$rule1$hu";
 if ($in)
@@ -480,5 +447,5 @@ if ($inc)
   $hnc = "$tr" . _("UNUSED CUSTOM FIELDS") . "$rule1$hnc";
 print "$hdr$hu$hn$hnc</table>\n";
 
-trackers_footer ([]);
+trackers_footer ();
 ?>
