@@ -7,7 +7,7 @@
 # Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -64,7 +64,7 @@ extract (sane_import ('get',
 ));
 extract (sane_import ('post',
   [
-    'true' => ['post_changes', 'create_value', 'by_field_id'],
+    'true' => ['post_changes', 'create_value', 'by_field_id', 'submit'],
     'specialchars' => ['title', 'description', 'body'],
     'digits' => ['order_id', 'from', 'to'],
     'strings' =>
@@ -75,6 +75,7 @@ extract (sane_import ('post',
     'preg' => [['mail_list', '/^[-+_@.,\s\da-zA-Z]*$/']]
   ]
 ));
+form_check (['create_value', 'post_changes', 'submit']);
 
 if (!$group_id)
   exit_no_group ();
@@ -234,6 +235,35 @@ $td_select_box = function ($field)
     && trackers_data_is_select_box ($field);
 };
 
+function print_predefined_val_entry ($fld_val)
+{
+  extract ($fld_val);
+  # Non-active value are not important here.
+  if ($status != "A")
+    return;
+  print "<dt><b>$value</b> ($order_id)</dt>\n";
+  print "<dd>$description</dd>\n";
+}
+
+function list_predefined_values ($field)
+{
+  $res = trackers_data_get_field_predefined_values (
+    $field, '100', false, false, false
+  );
+  if (!db_numrows ($res))
+    {
+      $msg =
+        _("No default values found. You should report this problem to\n"
+          . "administrators.");
+      fb ($msg, 1);
+      return;
+    }
+  print "<dl>\n";
+  while ($fld_val = db_fetch_array ($res))
+    print_predefined_val_entry ($fld_val);
+  print "</dl>\n";
+}
+
 if ($list_value)
   {
     # Display the list of values for a given bug field.
@@ -244,16 +274,15 @@ if ($list_value)
 
     if ($td_select_box ($field))
       {
-        # First check that this field is used by the project and
-        # it is in the project scope.
-
-        $is_project_scope = trackers_data_is_project_scope ($field);
-
-        trackers_header_admin (array ('title' => $hdr));
-
-        print '<h1>' . _("Field Label:") . ' '
-          . trackers_data_get_label ($field) . "</h1>\n<p>"
-          . '<span class="smaller">('
+        # First check that this field is used by the group and
+        # it is in the group scope.
+        $is_group_scope = trackers_data_is_project_scope ($field);
+        trackers_header_admin (['title' => $hdr]);
+        print
+          html_h (1,
+            _("Field Label:") . ' ' . trackers_data_get_label ($field)
+          )
+          . '<p><span class="smaller">('
           . utils_link (
               $sys_home . ARTIFACT . "/admin/field_usage.php?group=$group"
               . "&amp;update_field=1&amp;field=$field",
@@ -268,29 +297,23 @@ if ($list_value)
 
         if (!$result || $rows <= 0)
           # TRANSLATORS: the  argument is field label.
-          printf (
-            "\n<h1>" . _("No values defined yet for %s") . "</h1>\n",
+          printf (html_h (1, _("No values defined yet for %s")),
             trackers_data_get_label ($field)
           );
         else
           {
-            print "\n<h2>" . _("Existing Values") . "</h2>\n";
-
-            $title_arr =  [];
-            if (!$is_project_scope)
-              $title_arr[] = _('ID');
-            $title_arr[] = _("Value label");
-            $title_arr[] = _("Description");
-            $title_arr[] = _("Rank");
-            $title_arr[] = _("Status");
-            $title_arr[] = _("Occurrences");
+            print html_h (2, _("Existing Values"));
+            $title_arr =  [_("Value label"), _("Description"), _("Rank"),
+              _("Status"), _("Occurrences")];
+            if (!$is_group_scope)
+              $title_arr = array_merge ([_('ID')], $title_arr);
 
             $hdr = html_build_list_table_top ($title_arr);
 
+            # TRANSLATORS: this is field status.
             $status_stg = [
-              # TRANSLATORS: this is field status.
              'A' => _("Active"), 'P' => _("Permanent"), 'H' => _("Hidden")
-           ];
+            ];
 
             # Display the list of values in 2 blocks: active first,
             # hidden second.
@@ -314,7 +337,7 @@ if ($list_value)
 
                 # Show the value ID only for system wide fields which
                 # value id are fixed and serve as a guide.
-                if (!$is_project_scope)
+                if (!$is_group_scope)
                   $html .= "<td>$value_id</td>\n";
 
                 # The permanent values cant be modified (No link).
@@ -360,11 +383,10 @@ if ($list_value)
             print "$hdr$ha$hh</table>\n";
           } # !(!$result || $rows <= 0)
 
-        # Only show the add value form if this is a project scope field.
-        if ($is_project_scope)
+        # Only show the add value form if this is a group scope field.
+        if ($is_group_scope)
           {
-            print '<h2>' . _("Create a new field value") . "</h2>\n";
-
+            print html_h (2, _("Create a new field value"));
             if ($ih)
               print '<p>'
                 . _("Before you create a new value make sure there isn't one "
@@ -379,11 +401,11 @@ if ($list_value)
                   'group_id' => $group_id
                 ]
               );
-            print '<span class="preinput"><label for="title">'
-              . _("Value:") . '</label> </span>'
+            print '<span class="preinput">'
+              . html_label ('title', _("Value:")) . '</span>&nbsp;'
               . form_input ("text", "title", "", 'size="30" maxlength="60"')
-              . "\n&nbsp;&nbsp;<span class='preinput'><label for='order_id'>"
-              . _("Rank:") . '</label> </span>'
+              . "\n&nbsp;&nbsp;<span class='preinput'>"
+              . html_label ('order_id', _("Rank:")) . '</span>&nbsp;'
               . form_input ("text", "order_id", "", 'size="6" maxlength="6"');
 
             if (isset ($none_rk))
@@ -395,71 +417,39 @@ if ($list_value)
                 print "</strong></p>\n";
               }
 
-            print "<p><span class='preinput'><label for='description'>"
-              . _("Description (optional):") . "</label></span><br />\n"
-              . "<textarea id='description' name='description' rows='4' "
-              . "cols='65' wrap='hard'></textarea></p>\n"
-              . "<div class='center'>\n"
-              . "<input type='submit' name='submit' value=\""
-              . _("Update") . "\" />\n</div>\n</form>\n";
-          } # $is_project_scope
+            print "<p><span class='preinput'>"
+              . html_label ('description', _("Description (optional):"))
+              . "</span><br />\n"
+              . form_textarea ('description', '',
+                 "rows='4' cols='65' wrap='hard'")
+              . "</p>\n" . form_footer (_("Update"), 'submit');
+          } # $is_group_scope
 
-        # If the project use custom values, propose to reset to the default.
+        # If the group use custom values, propose to reset to the default.
         if (trackers_data_use_field_predefined_values ($field, $group_id))
           {
-            print '<h2>' . _("Reset values") . "</h2>\n";
+            print html_h (2, _("Reset values"));
             print '<p>'
               . _("You are currently using custom values. If you want "
                   . "to reset values to the\ndefault ones, use the following "
                   . "form:")
               . "</p>\n\n"
-              . "<form action='field_values_reset.php' method='post' "
-              . "class='center'>\n"
+              . form_tag (
+                  ['action' => 'field_values_reset.php', 'class' => 'center']
+                )
               . form_hidden (['group_id' => $group_id, 'field' => $field])
-              . '<input type="submit" name="submit" value="'
-              . _("Reset values") . "\" />\n</form>\n<p>"
+              . form_footer (_("Reset values"), 'submit') . "<p>"
               . _("For your information, the default active values are:")
               . "</p>\n";
 
-            $default_result = trackers_data_get_field_predefined_values (
-              $field, '100', false, false, false
-            );
-            $default_rows = db_numrows ($default_result);
-            $previous = false;
-            if ($default_result && $default_rows > 0)
-              {
-                while ($fld_val = db_fetch_array ($default_result))
-                  {
-                    $status = $fld_val['status'];
-                    $value = $fld_val['value'];
-                    $description = $fld_val['description'];
-                    $order = $fld_val['order_id'];
-
-                    # Non-active value are not important here.
-                    if ($status != "A")
-                      continue;
-
-                    if ($previous)
-                      print ", ";
-
-                    print "<b>$value</b> <span class='smaller'>"
-                      . "($order, \"$description\")</span>";
-                    $previous = true;
-                  }
-              }
-            else
-              fb (
-                _("No default values found. You should report this problem "
-                  . "to\nadministrators."),
-                1
-              );
+            list_predefined_values ($field);
           }
       }
     else # ! $td_select_box ($field)
       {
         # TRANSLATORS: the argument is field.
         $msg = sprintf (
-          _("The field you requested '%s' is not used by your project "
+          _("The field you requested '%s' is not used by your group "
             . "or you are not\nallowed to customize it"),
           $field
         );
@@ -596,10 +586,7 @@ if ($list_value)
 
         print form_tag ([], "#registered");
         print form_hidden (
-          [
-            "post_transition_changes" => "y", "list_value" => "y",
-            "field" => $field, "group_id" => $group_id
-          ]
+          ["list_value" => "y", "field" => $field, "group_id" => $group_id]
         );
 
         $result = db_execute ("
@@ -646,27 +633,41 @@ if ($list_value)
               false, 'Any', false, _("allowed or not")
             )
           . "</td>\n";
-        $mlist   = "<td>\n<input type='text' value='' title=\""
-          . _("Carbon-Copy List")
-          . "\" name='mail_list' size='30' maxlength='60' />\n</td>\n";
-        print "$mlist</tr>\n</table>\n";
-        print '<div align="center"><input type="submit" name="submit" value="'
-          . _("Update Transition") . "\" /></div>\n</form>\n";
+        $mlist = form_input ('text', 'mail_list', '',
+            "title=\"" . _("Carbon-Copy List") . '" size="30" maxlength="60"'
+          );
+        print "<td>\n$mlist</td>\n</tr>\n</table>\n";
+        print form_footer (_("Update Transition"), 'submit');
       }
     else # !$td_select_box ($field)
       {
         print "\n\n<p><b>";
         # TRANSLATORS: the argument is field.
         printf (
-          _("The Bug field you requested '%s' is not used by your project "
+          _("The field you requested '%s' is not used by your group "
             . "or you are not\nallowed to customize it"),
           $field
         );
         print "</b></p>\n";
       }
-    trackers_footer ([]);
+    trackers_footer ();
     exit (0);
   } # if ($list_value)
+
+function print_value_rank ($row, $title)
+{
+  print '<span class="preinput">' . html_label ('title', $title);
+  print form_input (
+    "text", "title", utils_specialchars_decode ($row['value'], ENT_QUOTES),
+    'size="40" maxlength="60"'
+  );
+  print "\n&nbsp;&nbsp;\n<span class='preinput'>"
+    . html_label ('order_id', _("Rank:")) . '</span>&nbsp;';
+  print form_input (
+     "text", "order_id", $row['order_id'], 'size="6" maxlength="6"'
+   );
+}
+
 if ($update_value)
   {
     # Show the form to update an existing field_value.
@@ -675,6 +676,7 @@ if ($update_value)
 
     # Get all attributes of this value.
     $res = trackers_data_get_field_value ($fv_id);
+    $row = db_fetch_array ($res);
 
     print form_tag ()
       . form_hidden (
@@ -683,38 +685,21 @@ if ($update_value)
             "fv_id" => $fv_id, "field" => $field, "group_id" => $group_id,
           ]
         );
-    print '<p><span class="preinput"><label for="title">'
-      . _("Value:") . "</label> </span><br />\n";
-    print form_input (
-       "text", "title",
-       utils_specialchars_decode (db_result ($res, 0, 'value'), ENT_QUOTES),
-       'size="30" maxlength="60"'
-    );
-    print "\n&nbsp;&nbsp;\n"
-      . '<span class="preinput"><label for="order_id">'
-      . _("Rank:") . '</label> </span>';
-    print form_input (
-       "text", "order_id", db_result ($res, 0, 'order_id'),
-       'size="6" maxlength="6"'
-     );
-    $h_selected = '';
-    if (db_result ($res, 0, 'status') == 'H')
-      $h_selected = ' selected="selected"';
-    print "\n&nbsp;&nbsp;\n"
-      . '<span class="preinput"><label for="status">'
-      . _("Status:") . "</label></span>\n"
+    print_value_rank ($row, _("Value:"));
+    print "\n&nbsp;&nbsp;\n<span class='preinput'>"
+      . html_label ('status', _("Status:")) . "</span>\n"
       . "<select name='status' id='status'>\n"
       # TRANSLATORS: this is field status.
-      . "  <option value='A'>" . _("Active") . "</option>\n"
-      . "  <option value='H'$h_selected>" . _("Hidden")
-      . "</option>\n</select>\n<p>\n"
-      . '<span class="preinput"><label for="description">'
-      . _("Description (optional):") . "</label></span><br />\n"
-      . '<textarea id="description" name="description" rows="4" '
-      . 'cols="65" wrap="soft">'
-      . db_result ($res, 0, 'description'). "</textarea></p>\n";
+      . form_option ('A', null, _("Active"))
+      . form_option ('H', $row['status'], _("Hidden"))
+      . "</select>\n<p>\n<span class='preinput'>"
+      . html_label ('description', _("Description (optional):"))
+      . "</span><br />\n"
+      . form_textarea ('description', $row['description'],
+          'rows="4" cols="65" wrap="soft"')
+      . "</p>\n";
     $count = trackers_data_count_field_value_usage (
-      $group_id, $field, db_result ($res, 0, 'value_id')
+      $group_id, $field, $row['value_id']
     );
     if ($count > 0)
       {
@@ -735,12 +720,57 @@ if ($update_value)
         print "</p>\n";
       }
     print "\n<div class='center'>\n"
-      . '<input type="submit" name="submit" value="' . _("Submit")
-      . "\" />\n</p>\n";
+      . form_submit (_("Submit"), 'submit') . "</div>\n";
 
-    trackers_footer ([]);
+    trackers_footer ();
     exit (0);
   }
+function canned_hidden ($create)
+{
+  global $group_id, $item_canned_id;
+  $hidden = ['post_changes' => 'y', 'group_id' => $group_id];
+  if ($create)
+    {
+      $hidden['create_canned'] = 'y';
+      return $hidden;
+    }
+  $hidden['update_canned'] = 'y';
+  $hidden['item_canned_id'] = $item_canned_id;
+  return $hidden;
+}
+
+function print_form_canned ($row = null)
+{
+  $hidden = canned_hidden ($row === null);
+  if ($row === null)
+    $row = ['body' => '', 'order_id' => '', 'title' => ''];
+  print "<p>" . form_tag () . form_hidden ($hidden);
+  $row['value'] = $row['title'];
+  print_value_rank ($row, _("Title:"));
+  print "<br />\n<span class='preinput'>"
+    . html_label ("body", _("Message Body:")) . "</span><br />\n&nbsp;&nbsp;"
+    . form_textarea ('body', $row['body'], "rows='20' cols='65' wrap='hard'")
+    . form_footer (_("Submit"), 'submit');
+}
+
+function print_canned_row ($row, $group_id, $i)
+{
+  global $php_self;
+  $id = $row['bug_canned_id'];
+  $s_body = utils_cutstring ($row['body'], 360);
+  print '<tr class="' . utils_altrow ($i) . '">'
+    . "<td><a href=\"$php_self?update_canned=1&amp;"
+    . "item_canned_id=$id&amp;group_id=$group_id\">{$row['title']}</a></td>\n"
+    . "<td>$s_body</td>\n<td>{$row['order_id']}</td>\n"
+    . "<td class='center'>";
+  print form_tag ()
+    . form_hidden (['func' => 'delcanned', 'item_canned_id' => $id,
+        'group_id' => $group_id]
+      )
+    . form_image_trash ('submit') . "</form>\n";
+  print "</td></tr>\n";
+}
+
 if ($create_canned || $delete_canned)
   {
     # Show existing responses and UI form.
@@ -754,61 +784,24 @@ if ($create_canned || $delete_canned)
 
     if ($result && $rows > 0)
       {
-        print "\n<h2>" . _("Existing Responses:") . "</h2>\n<p>\n";
-
+        print html_h (2, _("Existing Responses:")) . "<p>\n";
         $title_arr = [
           _("Title"), _("Body (abstract)"), _("Rank"), _("Delete")
         ];
-
         print html_build_list_table_top ($title_arr);
-
-        for ($i = 0; $i < $rows; $i++)
-          {
-            $s_body = substr (db_result ($result, $i, 'body'), 0, 360);
-            print '<tr class="' . utils_altrow ($i) . '">'
-              . "<td><a href=\"$php_self"
-              . '?update_canned=1&amp;item_canned_id='
-              . db_result ($result, $i, 'bug_canned_id')
-              . "&amp;group_id=$group_id\">"
-              . db_result ($result, $i, 'title') . "</a></td>\n"
-              . "<td>$s_body...</td>\n"
-              . '<td>' . db_result ($result, $i, 'order_id') . "</td>\n"
-              . "<td class='center'><a href=\"$php_self"
-              . '?func=delcanned&amp;item_canned_id='
-              . db_result ($result, $i, 'bug_canned_id')
-              . "&amp;group_id=$group_id\">"
-              . html_image_trash (['alt' => _("Delete this canned response")])
-              . "</a></td></tr>\n";
-          }
+        $i = 0;
+        while ($row = db_fetch_array ($result))
+          print_canned_row ($row, $group_id, $i++);
         print "</table>\n";
       }
     else
-      print "\n<h2>" . _("No canned bug responses set up yet") . "</h2>\n";
-    print '<h2>' . _("Create a new response") . "</h2>\n<p>"
+      print html_h (2, _("No canned bug responses set up yet"));
+    print html_h (2,  _("Create a new response")) . "<p>"
       . _("Creating generic quick responses can save a lot of time when "
           . "giving common\nresponses.")
-      . "</p>\n" . form_tag ()
-      . form_hidden (
-          [
-            "create_canned" => "y", "group_id" => $group_id,
-            "post_changes" => "y",
-          ]
-        );
-    print '<span class="preinput"><label for="title">'
-      . _("Title:") . "</label></span><br />\n"
-      . '&nbsp;&nbsp;<input type="text" name="title" id="title" value="" '
-      . "size='50' maxlength='50' /><br />\n"
-      . '<span class="preinput"><label for="order_id">'
-      . _("Rank (useful in multiple canned responses):")
-      . "</label></span><br />\n"
-      . "&nbsp;&nbsp;<input type='text' name='order_id' id='order_id' "
-      . "value='' maxlength='50' /><br />\n"
-      . '<span class="preinput"><label for="body">' . _("Message Body:")
-      . "</label></span><br />\n&nbsp;&nbsp;<textarea id='body' name='body' "
-      . "rows='20' cols='65' wrap='hard'></textarea>\n<div class='center'>\n"
-      . '<input type="submit" name="submit" value="' . _("Submit")
-      . "\" />\n</div>\n</form>\n";
-    trackers_footer ([]);
+      . "</p>\n";
+    print_form_canned ();
+    trackers_footer ();
     exit (0);
   }
 if ($update_canned)
@@ -830,37 +823,17 @@ if ($update_canned)
         print '<p>'
 	  . _("Creating generic messages can save you a lot of time when giving\n"
               . "common responses.");
-        print "</p>\n<p>" . form_tag ()
-          . form_hidden (
-              [
-                "update_canned" => "y", "group_id" => $group_id,
-                "item_canned_id" => $item_canned_id, "post_changes" => "y"
-              ]
-            );
-        print '<span class="preinput">' . _("Title")
-          . ":</span><br />\n&nbsp;&nbsp;"
-          . '<input type="text" name="title" value="'
-          . db_result ($result, 0, 'title')
-          . "\" size='50' maxlength='50' /></p>\n<p>\n"
-          . '<span class="preinput">' . _("Rank") . ":</span><br />\n"
-          . '&nbsp;&nbsp;<input type="text" name="order_id" value="'
-          . db_result ($result, 0, 'order_id') . "\" /></p>\n<p>\n"
-          . '<span class="preinput">' . _("Message Body:") . "</span><br />\n"
-          . '&nbsp;&nbsp;<textarea name="body" rows="20" cols="65" '
-          . 'wrap="hard">' . db_result ($result, 0, 'body')
-          . "</textarea></p>\n<div class='center'>\n"
-          . "<input type='submit' name='submit' value=\"" . _("Submit")
-          . "\" />\n</div>\n</form>\n";
+        print "</p>\n";
+        print_form_canned (db_fetch_array ($result));
       }
-    trackers_footer ([]);
+    trackers_footer ();
     exit (0);
   }
 
 trackers_header_admin (['title' => _("Edit Field Values")]);
-
 print "<br />\n";
 
-# Loop through the list of all used fields that are project manageable.
+# Loop through the list of all used fields that are group manageable.
 $i = 0;
 $title_arr = [_("Field Label"), _("Description"), _("Scope")];
 print html_build_list_table_top ($title_arr);
@@ -875,7 +848,7 @@ while ($field_name = trackers_list_all_fields ())
       continue;
     $scope_label  = _("System");
     if (trackers_data_is_project_scope ($field_name))
-      $scope_label  = _("Project");
+      $scope_label  = _("Group");
     $desc = trackers_data_get_description ($field_name);
     print '<tr class="' . utils_altrow ($i) . '">'
       . "<td><a href=\"$php_self?group_id=$group_id"
@@ -893,8 +866,8 @@ print "\n<td>"
       . "tracker.\nThese pre-written messages can then be used to quickly "
       . "reply to item\nsubmissions.")
   . " </td>\n";
-print "\n<td>" . _("Project") . "</td></tr>\n";
+print "\n<td>" . _("Group") . "</td></tr>\n";
 print "</table>\n";
 
-trackers_footer ([]);
+trackers_footer ();
 ?>
