@@ -1,14 +1,22 @@
 <?php
 # Operate trackers.
 #
-# Copyright (C) 1999-2000 The SourceForge Crew
-# Copyright (C) 2001-2002 Laurent Julliard, CodeX Team, Xerox
-# Copyright (C) 2002-2006 Mathieu Roy <yeupou--gnu.org>
+# Copyright (C) 1999, 2000 The SourceForge Crew
+# Copyright (C) 2001, 2002 Laurent Julliard, CodeX Team, Xerox
+# Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright (C) 2017, 2019, 2022 Ineiev
+# Copyright (C) 2014, 2016, 2017 Assaf Gordon
+# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
+# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
+# under the terms of the GNU General Public license version 3 or (at your
+# option) any later version; further contributions are covered by
+# the GNU Affero General Public license version 3 or (at your option)
+# any later version.  The license notices for the AGPL and the GPL follow.
+#
 # Savane is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
 # published by the Free Software Foundation, either version 3 of the
@@ -21,8 +29,22 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Savane is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# Savane is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require_once ('../include/init.php');
+require_once ('../include/group.php');
 require_once ('../include/trackers/general.php');
 require_once ('../include/trackers/votes.php');
 
@@ -32,6 +54,19 @@ if (!$group_id)
 $is_trackeradmin =
   member_check (0, $group_id, member_create_tracker_flag (ARTIFACT) . '2');
 
+function extract_revert_order ()
+{
+  global $revert_comment_order, $order_reverted;
+  $revert_comment_order = false;
+  $revert = sane_import ('request', ['true' => ['revert_order', 'revert_bis']]);
+  $revert_comment_order = isset ($revert['revert_order']);
+  $order_reverted = isset ($revert['revert_bis']);
+  if ($order_reverted)
+    $revert_comment_order = !$revert_comment_order;
+}
+
+extract_revert_order ();
+
 # Mention if there was an attached file: we cannot pre-fill an HTML input file.
 function warn_about_uploads ()
 {
@@ -72,11 +107,11 @@ extract (sane_import ('request',
 ));
 extract (sane_import ('post',
   [
-    'hash' => 'form_id', 'true' => ['submitreturn', 'preview'],
-    'digits' => ['comment_type_id', 'quote_no'], 'pass' => 'comment',
+    'true' => ['submitreturn', 'preview'],
+    'digits' => ['comment_type_id', 'quote_no', 'new_vote'],
+    'pass' => 'comment',
     'preg' =>
       [
-        ['canned_response', '/^(\d+|!multiple!)$/'],
         [
           'originator_email',
           '/^[a-zA-Z0-9_.+-]+@(([a-zA-Z0-9-])+\.)+[a-zA-Z0-9]+$/'
@@ -88,10 +123,10 @@ extract (sane_import ('post',
 # Assign null to the fields that only tracker admins may modify.
 foreach (
   [
-    'depends_search', 'reassign_change_project_search', 'new_vote',
-    'cc_comment', 'add_cc', 'reassign_change_project',
+    'depends_search', 'reassign_change_group_search',
+    'cc_comment', 'add_cc', 'reassign_change_group',
     'depends_search_only_artifact', 'reassign_change_artifact',
-    'depends_search_only_project', 'dependent_on_task', 'dependent_on_bugs',
+    'depends_search_only_group', 'dependent_on_task', 'dependent_on_bugs',
     'dependent_on_support', 'dependent_on_patch',
   ] as $var
 )
@@ -100,13 +135,13 @@ foreach (
 if ($is_trackeradmin)
   extract (sane_import ('post',
     [
-      'pass' => ['depends_search', 'reassign_change_project_search'],
-      'digits' => 'new_vote', 'specialchars' => 'cc_comment',
+      'pass' => ['depends_search', 'reassign_change_group_search'],
+      'specialchars' => 'cc_comment',
       'preg' =>
         [
           ['add_cc', '/^[-+_@.,;\s\da-zA-Z]*$/'],
           [
-            'reassign_change_project', '/^[-_[:alnum:]]*$/'
+            'reassign_change_group', '/^[-_[:alnum:]]*$/'
           ]
         ],
       'strings' =>
@@ -117,7 +152,7 @@ if ($is_trackeradmin)
             ['all', 'support', 'bugs', 'task', 'patch']
           ],
           [
-            'depends_search_only_project',
+            'depends_search_only_group',
             ['any', 'notany']
           ]
         ],
@@ -132,14 +167,13 @@ if ($is_trackeradmin)
     ]
   ));
 
-foreach (['reassign_change_project_search', 'depends_search'] as $var)
+foreach (['reassign_change_group_search', 'depends_search'] as $var)
   if (!is_scalar ($$var))
     $$var = '';
 
-if ($canned_response === null)
-  extract (sane_import ('post',
-    ['array' => [['canned_response', [null, 'digits']]]]
-  ));
+extract (sane_import ('post',
+  ['array' => [['canned_response', [null, 'digits']]]]
+));
 
 if (empty ($canned_response))
   $canned_response = null;
@@ -151,17 +185,11 @@ extract (sane_import ('get',
   ]
 ));
 
-# If we are on an artifact index page and we have only one argument which is
-# a numeric number, we suppose it is an item_id.
-# Maybe it was a link shortcut like
-# blabla.org/task/?nnnn (blabla.org/task/?#nnnn cannot work because # is
-# not sent by the browser as it's a tag for html anchors).
-if (!empty ($_SERVER['QUERY_STRING'])
-    && ctype_digit ($_SERVER['QUERY_STRING']))
+if ($have_item_id && empty ($func))
   $func = 'detailitem';
 
 # Initialize the global data structure before anything else.
-trackers_init($group_id);
+trackers_init ($group_id);
 
 $project = project_get_object ($group_id);
 $changed = false;
@@ -174,35 +202,24 @@ if (!$func)
   $func = 'browse';
 
 $process_comment = false;
-if ($preview || isset($quote_no))
+if ($preview || isset ($quote_no) || $order_reverted)
   $process_comment = true;
 if ($process_comment)
   $submitreturn = 1;
 switch ($func)
 {
-  case 'search':
-    # Search in the item database.
+  case 'search': # Search items.
     include '../include/trackers_run/search.php';
     break;
 
-  case 'digest':
-    # Item digest: search item stage.
-    include '../include/trackers_run/digest.php';
-    include '../include/trackers_run/browse.php';
-    break;
-
-  case 'digestselectfield':
-    # Item digest: select field stage.
+  case 'digest':            # Item digest: select items.
+  case 'digestselectfield': # Item digest: select fields.
+  case 'digestget':         # Item digest: output.
+  case 'view-dependencies': # Special digest.
     include '../include/trackers_run/digest.php';
     break;
 
-  case 'digestget':
-    # Item digest: output.
-    include '../include/trackers_run/digest.php';
-    break;
-
-  case 'browse':
-    # Browse the bug database (it also the default).
+  case 'browse': # List items (the default).
     include '../include/trackers_run/browse.php';
     break;
 
@@ -218,12 +235,14 @@ switch ($func)
     # Actually add in the database what was filled in the form.
     $fields = sane_import ('post',
       [
-        'hash' => 'form_id', 'strings' => [['check', '1984']],
+        'strings' => [['check', '1984']],
         # As of 2022-02, frontend never reads from the spam_stats table,
-        # so we may safely 'pass' 'details'.
-        'pass' => 'details', 'true' => 'preview'
+        # so we may safely 'pass' 'details' and 'form_id'.
+        'pass' => ['form_id', 'details'], 'true' => 'submit'
       ]
     );
+    if (!isset ($fields['submit']))
+      $preview = true;
     db_autoexecute (
       'spam_stats',
       [
@@ -239,15 +258,13 @@ switch ($func)
     if (!user_isloggedin ())
       $anon_check_failed = empty ($fields['check']);
 
-    # Check for duplicates.
-    if (!form_check ($form_id))
-      exit_error(_("Exiting"));
+    form_check ();
 
     # Get the list of bug fields used in the form.
     $vfl = trackers_extract_field_list ();
 
     $item_id = null;
-    if (empty ($preview))
+    if (empty ($preview) && !$anon_check_failed)
       {
         # Data control layer.
         $item_id = trackers_data_create_item ($group_id, $vfl, $address);
@@ -271,7 +288,7 @@ switch ($func)
         list ($changed,) =
           trackers_attach_several_files ($item_id, $group_id, $changes);
         # Add new cc if any.
-        if ($add_cc && user_isloggedin())
+        if ($add_cc)
           trackers_add_cc ($item_id, $add_cc, $cc_comment, $changes);
 
         # Originator Email:
@@ -290,7 +307,7 @@ switch ($func)
                   trackers_add_cc (
                     $item_id, $originator_email, "-SUB-", $changes
                   );
-                else
+                elseif (!empty ($originator_email))
                   fb (_("Originator E-mail is not valid, thus was not added\n"
                         . "to the Carbon-Copy list."), 1);
               }
@@ -301,7 +318,7 @@ switch ($func)
         list ($additional_address, $sendall) =
           trackers_data_get_item_notification_info ($item_id, ARTIFACT, 0);
 
-        if ((trim ($address) != "") && (trim ($additional_address) != ""))
+        if ((trim ($address) != "") && $sendall)
           $address .= ", ";
         $address .= $additional_address;
         trackers_mail_followup ($item_id, $address);
@@ -343,8 +360,8 @@ switch ($func)
     # or manager.
     $fields = sane_import ('post',
       [
-        'hash' => 'form_id', 'digits' => ['item_id'],
-        'strings' => [['check', '1984']], 'pass' => 'comment'
+        'digits' => ['item_id'],
+        'strings' => [['check', '1984']], 'pass' => ['comment', 'form_id']
       ]
     );
     db_autoexecute (
@@ -356,10 +373,7 @@ switch ($func)
         'check_value' => $fields['check'], 'details' => $fields['comment']
       ]
     );
-
-    if (!form_check ($form_id))
-      exit_error (_("Exiting"));
-
+    form_check ();
     $anon_check_failed = false;
     if (!user_isloggedin ())
       $anon_check_failed = empty ($fields['check']) && !$process_comment;
@@ -390,7 +404,7 @@ switch ($func)
           }
         if (!$is_trackeradmin && db_result ($result, 0, 'discussion_lock'))
           exit_permission_denied ();
-        if (!group_restrictions_check ($group_id, ARTIFACT, 2))
+        if (!group_restrictions_check ($group_id, ARTIFACT, TRACKER_EVENT_COMMENT))
           exit_permission_denied ();
       }
     elseif (!$is_trackeradmin)
@@ -401,8 +415,7 @@ switch ($func)
 
     # Special case: we may be searching for an item, in that case
     # reprint the same page, plus search results.
-    if ($depends_search || $reassign_change_project_search
-        || $canned_response == "!multiple!")
+    if ($depends_search || $reassign_change_group_search)
       {
         if ($depends_search)
           {
@@ -415,23 +428,17 @@ switch ($func)
             );
             fb ($msg);
           }
-        if ($reassign_change_project_search)
+        if ($reassign_change_group_search)
           {
             $msg = sprintf (
-              _("You provided search words to get a list of projects\nthis "
+              _("You provided search words to get a list of groups\nthis "
                 . "item should maybe reassigned to. Below, in the section\n"
                 . "[%s Reassign this item], you can now select the "
-                . "appropriate\nproject and submit the form."),
-              $sys_https_url . $_SERVER['SCRIPT_NAME'] .'#reassign'
+                . "appropriate\ngroup and submit the form."),
+              $sys_https_url . $_SERVER['SCRIPT_NAME'] . '#reassign'
             );
             fb ($msg);
           }
-        if ($canned_response == "!multiple!")
-          {
-            fb (_("You selected Multiple Canned Responses: you are free now\n"
-                  . "to select the one you want to use to compose your answer.")
-            );
-          }
         include '../include/trackers_run/mod.php';
         exit (0);
       }
@@ -440,7 +447,9 @@ switch ($func)
     $vfl = trackers_extract_field_list();
 
     $changed = 0;
-    if (!$process_comment)
+    if ($process_comment)
+      warn_about_uploads ();
+    else
       {
         fb_anon_check_failed ($anon_check_failed);
         if (!$anon_check_failed)
@@ -477,32 +486,22 @@ switch ($func)
             exit (0);
           }
 
-        # Add new cc if any.
         if ($add_cc)
-          {
-            # No notification needs to be sent when a cc is added,
-            # it is irrelevant to the item itself.
-            trackers_add_cc ($item_id, $add_cc, $cc_comment, $changes);
-          }
-
-        # Update vote (will do the necessary checks itself).
-        # Currently votes does not influence notifications
-        # (that could harass developers).
+          # No notification needs to be sent when a CC is added,
+          # it is irrelevant to the item itself.
+          trackers_add_cc ($item_id, $add_cc, $cc_comment, $changes);
         if (trackers_data_is_used ("vote"))
           trackers_votes_update ($item_id, $new_vote);
       } # !$process_comment
-    else
-      warn_about_uploads ();
 
     # Now handle notification, after all necessary actions has been.
     if ($changed)
       {
         # Check if we re supposed to send all modifications to an address.
-        list($additional_address, $sendall) =
+        list ($additional_address, $sendall) =
           trackers_data_get_item_notification_info ($item_id, ARTIFACT, 1);
 
-        if (($sendall == 1) && (trim ($address) != "")
-            && (trim ($additional_address) != ""))
+        if ($sendall && trim ($address) != "")
           $address .= ", ";
         $address .= $additional_address;
         trackers_mail_followup ($item_id, $address, $changes);
@@ -526,15 +525,15 @@ switch ($func)
     # the bug must be in the original report, and will be duplicated
     # in the new one.
     if (
-      $reassign_change_project
+      $reassign_change_group
       || ($reassign_change_artifact && ($reassign_change_artifact != ARTIFACT))
     )
       {
-        dbg("reassign item: reassign_change_project:$reassign_change_project, "
+        dbg("reassign item: reassign_change_group:$reassign_change_group, "
             . "reassign_change_artifact:$reassign_change_artifact, ARTIFACT:"
             . ARTIFACT);
         trackers_data_reassign_item (
-          $item_id, $reassign_change_project, $reassign_change_artifact
+          $item_id, $reassign_change_group, $reassign_change_artifact
         );
       }
 
@@ -554,7 +553,7 @@ switch ($func)
             exit (0);
           }
         $_POST = $_FILES = [];
-        $form_id = $depends_search = $reassign_change_project_search =
+        $depends_search = $reassign_change_group_search =
         $add_cc = $input_file = $changed = $vfl = $details = $comment = null;
         $nocache = 1;
       }
@@ -568,7 +567,7 @@ switch ($func)
         trackers_data_delete_file($group_id, $item_id, $item_file_id);
 
          # Unset previous settings and return to the item.
-         $depends_search = $reassign_change_project_search = $add_cc
+         $depends_search = $reassign_change_group_search = $add_cc
            = $input_file = $changed = $vfl = $details = null;
          include '../include/trackers_run/mod.php';
       }
@@ -581,7 +580,7 @@ switch ($func)
     $changed = trackers_delete_cc ($group_id, $item_id, $item_cc_id, $changes);
 
     # Unset previous settings and return to the item.
-    $depends_search = $reassign_change_project_search = $add_cc = $input_file
+    $depends_search = $reassign_change_group_search = $add_cc = $input_file
       = $changed = $vfl = $details = null;
 
     include '../include/trackers_run/mod.php';
@@ -595,17 +594,16 @@ switch ($func)
     if ($changed)
       {
         # See if we are supposed to send all modifications to an address.
-        list($additional_address, $sendall) =
+        list ($additional_address, $sendall) =
           trackers_data_get_item_notification_info ($item_id, ARTIFACT, 1);
-        if (($sendall == 1) && (trim($address) != "")
-            && (trim($additional_address) != ""))
+        if ($sendall && trim ($address) != "")
           $address .= ", ";
         $address .= $additional_address;
         trackers_mail_followup($item_id, $address, $changes);
       }
 
     # Unset previous settings and return to the item.
-    $depends_search = $reassign_change_project_search = $add_cc = $input_file
+    $depends_search = $reassign_change_group_search = $add_cc = $input_file
       = $changed = $vfl = $details = $changes = $address = null;
     include '../include/trackers_run/mod.php';
     break;
@@ -622,8 +620,8 @@ switch ($func)
 
     # Determine the additional spamscore according to user credentials.
     # +1 = logged in user
-    # +3 = project member
-    # +5 = project admin
+    # +3 = group member
+    # +5 = group admin
     $spamscore = 1;
     if (member_check (0, $group_id))
       {
