@@ -1,11 +1,11 @@
 <?php
-# CVS instruction page.
+# VCS instruction page.
 # 
 # Copyright (C) 1999, 2000 The SourceForge Crew
 # Copyright (C) 2000-2006 Mathieu Roy
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -41,14 +41,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
-require_once('../include/init.php');
-require_once('../include/http.php');
-require_once('../include/vcs.php');
-
-# TRANSLATORS: This string is used in the context of
-# "Browsing the CVS repository" and "You can browse the CVS repository",
-# "Getting a copy of the CVS repository", see include/vcs.php.
-vcs_page (_('CVS'), 'cvs', $group_id);
-
+foreach (['init', 'http', 'vcs'] as $i)
+  require_once ("../include/$i.php");
+vcs_page (basename (dirname ($_SERVER['SCRIPT_NAME'])), $group_id);
 ?>
