@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -43,6 +43,7 @@
 
 require_once (dirname (__FILE__) . '/utils.php');
 require_once (dirname (__FILE__) . '/pwqcheck.php');
+require_once (dirname (__FILE__) . '/random-bytes.php');
 
 # Return a string explaining current pwcheck requirements.
 function expand_pwqcheck_options ()
@@ -182,6 +183,8 @@ function account_pwvalid ($newpass, $oldpass = '', $user = '')
 
 function account_realname_valid ($name)
 {
+  if ($name === null)
+    return 0;
   utils_get_content ("forbidden_realnames");
   if (empty ($GLOBALS['forbid_realname_regexp']))
     return 1;
@@ -190,6 +193,8 @@ function account_realname_valid ($name)
 
 function account_sanitize_realname ($name)
 {
+  if (!is_string ($name))
+    return '';
   return strtr ($name, "'\",<", "    ");
 }
 
@@ -453,67 +458,12 @@ function account_groupnamevalid ($name)
   return 0;
 }
 
-# <phpass>
-# From http://www.openwall.com/phpass/
-# Version 0.3 / genuine
-# Public domain
-# Author: Solar Designer
-function account_encode64 ($input, $count)
-{
-  $itoa64 = './0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz';
-  $output = '';
-  $i = 0;
-  do
-    {
-      $value = ord ($input[$i++]);
-      $output .= $itoa64[$value & 0x3f];
-      if ($i < $count)
-        $value |= ord ($input[$i]) << 8;
-      $output .= $itoa64[($value >> 6) & 0x3f];
-      if ($i++ >= $count)
-        break;
-      if ($i < $count)
-        $value |= ord ($input[$i]) << 16;
-      $output .= $itoa64[($value >> 12) & 0x3f];
-      if ($i++ >= $count)
-        break;
-      $output .= $itoa64[($value >> 18) & 0x3f];
-    }
-  while ($i < $count);
-  return $output;
-}
-
-function account_get_random_bytes ($count)
-{
-  $random_state = microtime ();
-  $output = '';
-  if (is_readable ('/dev/urandom') && ($fh = @fopen ('/dev/urandom', 'rb')))
-    {
-      $output = fread ($fh, $count);
-      fclose ($fh);
-    }
-  if (strlen ($output) < $count)
-    {
-      $output = '';
-      for ($i = 0; $i < $count; $i += 16)
-        {
-          $random_state =
-            md5 (microtime () . $random_state);
-          $output .=
-            pack ('H*', md5 ($random_state));
-        }
-      $output = substr ($output, 0, $count);
-    }
-  return $output;
-}
-# </phpass>
-
 function account_gensalt ($salt_base64_length = 16)
 {
   # Note: $salt_base64_length = 16 for SHA-512, cf. crypt(3)
   $salt_byte_length = $salt_base64_length * 6 / 8;
-  $rand_bytes = account_get_random_bytes ($salt_byte_length);
-  return account_encode64 ($rand_bytes, $salt_byte_length);
+  $rand_bytes = phpass_get_random_bytes ($salt_byte_length);
+  return phpass_encode64 ($rand_bytes, $salt_byte_length);
 }
 
 # Generate unix pw.
@@ -540,20 +490,6 @@ function account_nextuid ()
   return ($row[maxid] + 1);
 }
 
-# Print out shell selects.
-function account_shellselects ($current)
-{
-  $shells = file ("/etc/shells");
-  for ($i = 0; $i < count ($shells); $i++)
-    {
-      $this_shell = chop ($shells[$i]);
-      $sel = "";
-      if ($current == $this_shell)
-        $sel = " selected";
-      echo "<option$sel value=$this_shell>$this_shell</option>\n";
-    }
-}
-
 function account_validpw ($stored_pw, $plain_pw)
 {
   if (empty ($stored_pw) || empty ($plain_pw))
@@ -562,4 +498,67 @@ function account_validpw ($stored_pw, $plain_pw)
     return false;
   return crypt ($plain_pw, $stored_pw) == $stored_pw;
 }
+
+function account_key_separator ()
+{
+  return '###';
+}
+
+function account_filter_empty_keys ($keys)
+{
+  return array_filter ($keys, function ($x) { return !empty (trim ($x)); });
+}
+
+function account_get_authorized_keys ($uid = 0)
+{
+  if (empty ($uid))
+    $uid = user_getid ();
+  $res = db_execute (
+    "SELECT authorized_keys FROM user WHERE user_id = ?", [$uid]
+  );
+  $row = db_fetch_array ($res);
+  if (empty ($row['authorized_keys']))
+    $row['authorized_keys'] = '';
+  $keys = explode (account_key_separator (), $row['authorized_keys']);
+  return account_filter_empty_keys ($keys);
+}
+
+function account_join_keys ($keys)
+{
+  return join (account_key_separator (), account_filter_empty_keys ($keys));
+}
+
+function account_register_keys ($keys, $uid = 0)
+{
+  $res = db_execute ("UPDATE user SET authorized_keys = ? WHERE user_id = ?",
+    [account_join_keys ($keys), $uid]
+  );
+  if (!$res)
+    {
+      fb (_("Error while registering keys"), 1);
+      return;
+    }
+  if (count ($keys))
+    fb (_("Keys registered"));
+  else
+    fb (_("No key is registered"));
+}
+
+function account_new_keys_alert ($user_id)
+{
+  global $sys_name;
+  $subject = "$sys_name " . _("SSH key changed on your account");
+  # TRANSLATORS: the argument is site name (like Savannah).
+  $message = sprintf (
+    _("Someone, presumably you, has changed your SSH keys on %s.\n"
+      . "If it wasn't you, maybe someone is trying to compromise your "
+      . "account..."), $sys_name
+  );
+  # TRANSLATORS: the argument is site name (like Savannah).
+  $message .= "\n" . sprintf (_("-- the %s team."), $sys_name) . "\n";
+  sendmail_mail (
+    ['to' => user_get_email ($user_id)],
+    ['subject' => $subject, 'body' => $message]
+  );
+}
 ?>
