@@ -8,7 +8,7 @@
 # Copyright (C) 2007 Cliss XXI (GCourrier)
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -66,24 +66,21 @@ function db_check_mysqli ()
 
 function db_connect ()
 {
-  global $sys_dbhost, $sys_dbuser, $sys_dbpasswd, $conn, $sys_dbname;
-  global $mysql_conn;
+  global $sys_dbhost, $sys_dbport, $sys_dbuser, $sys_dbpasswd, $sys_dbname;
+  global $sys_dbsocket, $mysql_conn;
 
-  $mysql_conn = NULL;
+  $mysql_conn = null;
   db_check_mysqli ();
 
-  $conn = mysqli_connect ($sys_dbhost, $sys_dbuser, $sys_dbpasswd, $sys_dbname);
+  mysqli_report (MYSQLI_REPORT_ERROR);
+  $conn = mysqli_connect ($sys_dbhost, $sys_dbuser, $sys_dbpasswd, $sys_dbname,
+    $sys_dbport, $sys_dbsocket);
   if (!$conn)
-    {
-      print "<p>Failed to connect to database: ";
-      print mysqli_connect_error () . "</p>\n";
-      print "<p>Contact server administrators "
-        . "{$GLOBALS['sys_email_adress']}</p>\n";
-      exit;
-    }
+    return
+      "<p>Failed to connect to database: " . mysqli_connect_error () . "</p>\n";
   mysqli_set_charset ($conn, 'utf8');
   $mysql_conn = $conn;
-  return true;
+  return null;
 }
 
 function db_real_escape_string ($string)
@@ -211,40 +208,27 @@ function db_autoexecute ($table, $dict, $mode = DB_AUTOQUERY_INSERT,
 )
 {
   # Table name validation and quoting.
-  $tables = preg_split('/[\s,]+/', $table);
-  $tables_string = '';
-  $first = true;
+  $tables = preg_split ('/[\s,]+/', $table);
+  $tables_string = [];
   foreach ($tables as $table)
     {
-      if (!preg_match('/^[a-zA-Z_][a-zA-Z0-9_]+$/', $table))
+      if (!preg_match ('/^[a-zA-Z_][a-zA-Z0-9_]+$/', $table))
         util_die ("db_autoexecute: invalid table name: $table");
-      if ($first)
-        {
-          $tables_string = "`$table`";
-          $first = false;
-        }
-      else
-        $tables_string .= ",`$table`";
+      $tables_string[] = "`$table`";
     }
+  $tables_string = join (', ', $tables_string);
 
   switch ((string) $mode)
     {
     case 'INSERT':
     case '1':
-    # Quote fields to avoid problem with reserved words (bug #8898@gna).
-    # TODO: do connections with ANSI_QUOTES mode and use the standard
-    # "'" field delimiter.
-      $first = true;
+      # Quote fields to avoid problem with reserved words (bug #8898@gna).
+      # TODO: do connections with ANSI_QUOTES mode and use the standard
+      # "'" field delimiter.
+      $fields = [];
       foreach (array_keys ($dict) as $field)
-        {
-          if ($first)
-            {
-              $fields = "`$field`";
-              $first = false;
-            }
-          else
-            $fields .= ",`$field`";
-        }
+        $fields[] = "`$field`";
+      $fields = join (', ', $fields);
       $question_marks = utils_placeholders ($dict);
       return db_execute ("
         INSERT INTO $tables_string ($fields) VALUES ($question_marks)",
@@ -253,20 +237,17 @@ function db_autoexecute ($table, $dict, $mode = DB_AUTOQUERY_INSERT,
       break;
     case 'UPDATE':
     case '2':
-      $sql_fields = '';
-      $values = array();
-
+      $sql_fields = $values = [];
       foreach ($dict as $field => $value)
         {
-          $sql_fields .= "`$field`=?,";
+          $sql_fields[] = "`$field` = ?";
           $values[] = $value;
         }
-      $sql_fields = rtrim($sql_fields, ',');
-      $values = array_merge($values, $where_inputarr);
-      $where_sql = $where_condition ? "WHERE $where_condition" : '';
-      return db_execute ("
-        UPDATE $tables_string SET $sql_fields $where_sql",
-        $values
+      $sql_fields = join (', ', $sql_fields);
+      $values = array_merge ($values, $where_inputarr);
+      $where_sql = $where_condition? "WHERE $where_condition": '';
+      return db_execute (
+        "UPDATE $tables_string SET $sql_fields $where_sql", $values
       );
       break;
     default:
@@ -287,10 +268,21 @@ function db_autoexecute ($table, $dict, $mode = DB_AUTOQUERY_INSERT,
 # adodb.inc.php.
 function db_execute ($sql, $inputarr = null, $multi_query = 0)
 {
+  if (empty ($GLOBALS['mysql_conn']))
+    return null;
   $expanded_sql = db_variable_binding ($sql, $inputarr);
   return db_query ($expanded_sql, 0, $multi_query);
 }
 
+function db_query_prevent_die ($disable = null)
+{
+  static $die_disabled = false;
+  $prev = $die_disabled;
+  if ($disable !== null)
+    $die_disabled = !empty ($disable);
+  return $prev;
+}
+
 function db_query_die ($qstring, $errors = null)
 {
   $str = "db_query: SQL query error in [$qstring]";
@@ -299,7 +291,9 @@ function db_query_die ($qstring, $errors = null)
   else
     foreach ($errors as $idx => $err)
       $str .= "<br />\n<b>query $idx:</b> <i>$err</i>";
-  util_die ($str);
+  if (!db_query_prevent_die ())
+    util_die ($str);
+  return false;
 }
 
 function db_query ($qstring, $print = 0, $multi_query = 0)
@@ -351,7 +345,7 @@ function db_query ($qstring, $print = 0, $multi_query = 0)
   if ($print)
     {
       print "<pre>[";
-      print_r($qstring);
+      print_r ($qstring);
       print "]</pre>";
     }
 
@@ -375,14 +369,13 @@ function db_query ($qstring, $print = 0, $multi_query = 0)
           mysqli_next_result ($mysql_conn);
         }
       if ($fail)
-        db_query_die ($qstring, $errors);
+        return db_query_die ($qstring, $errors);
     }
   else
     $db_qhandle = mysqli_query ($mysql_conn, $qstring);
   if ($db_qhandle)
     return $db_qhandle;
-  db_query_die ($qstring);
-  return $db_qhandle;
+  return db_query_die ($qstring);
 }
 
 function db_numrows ($qhandle)
