@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -46,7 +46,7 @@ require_once (dirname (__FILE__) . "/utils.php");
 # Base function. The alternatives below should be used whenever relevant,
 # as they may wrap this one with additional useful things
 # (set HTTP response, etc).
-function exit_error ($title, $text = 0, $status = false)
+function exit_error ($title = '', $text = null, $status = false)
 {
   global $HTML, $feedback;
 
@@ -94,7 +94,7 @@ function exit_not_logged_in ()
 
 function exit_no_group ()
 {
-  exit_error (_("No group chosen"), 'nogroup');
+  exit_error (_("No group chosen"));
 }
 
 function exit_missing_param ($param_list = [])
