@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -43,40 +43,47 @@
 
 $dir_name = dirname (__FILE__);
 require_once ("$dir_name/spam.php");
+require_once ("$dir_name/random-bytes.php");
 
-# To use this form that disallow duplicates:
-#    - form_header must be used on the form
-#    - form_check must be used before any insert in the db after submission
-#    - form_clean must be used after succesful item submission
-
-# Start the form with unique ID, store it in the database.
-function form_header (
-  $action, $form_id = false, $method = "post", $extra = false
-)
+function form_get_id ()
 {
-  if ($extra)
-    $extra = " $extra";
-
-  # Keep previous form id, in case of form that are recreated on failure.
-  if (!$form_id)
-    {
-      utils_srand ();
-      $form_id = md5 (mt_rand (0, 1000000));
-    }
+  static $form_id = null;
+  if (!empty ($form_id))
+    return $form_id;
+  $uid = user_getid ();
+  $form_id = random_hash ($uid);
   $result = db_autoexecute ('form',
-    [ 'form_id' => $form_id, 'timestamp' => time (),
-      'user_id' => user_getid ()],
+    ['form_id' => $form_id, 'timestamp' => time (), 'user_id' => $uid],
     DB_AUTOQUERY_INSERT
   );
   if (db_affected_rows ($result) != 1)
     fb (_("System error while creating the form, report it to admins"), 1);
-
-  return "\n<form action=\""
-    . utils_specialchars ($action) . "\" method=\"$method\"$extra>"
-    . form_hidden (["form_id" => $form_id]);
+  return $form_id;
 }
 
-# Similar to form_header, but without generating new $form_id.
+function form_id_input ($method)
+{
+  if ($method != 'post')
+    return '';
+  return form_hidden (['form_id' => form_get_id ()]);
+}
+
+# To use this form that disallow duplicates:
+#    - form_header must be used on the form
+#    - form_check must be used before any insert in the DB after submission
+
+# Start the form with unique ID, store it in the database.
+function form_header ($action = null, $method = "post", $extra = false)
+{
+  if ($action === null)
+    $action = $GLOBALS["php_self"];
+  if ($extra)
+    $extra = " $extra";
+  return "\n<form action=\"$action\" method=\"$method\"$extra>\n"
+    . form_id_input ($method);
+}
+
+# Similar to form_header, but with a different argument parser.
 function form_tag ($args = [], $action_suffix = '')
 {
   $def_args = ['action' => $GLOBALS['php_self'], 'method' => 'post'];
@@ -86,11 +93,11 @@ function form_tag ($args = [], $action_suffix = '')
       $args[$k] = $def_args[$k];
 
   $args['action'] .= $action_suffix;
-  $arg_string = '';
+  $attr = '';
   foreach ($args as $k => $v)
-    $arg_string .= " $k=\"$v\"";
+    $attr .= " $k=\"$v\"";
 
-  return "\n<form $arg_string>\n";
+  return "<form $attr>\n" . form_id_input ($args['method']);
 }
 
 # Usual input.
@@ -121,7 +128,7 @@ function form_radio ($name, $value, $attr)
   $extra = '';
   if (!empty ($attr['checked']))
     $extra .= "checked='checked' ";
-  if (empty ($attr['id']) && !$label)
+  if (empty ($attr['id']) && $label)
     $attr['id'] = "val_{$value}_$name";
   if (!empty ($attr['id']))
     $extra .= "id=\"{$attr['id']}\"";
@@ -154,8 +161,13 @@ function form_option ($value, $selected_value = NULL, $label = NULL)
   if ($label === NULL)
     $label = $value;
   $ret = "<option value=\"$value\"";
-  if ($selected_value !== NULL && $value == $selected_value)
-    $ret .= ' selected="selected"';
+  if ($selected_value !== NULL)
+     {
+       if (!is_array ($selected_value))
+         $selected_value = [$selected_value];
+       if (in_array ($value, $selected_value))
+         $ret .= ' selected="selected"';
+     }
   return "$ret>$label</option>\n";
 }
 
@@ -177,10 +189,9 @@ function form_textarea ($name, $value="", $extra=false)
 }
 
 # Add submit button.
-function form_submit (
-  $text = false, $submit_name = "update", $extra = false, $skip_trap = false
-)
+function form_submit ($text = false, $submit_name = "update", $extra = false)
 {
+  global $int_trapisset;
   if (!$text)
     $text = _("Submit");
 
@@ -190,74 +201,32 @@ function form_submit (
   # Sure, some bots will someday implement CSS support, but the ones that does
   # not will not disappear as soon as this happen.
   $trap = '';
-  if (!$skip_trap && empty($GLOBALS['int_trapisset']) && !user_isloggedin())
+  if (empty ($int_trapisset) && !user_isloggedin ())
     {
       $trap = " " . form_input ("text", "website", "http://");
-      $GLOBALS['int_trapisset'] = true;
+      $int_trapisset = true;
     }
   return form_input ("submit", $submit_name, $text, $extra) . $trap;
 }
 
+function form_image ($img, $text, $name)
+{
+  $extra = html_image_attributes ($img, ['alt' => $text]);
+  return form_input ('image', $name, '', $extra);
+}
+
+function form_image_trash ($name, $text = null)
+{
+  if ($text === null)
+    $text = _('Delete');
+  $extra = html_image_trash_attributes (['alt' => $text]);
+  return form_input ('image', $name, '', $extra);
+}
 # Close the form, with submit button.
-function form_footer ($text=false, $submit_name="update")
+function form_footer ($text = false, $submit_name = "update")
 {
-  return '
-    <div class="center">
-      '.form_submit($text, $submit_name).'
-    </div>
-  </form>';
-}
-
-# Check whether this is a duplicate or not: return true if the form
-# is ok.
-# Exit if we found sql wildcards: forged form, probably.
-# We do need this extra check for anynomous users. Logged in users can forge
-# their id and remove all the form id of their user, if they wish. Its their
-# problem.
-#
-# form_check is also used as a cross-side request forgery (CSRF) protection.
-function form_check ($form_id)
-{
-  if (!empty($GLOBALS['sys_debug_noformcheck']))
-    return 1;
-  # First, check for spambots (will kill the session if necessary).
-  form_check_nobot();
-
-  if (user_getid() == 0
-      && (!preg_match('/^[a-f0-9]*$/', $form_id)))
-    {
-      fb(_("Unrecognized unique form_id"), 1);
-      return 0;
-    }
-
-  # See bug #6983.
-  # We must clean the form id right now. This is not how the form id mechanism
-  # was designed.
-  #
-  # Originally, form id was supposed to be deleted only when we are sure
-  # that the form was posted.
-  # However, since apache & all are multithreaded, you can end up with the
-  # case that the delay between the initial check and the end of the form
-  # is long enough to make possible a duplicate.
-  #
-  # Now, the check will remove the id. If the remove fail, it means that
-  # the form id no longer exists and then we exit. We will have only one
-  # SQL request, reducing as much as possible delays.
-  $result = db_execute (
-    "DELETE FROM form WHERE user_id = ? AND form_id = ?",
-    [user_getid (), $form_id]
-  );
-  if (db_affected_rows ($result))
-    return 1;
-  fb (_("Duplicate Post: this form was already submitted."), 1);
-  return 0;
-}
-
-# Remove form_id from database: the item was posted.
-function form_clean ($form_id)
-{
-  # Form_id are now directly removed by form_check.
-  return 1;
+  return "\n<div class='center'>\n" . form_submit ($text, $submit_name)
+    . "</div>\n</form>\n";
 }
 
 # Check whether the trap field has been filled. If so, refuse the post.
@@ -265,13 +234,70 @@ function form_clean ($form_id)
 # dumbuser-compliant.
 function form_check_nobot ()
 {
-  extract(sane_import('request', ['pass' => 'website']));
-  if ($website != "" && $website != "http://")
-    {
-      # Not much explanation on the reject, since we are hunting spammers.
-      exit_log("filled the spam trap special field");
-      exit_missing_param();
-    }
+  extract (sane_import ('request', ['pass' => 'website']));
+  if (in_array ($website, ["", "http://"]))
+    return;
+  # Not much explanation on the reject, since we are hunting spammers.
+  exit_log ("filled the spam trap special field");
+  exit_missing_param ();
+}
+
+function form_preliminary_check ($form_id)
+{
+  form_check_nobot ();
+  if (empty ($form_id))
+    exit_missing_param (['form_id']);
+}
+
+# Remove form_id from the database; make sure it belongs to the current
+# user.  Return 0 in case of success, else 1.
+function form_reset_form_id ($form_id)
+{
+  $result = db_execute ("DELETE FROM form WHERE user_id = ? AND form_id = ?",
+    [user_getid (), $form_id]
+  );
+  if (db_affected_rows ($result))
+    return 0;
+  fb (_("Duplicate Post: this form was already submitted."), 1);
   return 1;
 }
+
+# Return false either if $submit_list is null or any listed
+# global variables are set; else return true.
+function form_vars_empty ($submit_list)
+{
+  if ($submit_list === null)
+    return false;
+  if (!is_array ($submit_list))
+    $submit_list = [$submit_list];
+  foreach ($submit_list as $var)
+    if (!empty ($GLOBALS[$var]))
+      return false;
+  return true;
+}
+
+# Check whether this is a duplicate or not: exit when the form_id is absent
+# in the DB, which may mean that it has already been submitted (user's mistake)
+# or has never been registered (CSRF).
+function form_check ($submit_list = null)
+{
+  if (form_vars_empty ($submit_list))
+    return;
+  $form_id = '';
+  extract (sane_import ('post', ['hash' => 'form_id']));
+  form_preliminary_check ($form_id);
+  # See Savannah bug #6983.
+  # We must clean the form ID right now.  Originally, form ID was deleted
+  # only when we were sure that the form was posted.
+  #
+  # However, since apache & all are multithreaded, you can end up with the
+  # case that the delay between the initial check and the end of the form
+  # is long enough to make possible a duplicate.
+  #
+  # Now, the check will remove the ID.  If the remove fail, it means that
+  # the form ID no longer exists and then we exit.  We will have only one
+  # SQL request, reducing as much as possible delays.
+  if (form_reset_form_id ($form_id))
+    exit_error (_("Exiting"));
+}
 ?>
