@@ -7,7 +7,7 @@
 # Copyright (C) 2008 Aleix Conchillo Flaque
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -78,7 +78,9 @@ class Group extends savane_error
   var $data_array; # Data from db.
   var $type_data_array;
   var $group_id;
+  var $type_id;
   var $db_result; # Database result set handle.
+  var $db_type_result;
   var $perm_data_array; # Permissions data row from db.
   var $is_admin; # Whether the user is an admin/super user of this project.
 
@@ -450,20 +452,9 @@ class Group extends savane_error
     return $this->CanUse ($artifact);
   }
 
-  function UsesForHomepage ($artifact)
+  function UsesForHomepage ($vcs)
   {
-    # Useful to determine whether the project is a specific artifact
-    # to manage its homepage:
-    #   - must use homepage
-    #   - must be set as homepage SCM for the group type
-    #   - the projet url must be empty or equal to the group setting
-    return
-      $this->Uses ("homepage")
-      && $this->type_data_array['homepage_scm'] == $artifact
-      && (
-           $this->data_array['url_homepage'] == $this->getTypeUrl ('homepage')
-           || $this->data_array['url_homepage'] == ""
-         );
+    return $this->Uses ("homepage") && $vcs == 'cvs';
   }
 
   # Related to mail notification.
@@ -580,10 +571,20 @@ function group_trimmed_array ($res, $suff)
   return $ret;
 }
 
+function group_null_perm ($art)
+{
+  if (!is_array ($art))
+    return null;
+  $ret = [];
+  foreach ($art as $a)
+    $ret[$a] = null;
+  return $ret;
+}
+
 function group_get_perm_flags ($group_id, $artifact, $prefix = '')
 {
   if (empty ($artifact))
-    return null;
+    return group_null_perm ($artifact);
   $art = $artifact;
   if (is_scalar ($artifact))
     $art = [$art];
@@ -597,7 +598,7 @@ function group_get_perm_flags ($group_id, $artifact, $prefix = '')
     [$group_id]
   );
   if (!db_numrows ($res))
-    return null;
+    return group_null_perm ($artifact);
   if (is_scalar ($artifact))
     return db_result ($res, 0, "$artifact$suff");
   return group_trimmed_array ($res, $suff);
@@ -627,7 +628,7 @@ function group_getrestrictions (
 {
   $flag = group_get_perm_flags ($group_id, $artifact, 'r');
   if ($flag === null)
-    return $flag;
+    return group_null_perm ($artifact);
   $f = $flag;
   if (is_scalar ($f))
     $f = [$f];
