@@ -7,7 +7,7 @@
 # Copyright (C) 2008 Aleix Conchillo Flaque
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -87,24 +87,16 @@ function html_show_boxoptions ($legend, $text, $form_opening = 0,
 
   # We add boxoptionwanted to be able to determine if a boxoption was used
   # to update the page, in which case the boxoption must appear deployed.
-  $ret .= "$text"
-     . form_input ("hidden", "boxoptionwanted", "1")
-     . '</div>';
+  $ret .= $text . form_hidden (["boxoptionwanted" => "1"]);
 
   if ($form_opening && $submit)
     $ret .= "\n</form>\n";
+  $ret .= "</div>\n";
 
   return "$ret\n";
 }
 
-# Function to create a an area in the page that can be hidden or shown
-# in one click with a JavaScript.
-# Per policy, this must work with a browser that does not support at all
-# JavaScript.
-# This is useful on item pages because we have some info that is not
-# essential to be shown (like CC list etc), but still very nice be able to
-# access easily.
-function html_hidsubpart_header ($uniqueid, $title, $deployed=false)
+function html_hidsubpart_set_deployed ($uniqueid, $deployed)
 {
   global $is_deployed;
 
@@ -117,20 +109,35 @@ function html_hidsubpart_header ($uniqueid, $title, $deployed=false)
     $deployed = $is_deployed[$uniqueid];
   if ($deployed != 1)
     $deployed = 0;
+  return $deployed;
+}
 
-  $ret = "\n<h2 id=\"$uniqueid\">\n"
-    . '<script type="text/javascript" src="/js/show-hide.php?'
+function html_hidsubpart_js ($deployed, $title, $uniqueid)
+{
+ return '<script type="text/javascript" src="/js/show-hide.php?'
   . "deploy=$deployed&amp;legend=" . utils_urlencode ($title)
-  . "&amp;box_id=hidsubpart&amp;suffix=$uniqueid\"></script>\n";
-  $ret .= "\n<noscript>\n<a href=\"#$uniqueid\">$title</a>\n</noscript>"
+  . "&amp;box_id=hidsubpart&amp;suffix=$uniqueid\"></script>\n"
+  . "\n<noscript>\n<a href=\"#$uniqueid\">$title</a>\n</noscript>";
+}
+
+# Function to create a an area in the page that can be hidden or shown
+# in one click with a JavaScript.
+# Per policy, this must work with a browser that does not support at all
+# JavaScript.
+# This is useful on item pages because we have some info that is not
+# essential to be shown (like CC list etc), but still very nice be able to
+# access easily.
+function html_hidsubpart_header ($uniqueid, $title, $deployed = false)
+{
+  $deployed = html_hidsubpart_set_deployed ($uniqueid, $deployed);
+  $ret = "\n<h2 id=\"$uniqueid\">\n"
+    . html_hidsubpart_js ($deployed, $title, $uniqueid)
     . "</h2>\n\n";
   $ret .= "<div id=\"hidsubpartcontent$uniqueid\">\n";
-  if (!$deployed)
-    {
-      $ret .= '<script type="text/javascript" src="/js/hide-span.php'
-        . "?box_id=hidsubpartcontent$uniqueid\"></script>\n";
-    }
-  return $ret;
+  if ($deployed)
+    return $ret;
+  return $ret . '<script type="text/javascript" src="/js/hide-span.php'
+    . "?box_id=hidsubpartcontent$uniqueid\"></script>\n";
 }
 
 function html_hidsubpart_footer ()
@@ -210,6 +217,8 @@ function html_anchor ($content, $name)
 
 function html_format_feedback ($f)
 {
+  if (empty ($f))
+    $f = '';
   $f = preg_replace ('/\n*$/', '', $f);
   return nl2br (markup_basic (utils_specialchars ($f)));
 }
@@ -219,14 +228,6 @@ function html_feedback ($bottom)
 {
   global $feedback, $ffeedback, $sys_home;
 
-  # Escape the html special chars, active markup.
-
-  # Ugh... Actually this is because feedback may be passed through
-  # $_GET[] in some situations, which can lead to XSS if the content
-  # is not escaped. We need a proper way to display formatted text to
-  # the user - OR, we need to properly replace pages that pass
-  # 'feedback' as a GET argument (grep 'feedback=').
-
   # Be quiet when there is no feedback.
   if (!($ffeedback || $feedback))
     return;
@@ -243,11 +244,8 @@ function html_feedback ($bottom)
 
   $class_hide = 'feedback';
 
-  # Users can choose the same behavior, disallowing the fixed positionning
-  # of the feedback (less convenient as the feedback gets easily hidden,
-  # requires to scroll to be accessed, but seems prefered by users of
-  # mozilla that slow scrolling down/up when there is such fixed box on the
-  # page).
+  # Users can choose the same behavior, disallowing the fixed positioning
+  # of the feedback.
   if (user_get_preference ("nonfixed_feedback"))
     {
       $class_hide = 'feedback feedback-hide';
@@ -259,37 +257,28 @@ function html_feedback ($bottom)
   print '<script type="text/javascript" src="/js/show-feedback.php?suffix='
     . "$suffix\"></script>\n";
 
-  $img_ok = "bool/ok.png"; $img_wrong = "bool/wrong.png";
+  $img_ok = html_image ("bool/ok.png", ['class' => 'feedbackimage']);
+  $img_wrong = html_image ("bool/wrong.png", ['class' => 'feedbackimage']);
   # Only success.
   if ($feedback && !$ffeedback)
     print "<div id=\"feedback$suffix\" class=\"$class_hide\">"
-      . '<span class="feedbacktitle">'
-      . html_image ($img_ok, ['class' => 'feedbackimage'])
+      . '<span class="feedbacktitle">' . $img_ok
       . _("Success:") . "</span> $feedback</div>\n$script_hide";
 
   # Only errors.
   if ($ffeedback && !$feedback)
-    {
-      print "<div id=\"feedback$suffix\" class=\"feedbackerror $class_hide\">"
-        . "<span class='feedbackerrortitle'>"
-        . html_image ($img_wrong, ['class' => 'feedbackimage'])
-        . _("Error:") . "</span>\n$ffeedback</div>\n";
-    }
+    print "<div id=\"feedback$suffix\" class=\"feedbackerror $class_hide\">"
+      . "<span class='feedbackerrortitle'>$img_wrong"
+      . _("Error:") . "</span>\n$ffeedback</div>\n";
 
   # Errors and success.
   if ($ffeedback && $feedback)
-    {
-      print "<div id=\"feedback$suffix\" class=\"feedbackerrorandsuccess "
-        . "$class_hide\"><span class='feedbackerrorandsuccesstitle'>"
-        . html_image ($img_wrong, ['class' => 'feedbackimage'])
-        . _("Some Errors:") . "</span> $feedback $ffeedback</div>\n";
-    }
+    print "<div id=\"feedback$suffix\" class=\"feedbackerrorandsuccess "
+      . "$class_hide\"><span class='feedbackerrorandsuccesstitle'>$img_wrong"
+      . _("Some Errors:") . "</span> $feedback $ffeedback</div>\n";
 
   # We empty feedback so there will be a bottom feedback only if something
-  # changed. It may confuse users, however I would find more confusing to
-  # have two lookalike feedback information providing most of the time the
-  # same information AND (that is the problem) sometimes more information
-  # in the second one.
+  # changes.
   $feedback = $ffeedback = '';
 }
 
@@ -303,9 +292,21 @@ function html_feedback_bottom ()
   html_feedback (1);
 }
 
-function html_image ($src, $args = [])
+# Return image size attributes for a file.
+function html_image_get_size ($src, $path)
 {
-  GLOBAL $img_attr, $sys_home, $sys_www_topdir;
+  static $img_attr = [];
+  # Check to see if we've already fetched the image data.
+  if (!array_key_exists ($src, $img_attr) && is_file ($path))
+    list ($width, $height, $type, $img_attr[$src]) =
+      @getimagesize ($path);
+  return $img_attr[$src];
+}
+
+# Compile attributes for <img /> and <input type="image" />.
+function html_image_attributes ($src, $args)
+{
+  global $sys_home, $sys_www_topdir;
   $base = "images/" . SV_THEME . ".theme/$src";
   $path = "$sys_www_topdir/$base";
 
@@ -315,29 +316,39 @@ function html_image ($src, $args = [])
   if (empty ($args['border']))
     $args['border'] = 0;
 
-  $return = "<img src=\"$sys_home$base\"";
+  $return = "src=\"$sys_home$base\"";
 
   foreach ($args as $k => $v)
     $return .= " $k=\"$v\"";
 
   # If there is neither height nor width tag, insert them both.
   if (empty ($args['height']) && empty ($args['width']))
-    {
-     # Check to see if we've already fetched the image data.
-     if (empty ($img_attr[$src]) && is_file ($path))
-        {
-          list ($width, $height, $type, $img_attr[$src]) =
-            @getimagesize ($path);
-        }
-      $return .= ' ' . $img_attr[$src];
-    }
+    $return .= ' ' . html_image_get_size ($src, $path);
 
-  return "$return />";
+  return $return;
 }
 
-function html_image_trash ($args)
+function html_image_base ($attr)
 {
-  return html_image ('misc/trash.png', $args);
+  return "<img $attr />";
+}
+
+function html_image ($src, $args = [])
+{
+  return html_image_base (html_image_attributes ($src, $args));
+}
+
+function html_image_trash_attributes ($args)
+{
+  if (!array_key_exists ('alt', $args))
+    $args['alt'] = _("Delete");
+  return html_image_attributes ('misc/trash.png', $args);
+}
+
+function html_image_trash ($args = [])
+{
+  $attr = html_image_trash_attributes ($args);
+  return html_image_base ($attr);
 }
 
 function html_label ($for, $title)
@@ -345,6 +356,16 @@ function html_label ($for, $title)
   return "<label for='$for'>$title</label>";
 }
 
+function html_h ($no, $title, $attr = [])
+{
+  $extra = '';
+  if (!is_array ($attr))
+    $attr = ['id' => $attr];
+  foreach ($attr as $k => $v)
+    $extra .= " $k='$v'";
+  return "<h$no$extra>$title</h$no>\n";
+}
+
 # Start a list table from an array of titles and builds.
 # The first row of a new table.
 #
@@ -353,7 +374,6 @@ function html_build_list_table_top (
   $title_arr, $links_arr = false, $table = true
 )
 {
-  global $HTML;
   $return = '';
 
   if ($table)
@@ -363,21 +383,15 @@ function html_build_list_table_top (
 
   $count = count ($title_arr);
   if ($links_arr)
-    {
-      for ($i = 0; $i < $count; $i++)
-        {
-          $ln = $links_arr[$i]; $ti = $title_arr[$i];
-          $return .= "<th class='boxtitle'>"
-            . "<a class='sortbutton' href=\"$ln\">$ti</a></th>\n";
-        }
-    }
+    for ($i = 0; $i < $count; $i++)
+      {
+        $ln = $links_arr[$i]; $ti = $title_arr[$i];
+        $return .= "<th class='boxtitle'>"
+          . "<a class='sortbutton' href=\"$ln\">$ti</a></th>\n";
+      }
   else
-    {
-      for ($i = 0; $i < $count; $i++)
-        {
-          $return .= "<th class='boxtitle'>{$title_arr[$i]}</th>\n";
-        }
-    }
+    for ($i = 0; $i < $count; $i++)
+      $return .= "<th class='boxtitle'>{$title_arr[$i]}</th>\n";
   return "$return</tr>\n";
 }
 
@@ -406,17 +420,14 @@ function html_build_select_box_from_array (
   $vals, $select_name, $checked_val = 'xzxz', $samevals = 0, $title = ""
 )
 {
-  $return = "<select " . html_title_attr($title) . "name=\"$select_name\">\n";
+  $return = "<select " . html_title_attr ($title) . "name=\"$select_name\">\n";
   $rows = count ($vals);
   for ($i = 0; $i < $rows; $i++)
     {
       $v = $i;
       if ($samevals)
         $v = $vals[$i];
-      $return .= "  <option value=\"$v\"";
-      if ($v == $checked_val)
-        $return .= ' selected="selected"';
-      $return .= ">{$vals[$i]}</option>\n";
+      $return .= "  " . form_option ($v, $checked_val, $vals[$i]);
     }
   return "$return\n</select>\n";
 }
@@ -471,44 +482,27 @@ function html_build_select_box_from_arrays (
 
   # We want the "Default" on item initial post, only at this momement.
   if ($show_unknown)
-    {
-      $return .= "<option value=\"!unknown!\">" . _("Unknown") . "</option>\n";
-    }
+    $return .= form_option ("!unknown!", NULL, _("Unknown"));
 
   # We don't always want the default any  row shown.
   if ($show_any)
-    {
-      $selected = ( $checked_val == 0 ? 'selected="selected"':'');
-      $return .= "<option value=\"0\" $selected>$text_any </option>\n";
-    }
+    $return .= form_option ("0", $checked_val, $text_any);
 
   # We don't always want the default 100 row shown.
   if ($show_100)
-    {
-      $selected = ( $checked_val == 100 ? 'selected="selected"':'');
-      $return .= "<option value=\"100\" $selected>$text_100 </option>\n";
-    }
+    $return .= form_option ("100", $checked_val, $text_100);
 
   $rows = count ($vals);
   if (count ($texts) != $rows)
     $return .= _('ERROR - number of values differs from number of texts');
 
   for ($i = 0; $i < $rows; $i++)
-    {
-      #  Uggh - sorry - don't show the 100 row and Any row.
-      #  If it was shown above, otherwise do show it.
-      if ((($vals[$i] != '100') && ($vals[$i] != '0'))
-           || ($vals[$i] == '100' && !$show_100)
-           || ($vals[$i] == '0' && !$show_any))
-        {
-          $return .= "\n<option value=\"{$vals[$i]}\"";
-          if ($vals[$i] == $checked_val)
-            {
-              $return .= ' selected="selected"';
-            }
-          $return .= ">{$texts[$i]}</option>\n";
-       }
-    }
+    #  Uggh - sorry - don't show the 100 row and Any row.
+    #  If it was shown above, otherwise do show it.
+    if ((($vals[$i] != '100') && ($vals[$i] != '0'))
+         || ($vals[$i] == '100' && !$show_100)
+         || ($vals[$i] == '0' && !$show_any))
+      $return .= form_option ($vals[$i], $checked_val, $texts[$i]);
   $return .= "</select>\n";
   return $return;
 }
@@ -555,11 +549,8 @@ function html_build_localized_select_box (
 # or value and the second column being the text you want displayed.
 #
 # The second parameter is the name you want assigned to this form element.
-#
 # The third parameter is an array of checked values.
-#
 # The fourth parameter is the size of this box.
-#
 # Fifth to eigth params determine whether to show None and Any.
 #
 # Ninth param determine whether to show numeric values next to
@@ -572,41 +563,19 @@ function html_build_multiple_select_box (
 {
   $title_attr = html_title_attr ($title);
   $return = "\n<select $title_attr name=\"$name\" multiple size='$size'>\n";
-  # Put in the Any box.
   if ($show_any)
-    {
-      $return .= '<option value="0"';
-      foreach ($checked_array as $v)
-        if ($v == '0')
-          $return .= ' selected="selected"';
-      $return .= ">$text_any</option>\n";
-    }
-  # Put in the default NONE box.
+    $return .= form_option ("0", $checked_array, $text_any);
   if ($show_100)
+    $return .= form_option ("100", $checked_array, $text_100);
+  while ($row = db_fetch_array ($result))
     {
-      $return .= '<option value="100"';
-      foreach ($checked_array as $v)
-        if ($v == '100')
-          $return .= ' selected="selected"';
-      $return .= ">$text_100</option>\n";
-    }
-  $rows = db_numrows ($result);
-  for ($i = 0; $i < $rows; $i++)
-    {
-      if (db_result($result, $i, 0) != '100')
-        {
-          $return .= '<option value="' . db_result ($result, $i, 0) . '"';
-          # Determine if it's checked.
-          $val = db_result ($result, $i, 0);
-          foreach ($checked_array as $v)
-            if ($val == $v)
-              $return .= ' selected="selected"';
-          $val .= '-';
-          if (!$show_value)
-            $val = '';
-          $return .= ">$val"
-             . substr (db_result ($result, $i, 1), 0, 35) . "</option>\n";
-        }
+      if ($row[0] == '100')
+        continue;
+      $val = $row[0] . '-';
+      if (!$show_value)
+        $val = '';
+      $label = $val . substr ($row[1], 0, 35);
+      $return .= form_option ($row[0], $checked_array, $label);
     }
   return "$return</select>\n";
 }
@@ -636,10 +605,10 @@ function html_select_permission_box ($artifact, $row, $level = "member")
     . "\" name=\"{$artifact}_user_$num\">\n";
   if ($default)
     {
-      $sel = ' selected="selected"';
+      $sel = 'NULL';
       if ($value)
-        $sel = '';
-      print "  <option value='NULL'$sel>$default</option>\n";
+        $sel = 'value';
+      print "  " . form_option ('NULL', $sel, $default);;
     }
   $labels = [
     [9, _("None")],
@@ -651,11 +620,7 @@ function html_select_permission_box ($artifact, $row, $level = "member")
     {
       if ($artifact == 'news' && count ($vl) > 2)
         continue;
-      $v = $vl[0]; $l = $vl[1];
-      $sel = '';
-      if ($value == $v)
-        $sel = ' selected="selected"';
-      print "  <option value='$v'$sel>$l</option>\n";
+      print "  " . form_option ($vl[0], $value, $vl[1]);
     }
   print "</select>\n";
   if (!$value && $level == "group")
@@ -698,23 +663,17 @@ function html_select_restriction_box (
 
   if ($default)
     {
-      $sel = ' selected="selected"';
+      $sel = 'NULL';
       if ($value)
-        $sel = '';
-      print "<option value='NULL'$sel>$default</option>\n";
+        $sel = 'value';
+      print form_option ('NULL', $sel, $default);
     }
   $labels = [
     [6, _("Nobody")], [5, _("Group Member")],  [3, _("Logged-in User")],
     [2, _("Anonymous")],
   ];
   foreach ($labels as $vl)
-    {
-      $v = $vl[0]; $l = $vl[1];
-      $sel = '';
-      if ($value == $v)
-        $sel = ' selected="selected"';
-      print "<option value='$v'$sel>$l</option>\n";
-    }
+    print form_option ($vl[0], $value, $vl[1]);
   print "</select>\n";
 
   if (!$value && $level == "group" && $event == 1)
@@ -752,12 +711,7 @@ function html_select_typedir_box ($input_name, $current_value)
       "savannah-nongnu" => "Savannah non-GNU",
     ] as $dir => $title
   )
-    {
-      $sel = '';
-      if ($current_value == $dir)
-        $sel = ' selected="selected"';
-      print "<option value='$dir'$sel>$title</option>\n";
-    }
+    print form_option ($dir, $current_value, $title);
   print "</select> [BACKEND SPECIFIC]\n";
   print "<p><span class='smaller'>Basic directory will make the backend\n"
     . "using DownloadMakeArea(), defined in Savannah::Download;<br />\n"
@@ -777,20 +731,16 @@ function html_select_theme_box ($input_name = "user_theme", $current = 0)
   print '<select title="' . _("Website theme") . "\" name=\"$input_name\">\n";
   $theme_option = function ($theme, $label = null) use ($current)
   {
-    print "  <option value=\"$theme\"";
-    if ($theme == $current)
-      print ' selected="selected"';
-    print ">";
     if (empty ($label))
-      print $theme;
+      $label = $theme;
     else
-      print "&gt; $label";
+      $label = "&gt; $label";
     if ($theme == $GLOBALS['sys_themedefault'])
-      print ' ' . _("(default)");
-    print "</option>\n";
+      $label .= ' ' . _("(default)");
+    print form_option ($theme, $current, $label);
   };
   # Fixed themes.
-  foreach (theme_list() as $theme)
+  foreach (theme_list () as $theme)
     $theme_option ($theme);
   # Two special themes.
   $theme_option ("rotate", _("Pick theme alphabetically every day"));
@@ -903,7 +853,7 @@ function site_admin_header ($params)
   html_header ($params);
 }
 
-function site_admin_footer ($params)
+function site_admin_footer ($params = [])
 {
   html_footer ($params);
 }
