@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -42,29 +42,19 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 $file_dir = dirname (__FILE__);
-
-require_once ("$file_dir/error.php");
-# Autoconf-based:
-require_once ("$file_dir/ac_config.php");
-
-# Database abstraction.
-require_once ("$file_dir/database.php");
-# Security library.
-require_once ("$file_dir/session.php");
-# User functions like get_name, logged_in, etc.
-require_once ("$file_dir/user.php");
-# Title, helper to find out appropriate info depending on the context,
-# like title.
-require_once ("$file_dir/context.php");
-require_once ("$file_dir/exit.php");
-require_once ("$file_dir/utils.php");
+$inc = [
+  'error', 'ac_config', 'database', 'session', 'user', 'context', 'exit',
+  'utils'
+];
+foreach ($inc as $i)
+  require_once ("$file_dir/$i.php");
+unset ($inc);
 
 # Default values, so they cannot be found undefined in the code.
 $sys_name = "Change-This-Site-Name-with-\$sys_name";
 $sys_logo_name = 'floating.png';
 $stone_age_menu = false;
 $sys_spamcheck_spamassassin = false;
-$sys_use_krb5 = false;
 $sys_upload_max = 512;
 
 $sys_dbhost = 'localhost';
@@ -96,8 +86,6 @@ $sys_gpg_name = "gpg";
 $sys_debug_on = false;
 # Prevent redirections like sv.gnu.org -> sv.nongnu.org.
 $sys_debug_nobasehost = false;
-# Prevent form duplicate checks which are a PITA during debugging.
-$sys_debug_noformcheck = false;
 # Log which queries are used the most, using XCache variables.
 $sys_debug_sqlprofiler = false;
 
@@ -133,6 +121,10 @@ if (!empty ($sys_conf_file))
 
 if (empty ($sys_file_domain))
   $sys_file_domain = $sys_default_domain;
+if (empty ($sys_dbport))
+  $sys_dbport = null;
+if (empty ($sys_dbsocket))
+  $sys_dbsocket = null;
 
 # Detect where we are, unless it's explicitely specified in the
 # configuration file:
@@ -177,11 +169,6 @@ $php_self = utils_specialchars ($_SERVER['PHP_SELF']);
 utils_set_csp_headers ();
 utils_update_decimal_separator ();
 
-# Stop a failed assertion.  We don't use much assertions though,
-# because you can't provide additional feedback for debugging (like
-# the value of the invalid variable). Check util_die () instead.
-assert_options (ASSERT_BAIL, 1);
-
 # Source (require) all specific include files of a module from
 # the include area (all include files of a module are arranged
 # in subdirectories in the includes area, so this routine sources
@@ -211,7 +198,7 @@ function require_directory ($module)
   $GLOBALS["directory_{$module}_is_loaded"] = 1;
 }
 
-$tracker_list = ['bugs', 'patch', 'task', 'cookbook', 'support'];
+$tracker_list = utils_get_tracker_list ();
 
 function get_module_include_dir (
   $script_name, $true_artifact = 0, $true_dir = 0
@@ -238,9 +225,12 @@ function get_module_include_dir (
   return $guess;
 }
 
-# Start user session.
-# Connect to db.
-db_connect ();
+$db_err = db_connect ();
+if ($db_err !== null && empty ($testconfig_php))
+  {
+    print $db_err;
+    exit;
+  }
 
 # sys_unix_group_name is maybe defined
 # in this case, we want sys_group_id.
@@ -304,17 +294,22 @@ extract (sane_import ('request',
 if (!defined ('ARTIFACT'))
    define ('ARTIFACT', get_module_include_dir ($_SERVER['SCRIPT_NAME'], 1));
 
-# If we are on an artifact index page and we have only one argument which is
-# a numeric number, we suppose it is an item_id.
-# Maybe it was a link shortcut like
-# blabla.org/task/?nnnn (blabla.org/task/?#nnnn cannot work because # is
-# not sent by the browser as it's a tag for html anchors).
-# Necessary to determine group_id.
-if (
-  in_array (ARTIFACT, $tracker_list) && !empty ($_SERVER['QUERY_STRING'])
-  && ctype_digit (strval ($_SERVER['QUERY_STRING']))
-)
-  $item_id = $_SERVER['QUERY_STRING'];
+function init_extract_item_id ($tracker_list)
+{
+  global $item_id, $have_item_id;
+  # If we are on an artifact index page and we have an argument which is
+  # a numeric number, we suppose it is an item_id.
+  if (!in_array (ARTIFACT, $tracker_list))
+    return;
+  if (empty ($_SERVER['QUERY_STRING']))
+    return;
+  $qs = strval ($_SERVER['QUERY_STRING']);
+  if (ctype_digit ($qs))
+    $item_id = $qs;
+  $have_item_id = !empty ($item_id);
+}
+
+init_extract_item_id ($tracker_list);
 
 if (!empty ($item_id) && !is_numeric ($item_id))
   util_die (_("Invalid item ID."));
@@ -411,17 +406,9 @@ function init_group_vars ()
 
 function init_check_group_status ($status)
 {
-  if ($status == 'I' || $status == 'A')
+  if ($status == 'A' || user_is_super_user ())
     return;
-  $su = user_is_super_user ();
-  if ($status == 'M') # Maintenance mode, OK for superusers.
-    {
-      if (!$su)
-        exit_error (_("This group is in maintenance mode"));
-      fb (_("Note: this group is in maintenance mode"));
-    }
-  elseif (!$su) # Other cases, no access granted.
-    exit_error (_("This group is not in active state"));
+  exit_permission_denied ();
 }
 
 # Make sure we are on the correct site.
