@@ -6,7 +6,7 @@
 # Copyright (C) 2002-2006 Tobias Toedter <t.toedter--gmx.net>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -188,8 +188,8 @@ function markup_info ($level)
   $text = $info[$level][1];
 
   $img = html_image ('misc/edit.png', ['class' => 'icon']);
-  return '<span class="smaller">('
-    . utils_help ("$link_head$img$string$link_tail", $text) . ')</span>';
+  return '<span class="smaller">'
+    . utils_help ("$link_head$img$string$link_tail", $text) . '</span>';
 }
 
 # Convert special markup characters in the input text to HTML.
