@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -504,8 +504,8 @@ function show_post_form (
     . "wrap='SOFT'></textarea>\n</td></tr>\n"
     . "<tr><td colspan='2' align='middle'>\n<span class='warn'>"
     . "HTML tags will display in your post as text</span>\n<br />\n"
-    . '<input type="submit" name="submit" value="' . _("Post Comment")
-    . "\" />\n</td></tr></table>\n</form>\n</center>\n";
+    . form_input ('submit', 'submit', _("Post Comment"))
+    . "\n</td></tr></table>\n</form>\n</center>\n";
 }
 
 # Take a message id and recurse, deleting all followups.
