@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -48,6 +48,29 @@
 # 1 - approved for forge front page (obsolete, should be 0)
 # 0 - approved for group main page
 
+function news_format_atom_entry ($row)
+{
+  global $sys_default_domain, $sys_home;
+  $id = "https://$sys_default_domain{$sys_home}news/?id={$row['id']}";
+  $title = $row['summary'];
+  $updated = date ('c', $row['date']);
+  $author = $row['realname'];
+  $text = str_replace ('&nbsp;', ' ', markup_full (trim ($row['details'])));
+  return "
+  <entry>
+    <id>$id</id>
+    <link rel='alternate' href='$id'/>
+    <title>$title</title>
+    <updated>$updated</updated>
+    <author>
+      <name>$author</name>
+    </author>
+    <content type='xhtml' xml:base='$id'>
+      <div xmlns='http://www.w3.org/1999/xhtml'>$text</div>
+    </content>
+  </entry>\n";
+}
+
 function news_fetch_item ($news_id)
 {
   $result = db_execute ("SELECT * from news_bytes WHERE id = ?", [$news_id]);
@@ -60,15 +83,14 @@ function news_fetch_item ($news_id)
   return $row;
 }
 
-function news_show_news_item ($news_id)
+function news_show_news_item ($item, $level = 2)
 {
-  $item = news_fetch_item ($news_id);
   if (empty ($item))
     {
       fb (_("No news item found"), 1);
       return;
     }
-  print "<h2>" . $item['summary'] . "</h2>\n";
+  print html_h ($level, $item['summary']);
   print "<p><i>";
   # TRANSLATORS: the first argument is user's name, the second
   # argument is date.
@@ -97,7 +119,7 @@ function news_print_news_list ($result, $group_id, $group)
   while ($row = db_fetch_array ($result))
     {
       print "<li>";
-      print "<a href=\"$php_self?approve=1&amp;group=$group&amp;";
+      print "<a href=\"$php_self?show=1&amp;group=$group&amp;";
       print "id={$row['id']}\">{$row['summary']}</a></li>\n";
     }
   print "</ul>\n";
@@ -106,7 +128,7 @@ function news_print_news_list ($result, $group_id, $group)
 function news_list_news_to_manage ($group_id, $group)
 {
   $news_sets = [
-    '5' => [_("News wating for approval"), _("No news wating for approval")],
+    '5' => [_("News waiting for approval"), _("No news waiting for approval")],
     '4' => [_("Recently deleted news"), _("No recently deleted news")],
     '0, 1' => [_("Recently approved news"), _("No recently approved news")]
   ];
@@ -115,10 +137,10 @@ function news_list_news_to_manage ($group_id, $group)
       $result = news_query_news ($group_id, $set);
       if (!db_numrows ($result))
         {
-          print "<h2>{$t[1]}</h2>\n";
+          print html_h (2, $t[1]);
           continue;
         }
-      print "<h2>{$t[0]}</h2>\n";
+      print html_h (2, $t[0]);
       news_print_news_list ($result, $group_id, $group);
     }
 }
@@ -224,9 +246,9 @@ function news_print_approve_form ($row)
   );
   news_print_status_selector ($row['is_approved']);
   news_print_news_fields ($row['summary'], $row['details']);
-  print '<p><input type="submit" name="submit" value="'
-    . _("Submit") . "\" /></p>\n</form>\n";
-  print '<h2>' . _("Preview") . "</h2>\n" . markup_full ($row['details']);
+  print '<p>' . form_submit (_("Submit"), "submit") . "</p>\n</form>\n";
+  print html_h (2, _("Preview"));
+  news_show_news_item ($row, 3);
 }
 
 function news_new_subbox ($row)
