@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev <ineiev@gnu.org>
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev <ineiev@gnu.org>
 #
 # This file is part of Savane.
 #
@@ -336,9 +336,7 @@ function people_draw_skill_box ($result, $job_id = false, $group_id = false)
     $infix = 'job';
 
   $title_arr = [_('Skill'), _('Level'), _('Experience'), _('Action')];
-
-  $rows = db_numrows ($result);
-  if ($rows < 1)
+  if (!db_numrows ($result))
     {
       print html_build_list_table_top ($title_arr);
       print "\n<tr><td colspan='4'><strong>"
@@ -346,52 +344,44 @@ function people_draw_skill_box ($result, $job_id = false, $group_id = false)
         . "</strong></td></tr>\n</table>\n";
       print db_error ();
     }
-  for ($i = 0; $i < $rows; $i++)
+  for ($i = 0; $row = db_fetch_array ($result); $i++)
     {
       print form_tag ();
       print html_build_list_table_top ($title_arr);
+      $hid = ['group_id' => $group_id];
+      $k = "{$infix}_inventory_id";
+      $hid[$k] = $row[$k];
+      $k = "{$infix}_id";
+      $hid[$k] = $row[$k];
       print "<tr class='" . utils_altrow ($i)
-        . "'>\n<td><input type='hidden' name='{$infix}_inventory_id' "
-        . 'value="' . db_result ($result, $i, $infix . '_inventory_id')
-        . "\" />\n<input type='hidden' name='{$infix}_id' "
-        . "value='" . db_result ($result, $i, $infix . '_id')
-        . "' />\n<input type='hidden' name='group_id' "
-        . "value='$group_id' />\n<span class='smaller'>"
-        . db_result ($result, $i, 'skill_name')
+        . "'>\n<td>" . form_hidden ($hid)
+        . "<span class='smaller'>{$row['skill_name']}"
         . "</span></td>\n<td><span class='smaller'>"
-        . people_skill_level_box (
-            'skill_level_id', db_result ($result, $i, 'skill_level_id')
-          )
+        . people_skill_level_box ('skill_level_id', $row['skill_level_id'])
         . "</span></td>\n<td><span class='smaller'>"
-        . people_skill_year_box (
-           'skill_year_id', db_result ($result, $i, 'skill_year_id')
-          )
+        . people_skill_year_box ('skill_year_id', $row['skill_year_id'])
         . "</span></td>\n<td nowrap><span class='smaller'>"
-        . "<input type='submit' name='update_{$infix}_inventory' "
-        . "value='" . _("Update") . "'> &nbsp;\n"
-        . "<input type='submit' name='delete_from_{$infix}_inventory' "
-        . "value='" . _("Delete") . "'></span></td>\n</tr></table>\n"
+        . form_submit (_("Update"), "update_{$infix}_inventory") . "&nbsp;\n"
+        . form_submit (_("Delete"), "delete_from_{$infix}_inventory")
+        . "</span></td>\n</tr></table>\n"
         . "</form>\n";
     }
-
-  print "\n<h3>" . _("Add a New Skill") . "</h3>\n";
-
+  print html_h (3, _("Add a New Skill"));
   print form_tag ();
   print html_build_list_table_top ($title_arr);
   print "\n<tr class='" . utils_altrow (0) . "'>\n<td>";
 
   if ($job_id !== false)
-    print "<input type='hidden' name='{$infix}_id' value='$job_id' />"
-      . "<input type='hidden' name='group_id' value='$group_id' />\n";
+    print form_hidden (["{$infix}_id" => $job_id, 'group_id' => $group_id]);
 
   print '<span class="smaller">' . people_skill_box ('skill_id')
     . "</span></td>\n<td><span class='smaller'>"
     . people_skill_level_box ('skill_level_id')
     . "</span></td>\n<td><span class='smaller'>"
     . people_skill_year_box ('skill_year_id')
-    . "</span></td>\n<td nowrap><span class='smaller'><input type='submit' "
-    . "name='add_to_{$infix}_inventory'\n value='" . _("Add Skill")
-    . "'></span></td>\n</tr></table>\n</form>\n";
+    . "</span></td>\n<td nowrap><span class='smaller'>"
+    . form_submit (_("Add Skill"), "add_to_{$infix}_inventory")
+    . "</span></td>\n</tr></table>\n</form>\n";
 }
 
 function people_edit_job_inventory ($job_id, $group_id)
@@ -511,7 +501,7 @@ function people_show_jobs ($categories, $types)
        ON j.category_id = c.category_id)
       JOIN groups ON j.group_id = groups.group_id
     WHERE groups.is_public = 1 AND j.status_id = 1
-    ${cat_ids} ${type_ids} ORDER BY date DESC",
+    {$cat_ids} {$type_ids} ORDER BY date DESC",
     $sql_args
   );
   return people_show_job_list ($result);
@@ -597,9 +587,9 @@ function people_add_to_skill_inventory (
     SELECT * FROM people_skill_inventory WHERE user_id = ? AND skill_id = ?",
     [user_getid (), $skill_id]
   );
-  if (db_numrows ($result) > 0)
+  if (db_numrows ($result))
     {
-      fb (_('ERROR - skill already in your inventory'));
+      fb (_('ERROR - skill already in your inventory'), 1);
       return;
     }
   $result = db_autoexecute ('people_skill_inventory',
@@ -609,7 +599,7 @@ function people_add_to_skill_inventory (
     ],
     DB_AUTOQUERY_INSERT
   );
-  if ($result && db_affected_rows ($result) > 0)
+  if ($result && db_affected_rows ($result))
     {
       fb (_('Added to skill inventory'));
       return;
