@@ -1,11 +1,11 @@
 <?php
-# Group administration.
+# Group administrative info.
 # 
 # Copyright (C) 1999, 2000 The SourceForge Crew
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -41,41 +41,31 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
-# Nicely html-formatted output of this group's audit trail
-
+# Output group history.
 function show_grouphistory ($group_id)
 {
   # Show the group_history rows that are relevant to this group_id.
-  $result = group_get_history($group_id);
-  $rows = db_numrows($result);
+  $result = group_get_history ($group_id);
 
-  if ($rows <= 0)
+  print html_h (2, _("Group Change History")) . "<p>";
+  if (!db_numrows ($result))
     {
-      print '<h2>'
-        . _("No Changes Have Been Made to This Group") . "</h2>\n";
+      print _("No changes have been made to this group") . "</p>\n";
       return;
     }
-  print "\n<h2>" . _("Group Change History") . "</h2>\n<p>";
-  $title_arr = [];
-  $title_arr[] = _("Field");
-  $title_arr[] = _("Value");
-  $title_arr[] = _("Date");
-  $title_arr[] = _("Author");
-
+  $title_arr = [_("Field"), _("Value"), _("Date"), _("Author")];
   print html_build_list_table_top ($title_arr);
-
-  for ($i = 0; $i < $rows; $i++)
+  $i = 0;
+  while ($row = db_fetch_array ($result))
     {
-      $field = db_result ($result, $i, 'field_name');
-      print "\n\t<tr class=\"" . html_get_alt_row_color ($i)
+      $field = $row['field_name'];
+      print "\n\t<tr class=\"" . html_get_alt_row_color ($i++)
         . "\"><td>$field</td>\n<td>";
-      $str = db_result ($result, $i, 'old_value');
+      $str = $row['old_value'];
       if ($field == 'removed user')
         $str = user_getname ($str);
-      print "$str</td>\n<td>"
-        . utils_format_date (db_result ($result, $i, 'date')) . "</td>\n<td>"
-        . db_result ($result, $i, 'user_name') . "</td></tr>\n";
+      print "$str</td>\n<td>" . utils_format_date ($row['date']) . "</td>\n<td>"
+        . $row['user_name'] . "</td></tr>\n";
     }
   print "\n</table>\n";
 }
@@ -83,19 +73,15 @@ function show_grouphistory ($group_id)
 function project_admin_registration_info ($row_grp)
 {
   $res_admin = db_execute ("
-    SELECT
-      user.user_id AS user_id, user.user_name AS user_name,
-      user.realname AS realname, user.email AS email
-    FROM user, user_group
-    WHERE user_group.user_id = user.user_id
-    AND user_group.group_id = ? AND
-    user_group.admin_flags = 'A'",
+    SELECT u.user_id, u.user_name, u.realname, u.email
+    FROM user u, user_group ug
+    WHERE ug.user_id = u.user_id AND ug.group_id = ? AND ug.admin_flags = 'A'",
     [$row_grp['group_id']]
   );
 
   $spp = "<p><span class='preinput'>'";
   $spbr = "</span><br />\n ";
-  print $spp . _("Group Admins") . ":$spbr";
+  print $spp . no_i18n ("Group Admins") . ":$spbr";
   while ($row_admin = db_fetch_array ($res_admin))
     {
       print "<a href=\"{$GLOBALS['sys_home']}"
@@ -103,15 +89,16 @@ function project_admin_registration_info ($row_grp)
         . "&lt;{$row_admin['email']}&gt;</a> ; ";
     }
   $spp = "</p>\n$spp";
-  print $spp . _("Registration Date") . ":$spbr"
+  print $spp . no_i18n ("Registration Date") . ":$spbr"
     . utils_format_date ($row_grp['register_time']);
-  print $spp . _("System Group Name:") . $spbr . $row_grp['unix_group_name'];
-  print $spp . _("Submitted Description:") . $spbr
+  print $spp . no_i18n ("System Group Name:")
+    . $spbr . $row_grp['unix_group_name'];
+  print $spp . no_i18n ("Submitted Description:") . $spbr
     . markup_full($row_grp['register_purpose']);
-  print $spp . _("Required software:") . $spbr
+  print $spp . no_i18n ("Required software:") . $spbr
     . markup_full($row_grp['required_software']);
-  print $spp . _("Other comments:") . $spbr
-    . markup_full($row_grp['other_comments']);
+  print $spp . no_i18n ("Other comments:") . $spbr
+    . markup_full ($row_grp['other_comments']);
   print "</p>\n<p>";
   print utils_registration_history ($row_grp['unix_group_name']);
   print "</p>\n";
