@@ -7,7 +7,7 @@
 # Copyright (C) 2008 Nicodemo Alvaro
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -117,10 +117,7 @@ function search_list_tracker_options ($gid, $type_of_search, $is_small)
          $text = sprintf ($msg[1], $group_realname);
        if (!$text)
          continue;
-       $sel_attr = '';
-       if ($type_of_search == $key)
-          $sel_attr = ' selected="selected"';
-       $sel .= "<option value='$key' $sel_attr>$text</option>\n";
+       $sel .= form_option ($key, $type_of_search, $text);
      }
   return $sel;
 }
@@ -135,7 +132,8 @@ function search_list_tracker_options ($gid, $type_of_search, $is_small)
 function search_box ($searched_words = '', $scope = null, $size = 15)
 {
   global $words, $group_id, $exact, $type_of_search, $type, $max_rows;
-  global $only_group_id;
+  global $only_group_id, $sys_home;
+  $submit = form_input ("submit", 'search', _("Search"));
 
   if (!is_scalar ($searched_words))
     $searched_words = '';
@@ -165,16 +163,10 @@ function search_box ($searched_words = '', $scope = null, $size = 15)
   if ($words == "%%%")
     $words = "*";
 
-  $ret =
-    "<form action=\"{$GLOBALS['sys_home']}search/#options\" method='get'>\n";
-
+  $ret = form_header ("{$sys_home}search/#options", 'get');
   if (!$is_small)
-    {
-      # If it's a big form, we want the submit button on the right.
-      $ret .= '<span class="boxoptionssubmit">'
-        . '<input type="submit" name="Search" value="' . _("Search")
-        . "\" />&nbsp;</span>\n";
-    }
+    # If it's a big form, we want the submit button on the right.
+    $ret .= "<span class='boxoptionssubmit'>$submit&nbsp;</span>\n";
 
   $title = false;
   if ($is_small)
@@ -218,11 +210,9 @@ function search_box ($searched_words = '', $scope = null, $size = 15)
 
   if ($is_small)
     # If it's a small form, the submit button has not already been inserted.
-    $ret .= "<br />\n<input type='submit' "
-      . "name='Search' value=\"" . _("Search") . "\" />&nbsp;\n";
+    return $ret . form_hidden (['exact' => 1]) . "<br />\n"
+      . "$submit&nbsp;\n</form>\n";
 
-  if ($is_small)
-    return $ret . form_hidden (['exact' => 1]) . "</form>\n";
   $ret .= "<br />\n&nbsp;";
   $ret .= form_radio ('exact', 0,
     ['checked' => !$exact, 'label' => _("with at least one of the words")]
@@ -452,27 +442,23 @@ function search_run (
       $sql .= " AND $kw_sql ORDER BY user_name ";
       $sql_params = array_merge($sql_params, $kw_sql_params);
     }
-  elseif (
-    !in_array ($tos, ['bugs', 'support', 'patch', 'cookbook', 'task'])
-  )
+  elseif (!in_array ($tos, utils_get_tracker_list ()))
     exit_error (_("Invalid search."));
   else
     {
       $sql = "
         SELECT
-          $tos.bug_id, $tos.summary, $tos.date, $tos.privacy,
-          $tos.submitted_by, user.user_name, $tos.group_id
-        FROM $tos, user, groups
+          t.bug_id, t.summary, t.date, t.privacy,
+          t.submitted_by, user.user_name, t.group_id
+        FROM $tos t, user, groups
         WHERE
-          user.user_id = $tos.submitted_by
-          AND groups.group_id = $tos.group_id ";
+          user.user_id = t.submitted_by AND groups.group_id = t.group_id ";
       if ($tos != 'cookbook')
         # As of 2021, we have no use_cookbook in the groups table.
         $sql .= "AND groups.use_$tos = 1";
 
       list ($kw_sql, $kw_sql_params) = search_keywords_in_fields (
-        $arr_keywords, [ "$tos.details", "$tos.summary", "$tos.bug_id"],
-        $and_or
+        $arr_keywords, [ "t.details", "t.summary", "t.bug_id"], $and_or
       );
 
       $sql .= " AND $kw_sql ";
@@ -482,12 +468,12 @@ function search_run (
         {
           # $search_without_group_id can be set to avoid restricting search
           # to a group even if group_id is set.
-          $sql .= " AND $tos.group_id = ? ";
+          $sql .= " AND t.group_id = ? ";
           $sql_params[] = $only_group_id;
         }
 
-      $sql .= " AND $tos.spamscore < 5
-        GROUP BY bug_id, summary, date, user_name ORDER BY $tos.date DESC ";
+      $sql .= " AND t.spamscore < 5
+        GROUP BY bug_id, summary, date, user_name ORDER BY t.date DESC ";
     }
 
   $sql .= " LIMIT ?, ?";
@@ -513,14 +499,11 @@ function search_exact ($keywords)
     WHERE
       type = type_id AND group_name $ph AND status = 'A' AND is_public = '1'";
   $result = db_execute ($sql, $arr_keywords);
-  $num_rows = db_numrows ($result);
-
-  if ($num_rows != 1)
+  if (db_numrows ($result) != 1)
     return;
-  print "<h2>";
   # TRANSLATORS: this is a title for search results when exactly one item is found.
-  print _("Unique group search result");
-  print "</h2>\n<p>";
+  print html_h (2, _("Unique group search result"));
+  print "<p>";
   printf (_("Search string was: %s."),
     '<b>' . utils_specialchars ($keywords) . '</b>'
   );
