@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -55,7 +55,7 @@ function sendmail_signature ()
     . "\nhttps://$sys_default_domain$sys_home\n";
 }
 
-function sendmail_format_body (&$message, &$context)
+function sendmail_format_body (&$message, $context)
 {
   if (!empty ($context['skip_format_body']))
     return;
@@ -72,16 +72,28 @@ function sendmail_format_body (&$message, &$context)
   $message['body'] = str_replace ("\r\n", "\n", $body);
 }
 
+function sendmail_x_savane_server_header ()
+{
+  $ret = '';
+  if (!empty ($GLOBALS['int_delayspamcheck']))
+    return $ret;
+  foreach (['NAME' => '', 'PORT' => ':', 'ADDR' => ' '] as $key => $sep)
+    {
+      $val = '';
+      $key = "SERVER_$key";
+      if (!empty ($_SERVER[$key]))
+        $val = trim ($_SERVER[$key]);
+      if ($val !== '')
+        $ret .= "$sep$val";
+    }
+  return "X-Savane-Server: $ret\n";
+}
+
 function sendmail_savane_headers ($context)
 {
-  global $int_delayspamcheck;
-
-  $ret = '';
   # Add a signature for the server (not if delayed, because it will be added
   # we the mail will be actually sent).
-  if (empty ($int_delayspamcheck))
-    $ret .= "X-Savane-Server: {$_SERVER['SERVER_NAME']}:"
-       . "{$_SERVER['SERVER_PORT']} [{$_SERVER['SERVER_ADDR']}]\n";
+  $ret = sendmail_x_savane_server_header ();
 
   # Necessary for proper utf-8 support.
   $ret .= "MIME-Version: 1.0\nContent-Type: text/plain;charset=UTF-8\n";
@@ -108,9 +120,8 @@ function sendmail_extract_comment_id (&$context)
 
 function sendmail_create_msgid ()
 {
-  utils_srand ();
   return date ("Ymd-His", time ()) . ".sv" . user_getid () . "."
-    . mt_rand (0, 100000) . "@" . $_SERVER["HTTP_HOST"];
+    . utils_mt_rand () . "@" . $_SERVER["HTTP_HOST"];
 }
 
 function sendmail_msgid_headers ($context)
@@ -120,11 +131,15 @@ function sendmail_msgid_headers ($context)
   if (empty ($context['tracker']) || empty ($context['item']))
     return $headers;
   $tracker = $context['tracker']; $item_id = $context['item'];
-  $headers .= "References: " . trackers_get_msgid ($tracker, $item_id) . "\n";
-  $headers .= "In-Reply-To: "
-    . trackers_get_msgid ($tracker, $item_id, true) . "\n";
+  $refs = trackers_get_msgid ($tracker, $item_id);
+  if (count ($refs))
+    {
+      $headers .= "References: " . join (' ', $refs) . "\n";
+      # This code assumes that it's the latest message that's
+      # replied to, which may be wrong, actually.
+      $headers .= "In-Reply-To: {$refs[0]}\n";
+    }
   trackers_register_msgid ($msg_id, $tracker, $item_id);
-
   return $headers;
 }
 
@@ -167,9 +182,13 @@ function sendmail_explode_addr_list ($to)
   return $ret;
 }
 
-# If $from is a login name, write a nice From: field.
+# If $addresses['from'] is a login name, replace it with a nice From: field.
+# if no $addresses['from'] is empty, set it to default.
 function sendmail_format_from (&$addresses)
 {
+  global $sys_mail_replyto, $sys_mail_domain;
+  if (empty ($addresses['from']))
+    $addresses['from'] = "$sys_mail_replyto@$sys_mail_domain";
   $uid = user_getid ($addresses['from']);
   if (!user_exists ($uid))
     return;
@@ -237,7 +256,7 @@ function sendmail_send_to_list ($user_name, $user_subj, &$message, &$context)
         {
           $ret .= mail ($u_name, $u_subj, $body, $headers);
           # TRANSLATORS: the argument is a comma-separated list of recipients.
-          fb (sprintf (_("Mail sent to %s"), $u_name));
+          fb (sprintf (_("Mail sent to %s"), join (', ', $user_name[$v])));
           continue;
         }
       sendmail_spamcheck_queue ($context, $u_name, $u_subj, $message);
@@ -333,25 +352,43 @@ function sendmail_addr_is_account_name ($a)
   return !(sendmail_addr_is_uid ($a) || sendmail_addr_is_email ($a));
 }
 
+# Normalize account names in the address lists to lower case.
+# Return extracted set of account names.
+function sendmail_extract_account_names (&$to, &$exclude)
+{
+  $lowered_names = [];
+  foreach ([$to, $exclude] as $arr)
+    {
+      $names = [];
+      foreach ($arr as $k => $ignored)
+        if (sendmail_addr_is_account_name ($k))
+          {
+            $names[$k] = true;
+            $lowered_names[strtolower ($k)] = true;
+          }
+       foreach ($names as $k => $ignored)
+         {
+           unset ($arr[$k]);
+           $arr[strtolower ($k)] = true;
+         }
+    }
+  return array_keys ($lowered_names);
+}
+
 function sendmail_reduce_names_to_uids ($to, $exclude)
 {
-  $names = [];
-  foreach ([$to, $exclude] as $arr)
-    foreach ($arr as $k => $ignored)
-      if (sendmail_addr_is_account_name ($k))
-        $names[$k] = true;
+   $names = sendmail_extract_account_names ($to, $exclude);
    if (empty ($names))
      return [$to, $exclude];
-   $names = array_keys ($names);
    $ph = utils_in_placeholders ($names);
    $res = db_execute (
      "SELECT user_id, user_name FROM user WHERE user_name $ph", $names
    );
    while ($row = db_fetch_array ($res))
      foreach (['to', 'exclude'] as $a)
-       if (!empty ($$a[$row['user_name']]))
+       if (!empty ($$a[strtolower ($row['user_name'])]))
          {
-           unset ($$a[$row['user_name']]);
+           unset ($$a[strtolower ($row['user_name'])]);
            $$a[$row['user_id']] = true;
          }
    return [$to, $exclude];
@@ -466,7 +503,7 @@ function sendmail_make_subjects ($to, $message, $context)
   $v = join (', ', $recipients);
   $emails[$v] = $recipients;
   $user_subj[$v] = $subject;
-  return [$user_subj, $emails];
+  return [array_map ("sendmail_encode_header", $user_subj), $emails];
 }
 
 function sendmail_encrypt_message ($uid, &$msg)
@@ -480,10 +517,17 @@ function sendmail_encrypt_message ($uid, &$msg)
   return [$encrypted === '', $gpg_error];
 }
 
-# Send the mail.
-# Every mail sent by Savannah should be using that function which
-# works like mail ().
-# $to can be a comma-separated list; $from and $to can contain user names.
+# Send the mail. Every mail sent by Savannah should be using this function.
+#
+# $addresses['to'] is comma-separated list; $addresses['from']
+# and $addresses['to'] may contain user names instead of emails.
+#
+# $message contains a list of headers (['headers']), the subject
+# (['subject']), the body (['body']).
+#
+# $context may contain additional data like relevant unix_group_name
+# (['group']), artifact (['tracker']), item and comment IDs (['item']),
+# additional flags (['skip_format_body']).
 function sendmail_mail ($addresses, $message, $context = [])
 {
   sendmail_check_displayspamcheck ($context);
@@ -494,12 +538,8 @@ function sendmail_mail ($addresses, $message, $context = [])
   list ($recipients, $subj_pfx, $emails) =
     sendmail_compile_custom_subject_lines ($to, $context);
   sendmail_debug_override_address ($recipients, $subj_pfx, $message, $emails);
-  list ($user_subj, $emails) =
-    sendmail_make_subjects ($to, $message, $context);
-
-  return sendmail_send_to_list (
-    $emails, $user_subj, $message, $context
-  );
+  list ($subj, $emails) = sendmail_make_subjects ($to, $message, $context);
+  return sendmail_send_to_list ($emails, $subj, $message, $context);
 }
 
 # Encode each recipient separately and separate them using commas.
@@ -553,34 +593,28 @@ function sendmail_form_message ($form_action, $user_id, $cc_me = true)
     # TRANSLATORS: the argument is user's name.
     sprintf (_("Send a message to %s"), user_getrealname ($user_id))
   );
-  print '<p class="warn">'
-    . _("If you are writing for help, did you read the\nproject documentation "
-        . "first? Try to provide any potentially useful information\n"
-        . "you can think of.")
-     . "</p>\n";
-
   $pre = '<span class="preinput">';
   $post = "</span><br />\n&nbsp;&nbsp;&nbsp;";
   # We do not really bother finding out the realname + email, sendmail_mail ()
   # will do it.
-  print "<form action=\"$form_action\" method='post'>\n"
+  print form_header ($form_action)
     . form_hidden ([
         'touser' => utils_specialchars ($user_id),
         'fromuser' => user_getname ()])
-    . "\n$pre" . _("From:") . "$post"
+    . "\n$pre" . _("From:") . $post
     . user_getrealname (user_getid (), 1) . ' &lt;'
     . user_getemail (user_getid ()) . "&gt;<br />\n"
     . $pre . _("Mailer:") . $post
     . utils_cutstring ($_SERVER['HTTP_USER_AGENT'], "50")
-    . "<br />\n$pre<label for='subject'>" . _("Subject:") . "</label>$post"
-    . '<input type="text" id="subject" name="subject" '
-    . "size='60' maxlength='45' value='' /><br />\n$pre"
-    . form_checkbox ("cc_me", $cc_me, ['value' => 'cc_me'])
-    . " <label for='cc_me'>" . _("Send me a copy") . "</label>$post"
-    . "$pre<label for='body'>" . _("Message:") . "</label>$post"
-    . "<textarea id='body' name='body' rows='20' cols='60'></textarea>\n\n"
-    . '<p align="center"><input type="submit" name="send_mail" value="'
-    . _('Send Message') . "\" /></p>\n</form>\n";
+    . "<br />\n$pre" . html_label ('subject', _("Subject:")) . $post
+    . form_input ('text', "subject", '', "size='60' maxlength='45'")
+    . "<br />\n$pre"
+    . form_checkbox ("cc_me", $cc_me,
+        ['value' => 'cc_me', 'label' => _("Send me a copy")]
+      )
+    . $post . $pre . html_label ('body', _("Message:")) . $post
+    . form_textarea ('body', '', "rows='20' cols='60'") . "\n\n"
+    . form_footer (_('Send Message'), "send_mail");
   print $HTML->box_bottom ();
 }
 
