@@ -6,7 +6,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -81,123 +81,86 @@ require_once (dirname (__FILE__) . '/account.php');
 
 $G_SESSION = $G_USER = [];
 
-function session_login_valid (
-  $form_loginname, $form_pw, $allowpending = 0, $cookie_for_a_year = 0,
-  $crypted_pw = 0, $stay_in_ssl = 1
-)
+function session_stay_in_ssl ()
 {
-  global $session_hash;
+  return isset ($GLOBALS['sys_https_host']);
+}
 
-  if (!$form_loginname || !$form_pw)
+function session_login_is_sane ($name, $password)
+{
+  if ($password === '')
     {
-      fb (_('Missing Password Or User Name'), 1);
+      fb (_('Missing password'), 1);
       return false;
     }
+  if (!empty ($name))
+     return true;
+  $raw_loginname = null;
+  if (array_key_exists ('form_loginname', $_REQUEST))
+    $raw_loginname = $_REQUEST['form_loginname'];
+  if (null === $raw_loginname)
+    fb (_('Missing user name'), 1);
+  else
+    fb (sprintf (_('Invalid user name *%s*'), $raw_loginname), 1);
+  return false;
+}
 
+function session_login_is_disallowed ($status, $allow_pending)
+{
+  $GLOBALS['signal_pending_account'] = 0;
+  if ($status == 'A')
+     return false;
+  if ($status == 'SQD') # Squad account, silently exit.
+    return true;
+  if ($status == 'P')
+    {
+      if ($allow_pending) # If allowpending (in verify.php), then allow.
+        return false;
+      fb (_('Account pending'), 1);
+      # We can't rely on $ffeedback because it's cleared after use.
+      $GLOBALS['signal_pending_account'] = 1;
+    }
+  elseif ($status == 'D' || $status == 'S')
+    fb (_('Account deleted'), 1);
+  else
+    fb (_('Account not active'), 1);
+  return true;
+}
+
+function session_fetch_login_data ($name)
+{
   $resq = db_execute (
     "SELECT user_id, user_pw, status FROM user WHERE user_name = ?",
-    [$form_loginname]
+    [$name]
   );
   if (db_numrows ($resq) < 1)
     {
-      fb (_('Invalid User Name'), 1);
+      fb (sprintf (_('User *%s* not found'), $name), 1);
+      return null;
+    }
+  return db_fetch_array ($resq);
+}
+
+function session_login_valid (
+  $name, $password, $cookie_for_a_year = 0, $allowpending = 0
+)
+{
+  if (!session_login_is_sane ($name, $password))
+    return false;
+
+  $usr = session_fetch_login_data ($name);
+  if ($usr === null)
+    return false;
+
+  if (session_login_is_disallowed ($usr['status'], $allowpending))
+    return false;
+
+  if (!account_validpw ($usr['user_pw'], $password))
+    {
+      fb (_('Invalid password'), 1);
       return false;
     }
-
-  $usr = db_fetch_array ($resq);
-  $GLOBALS['signal_pending_account'] = 0;
-
-  # Check status first:
-  # if allowpending (for verify.php) then allow.
-  if ($allowpending && ($usr['status'] == 'P'))
-    {
-      #1;
-    }
-  else
-    {
-      if ($usr['status'] == 'SQD')
-        {
-          # Squad account, silently exit.
-          return false;
-        }
-      if ($usr['status'] == 'P')
-        {
-          fb (_('Account Pending'), 1);
-          # We can't rely on $ffeedback because it's cleared after use.
-          $GLOBALS['signal_pending_account'] = 1;
-          return false;
-        }
-      if ($usr['status'] == 'D' || $usr['status'] == 'S')
-        {
-          fb (_('Account Deleted'), 1);
-          return false;
-        }
-      if ($usr['status'] != 'A')
-        {
-          fb (_('Account Not Active'), 1);
-          return false;
-        }
-    }
-
-  if ($usr['user_pw'] == '')
-    {
-      # Authentication method: Kerberos
-      # If both user_pw and unix_pw are empty the user might
-      # be able to login if she/he has a Kerberos account.
-      # Update unix_pw and user_pw.
-      if ($GLOBALS['sys_use_krb5'])
-        $ret = krb5_login ($form_loginname, $form_pw);
-
-      if($ret == KRB5_NOTOK)
-        {
-          fb (_("phpkrb5 module failure"), 1);
-          return false;
-        }
-      if($ret == KRB5_BAD_USER)
-        {
-          fb (_("user is not a kerberos principal"), 1);
-          return false;
-        }
-      if($ret == KRB5_BAD_PASSWORD)
-        {
-          fb (_("user is a kerberos principal but passwords do not match"), 1);
-          return false;
-        }
-      $stored_pw = account_encryptpw ($form_pw);
-      db_execute ("UPDATE user SET user_pw = ? WHERE user_id = ?",
-        [$stored_pw, $usr['user_id']]
-      );
-    }
-  elseif ($usr['user_pw'] == 'SSH')
-    {
-      fb (_("This user is known, but cannot be authenticated.\n"
-          . "Please ask site administrators for a password."), 1
-      );
-      return false;
-    }
-  else
-    {
-      # For this authentication method we enable a brother site
-      # login mechanism:
-      # Password is crypted (crypt()) if we are coming from the brother site.
-      # Normally, users shouldn't use this feature
-      # unless they login at brother site one time.
-      if ($crypted_pw)
-        {
-          if (crypt ($usr['user_pw'], $form_pw) != $form_pw)
-            {
-              fb (_('Invalid Password'), 1);
-              return false;
-            }
-        }
-      elseif (!account_validpw ($usr['user_pw'], $form_pw))
-        {
-          fb (_('Invalid Password'), 1);
-          return false;
-        }
-    }
-  # Create a new session.
-  session_set_new ($usr['user_id'], $cookie_for_a_year, $stay_in_ssl);
+  session_set_new ($usr['user_id'], $cookie_for_a_year);
   return true;
 }
 
@@ -288,49 +251,46 @@ function session_setglobals ($user_id)
     $G_USER = db_fetch_array ($result);
 }
 
-function session_set_new ($user_id, $cookie_for_a_year = 0, $stay_in_ssl = 1)
+# Try inserting new session hash in the table.  Return false if the hash already
+# exists; when $tries_left is zero, the error shows up in the browser and
+# terminates the further output (it would be more user-friendly to explain what
+# happened, but the event is unlikely enough to cut the corners).
+function session_try_insert_hash ($user_id, $hash, $tries_left)
+{
+  $vals = ['session_hash' => $hash, 'user_id' => $user_id,
+    'ip_addr' => $_SERVER['REMOTE_ADDR'], 'time' => time (),
+    'stay_in_ssl' => session_stay_in_ssl ()
+  ];
+  $saved = utils_disable_warnings (E_ALL, !$tries_left);
+  db_query_prevent_die ($tries_left);
+  $res = db_autoexecute ('session', $vals);
+  db_query_prevent_die (false);
+  utils_restore_warnings ($saved);
+  return !empty ($res);
+}
+
+function session_generate_hash ($user_id)
+{
+  $tries = 17;
+  while ($tries--)
+    {
+      $hash = random_hash ();
+      if (session_try_insert_hash ($user_id, $hash, $tries))
+        return db_execute (
+          'SELECT * FROM session WHERE session_hash = ?', [$hash]
+        );
+      trigger_error ("duplicate hash $hash detected, tries left: $tries");
+    }
+  return false;
+}
+
+function session_set_new ($user_id, $cookie_for_a_year)
 {
   global $G_SESSION, $session_hash;
-
-  # Concatinate current time, and random seed for MD5 hash
-  # continue until unique hash is generated (SHOULD only be once).
-  do
-    {
-      $pre_hash = time () . rand () . $_SERVER['REMOTE_ADDR'] . microtime ();
-      $session_hash = md5 ($pre_hash);
-      $result = db_execute (
-        "SELECT session_hash FROM session WHERE session_hash = ?",
-        [$session_hash]
-      );
-    }
-  while (db_numrows ($result) > 0); # do
-
-  # Make new session entries into DB.
-  if (!isset ($stay_in_ssl))
-    $stay_in_ssl = 0; # Avoid passing NULL.
-  db_autoexecute ('session',
-    [
-      'session_hash' => $session_hash, 'ip_addr' => $_SERVER['REMOTE_ADDR'],
-      'time' => time(), 'user_id' => $user_id, 'stay_in_ssl' => $stay_in_ssl
-    ],
-    DB_AUTOQUERY_INSERT
-  );
-  # Set global.
-  $res = db_execute (
-    "SELECT * FROM session WHERE session_hash = ?", [$session_hash]
-  );
-  if (db_numrows ($res) > 1)
-    {
-      db_execute (
-        "DELETE FROM session WHERE session_hash = ?", [$session_hash]
-      );
-      exit_error (
-        _("Two people had the same session hash - re-login.\n"
-          . "It should never happen again.")
-      );
-    }
+  $res = session_generate_hash ($user_id);
   $G_SESSION = db_fetch_array ($res);
   session_setglobals ($G_SESSION['user_id']);
+  $session_hash = $G_SESSION['session_hash'];
 
   # If the user specified he wants only one session to be opened at a time,
   # kill all other sessions.
@@ -338,14 +298,14 @@ function session_set_new ($user_id, $cookie_for_a_year = 0, $stay_in_ssl = 1)
     db_execute ("DELETE FROM session WHERE session_hash <> ? AND user_id = ?",
       [$session_hash, $user_id]
     );
-  session_set_new_cookies ($user_id, $cookie_for_a_year, $stay_in_ssl);
+  session_set_new_cookies ($user_id, $cookie_for_a_year);
 }
 
 # Set session cookies.
-function session_set_new_cookies (
-  $user_id, $cookie_for_a_year = 0, $stay_in_ssl = 1
-)
+function session_set_new_cookies ($user_id, $cookie_for_a_year = 0)
 {
+  $stay_in_ssl = session_stay_in_ssl ();
+  # Concatinate current time, and random seed for MD5 hash.
   # Set a non-secure cookie so that Savane automatically redirects to HTTPS.
   if ($stay_in_ssl)
     session_cookie ('redirect_to_https', 1, $cookie_for_a_year, 0);
@@ -369,7 +329,7 @@ function session_set ()
 
   # Here also check for good hash, set if new session is needed.
   extract (sane_import ('cookie',
-    ['hash' =>'session_hash', 'digits' => 'session_uid'])
+    ['hash' => 'session_hash', 'digits' => 'session_uid'])
   );
   if ($session_hash && $session_uid)
     {
