@@ -6,7 +6,7 @@
 # Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -94,7 +94,7 @@ function sitemenu ($params)
 # that need to keep such context.
 function sitemenu_extraurl ($only_with_post = false)
 {
-  global $goup_name, $item_id;
+  global $goup_name, $item_id, $have_item_id;
   # If only_with_post is set, it means that we will return nothing if the
   # page was loaded with a get.
   if ($only_with_post && $_SERVER["REQUEST_METHOD"] != "POST")
@@ -104,8 +104,7 @@ function sitemenu_extraurl ($only_with_post = false)
   if ($_SERVER["REQUEST_METHOD"] == "POST")
     {
       if (!empty($group_name))
-        $extraurl .= "&amp;group=" . utils_urlencode ($group_name)
-          . "&amp;";
+        $extraurl .= "&amp;group=" . utils_urlencode ($group_name) . "&amp;";
       if (!empty ($item_id))
         $extraurl .= "&amp;func=detailitem&amp;item_id="
           . utils_urlencode ($item_id) . "&amp;";
@@ -114,11 +113,10 @@ function sitemenu_extraurl ($only_with_post = false)
   $query_string = '';
   if (!empty ($_SERVER['QUERY_STRING']))
     $query_string = $_SERVER['QUERY_STRING'];
-  if (!empty ($item_id) && ctype_digit (strval ($query_string)))
+  if ($have_item_id && ctype_digit (strval ($query_string)))
     {
       # Short link case (like /bugs/?212).
-      $extraurl .= "&amp;func=detailitem&amp;item_id="
-        . utils_urlencode ($item_id);
+      $extraurl .= "&amp;func=detailitem&amp;item_id=$item_id";
       return $extraurl;
     }
   $extraurl = utils_urlencode ($query_string);
@@ -209,6 +207,36 @@ function menu_thispage ($page_title, $page_toptab = 0, $page_group = 0)
   return sitemenu_thispage ($page_title, $page_toptab, $page_group);
 }
 
+function sitemenu_context_title ($params)
+{
+  $title = context_title ();
+  if ($title === null)
+    $title = '';
+  if (!array_key_exists ('title', $params) || $params['title'] == '')
+    return $title;
+  if ($title !== '')
+    # TRANSLATORS: this string is used to separate context from
+    # further description, like _("Bugs") . _(": ") . $bug_title.
+    $title .= _(": ");
+  return $title . $params['title'];
+}
+
+function sitemenu_bookmark_entry ($page_title)
+{
+  global $HTML, $sys_home;
+  if (!empty ($_POST))
+    return;
+  if (!(user_isloggedin () && user_get_preference ("use_bookmarks")))
+    return;
+  $title =
+    utils_urlencode (sitemenu_context_title (['title' => $page_title]));
+  $HTML->menu_entry ("{$sys_home}my/bookmarks.php?add=1&amp;url="
+    . utils_urlencode ($_SERVER['REQUEST_URI'])
+    . "&amp;title=$title",
+    _("Bookmark It"), 1, _("Add this page to my bookmarks")
+  );
+}
+
 # Page-specific toolbox.
 function sitemenu_thispage ($page_title, $page_toptab = 0, $page_group = 0)
 {
@@ -233,29 +261,12 @@ function sitemenu_thispage ($page_title, $page_toptab = 0, $page_group = 0)
     $extra_name = $GLOBALS['extra_script_name'];
 
   $script_extra = $_SERVER['SCRIPT_NAME'] . $extra_name;
-  $HTML->menu_entry ("$script_extra?reload=1" . $extraurl,
-    _("Clean Reload"), 1,
+  $HTML->menu_entry (
+    "$script_extra?reload=1$extraurl", _("Clean Reload"), 1,
     _("Reload the page without risk of reposting data")
   );
   $HTML->menuhtml_bottom ();
-
-  if (empty ($_POST))
-    {
-      if (user_isloggedin () && user_get_preference ("use_bookmarks"))
-        {
-          $bookmark_title = utils_urlencode (context_title ());
-          if ($page_title)
-            # TRANSLATORS: this string is used to separate context from
-            # further description, like _("Bugs")._(": ").$bug_title.
-            $bookmark_title .= utils_urlencode (_(": ") . $page_title);
-
-            $HTML->menu_entry ("{$sys_home}my/bookmarks.php?add=1&amp;url="
-              . utils_urlencode ($_SERVER['REQUEST_URI']) . '&amp;title='
-              . $bookmark_title,
-              _("Bookmark It"), 1, _("Add this page to my bookmarks")
-            );
-        }
-    }
+  sitemenu_bookmark_entry ($page_title);
 
   # Show related recipes. Maybe not the best way to put it, but in "this page"
   # it makes sense.
@@ -419,23 +430,24 @@ function sitemenu_help ()
   $HTML->menuhtml_bottom ();
 }
 
-function menu_loggedin ($page_title, $page_toptab=0, $page_group=0)
+function menu_loggedin ($page_title, $page_toptab = 0, $page_group = 0)
 {
   return sitemenu_loggedin ($page_title, $page_toptab, $page_group);
 }
 
-function sitemenu_loggedin ($page_title, $page_toptab=0, $page_group=0)
+function sitemenu_loggedin ($page_title, $page_toptab = 0, $page_group = 0)
 {
   global $HTML, $sys_home;
+  $uname = user_getname ();
+  $req_uri = utils_urlencode ($_SERVER['REQUEST_URI']);
   # Show links appropriate for logged in people, like account maintenance, etc.
   if (!user_is_super_user ())
     # TRANSLATORS: the argument is user's name.
-   $HTML->menuhtml_top (sprintf (_("Logged in as %s"), user_getname ()));
+    $HTML->menuhtml_top (sprintf (_("Logged in as %s"), $uname));
   else
     # TRANSLATORS: the argument is user's name.
     $HTML->menuhtml_top ('<span class="warn">'
-      . sprintf (_("%s logged in as superuser"), user_getname())
-      . '</span>'
+      . sprintf (_("%s logged in as superuser"), $uname) . '</span>'
     );
   if (user_can_be_super_user () && !user_is_super_user ())
     $HTML->menu_entry ("{$sys_home}account/su.php?action=login&amp;uri="
@@ -445,22 +457,17 @@ function sitemenu_loggedin ($page_title, $page_toptab=0, $page_group=0)
   if (user_is_super_user ())
     {
       print form_tag (['action' => "{$sys_home}account/impersonate.php"])
-        . '<label for="user_name">' . _("Become this user:")
-        . "</label><br/>\n";
-      print form_hidden (["uri" => utils_urlencode ($_SERVER['REQUEST_URI'])]);
-      print '<input type="text" id="user_name" name="user_name" size=10 '
-        . '/>&nbsp;';
-      print '<input type="submit" name="impersonate" value="'
-        . _("Impersonate") . '" />';
-      print "</form>\n";
+        . html_label ("user_name", _("Become this user:")) . "<br/>\n";
+      print form_hidden (["uri" => $req_uri]);
+      print form_input ('text', "user_name", '', 'size=10') . '&nbsp;';
+      print form_submit (_("Impersonate"), "impersonate") . "</form>\n";
     }
   $HTML->menu_entry ("{$sys_home}my/", _("My Incoming Items"), 1,
     _("What's new for me: new items I should have a look at")
   );
-  $HTML->menu_entry ("{$sys_home}my/items.php",
-                    _("My Items"),
-                    1,
-                    _("Browse my items (submitted by me or assigned to me)"));
+  $HTML->menu_entry ("{$sys_home}my/items.php", _("My Items"), 1,
+    _("Browse my items (submitted by me or assigned to me)")
+  );
   if (user_use_votes ())
     $HTML->menu_entry ("{$sys_home}my/votes.php", _("My Votes"), 1,
       _("Browse items I voted for")
@@ -480,8 +487,7 @@ function sitemenu_loggedin ($page_title, $page_toptab=0, $page_group=0)
 
   if (user_is_super_user ())
     $HTML->menu_entry (
-      "{$sys_home}account/su.php?action=logout&amp;uri="
-      . utils_urlencode ($_SERVER['REQUEST_URI']),
+      "{$sys_home}account/su.php?action=logout&amp;uri=$req_uri",
       _("Logout Superuser"), 1,
       _("End the Superuser session, go back to normal user session")
     );
