@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -150,8 +150,7 @@ function theme_validate ($user_theme)
 function theme_next_random ()
 {
   $theme = theme_list ();
-  utils_srand ();
-  $num = mt_rand (0, count ($theme) - 1);
+  $num = utils_mt_rand (count ($theme) - 1);
   $random_theme = theme_validate ($theme[$num]);
   $expire = time () + 60 * 60 * 24;
   return $random_theme;
