@@ -4,13 +4,10 @@
 # Copyright (C) 1999, 2000 The SourceForge Crew
 # Copyright (C) 2001, 2002 Laurent Julliard, CodeX Team, Xerox
 # Copyright (C) 2000-2006 Mathieu Roy
+# Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
-#
-# Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright (C) 2017, 2018, 2020, 2022, 2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -92,7 +89,7 @@ function trackers_header_admin ($params)
   trackers_header ($params, 'a');
 }
 
-function trackers_footer ($params)
+function trackers_footer ($params = [])
 {
   site_project_footer ($params);
 }
@@ -120,7 +117,7 @@ function trackers_list_all_fields ($sort_func = false, $by_field_id = false)
         $sort_func = 'cmp_place';
       uasort ($BF_USAGE_BY_ID, $sort_func);
       uasort ($BF_USAGE_BY_NAME, $sort_func);
-      $AT_START=false;
+      $AT_START = false;
     }
 
   # Return the next bug field in the list.  If the global
@@ -130,10 +127,9 @@ function trackers_list_all_fields ($sort_func = false, $by_field_id = false)
   # list of field names.
   $idx = $by_field_id? 'bug_field_id': 'field_name';
 
-  if (current ($BF_USAGE_BY_ID) !== FALSE)
+  if (current ($BF_USAGE_BY_ID) !== false)
     {
       $field_array = current ($BF_USAGE_BY_ID);
-      $key = key ($BF_USAGE_BY_ID);
       next ($BF_USAGE_BY_ID);
       return $field_array[$idx];
     }
@@ -170,8 +166,8 @@ function trackers_field_label_display (
 
 # Display a bug field either as a read-only value or as a read-write
 # making modification possible.
-# - field_name : name of the bug field (column name).
-# - group_id : the group id (project id).
+# - field_name: name of the column.
+# - group_id: the group id.
 # - value: the current value stored in this field (for select boxes type of field
 #     it is the value_id actually. It can also be an array with mutliple values.
 # - break: true if a break line is to be inserted between the field label
@@ -249,14 +245,14 @@ function trackers_field_display (
 
     case 'DF':
       if ($ascii)
-        $output .= ($value == 0)? '': utils_format_date ($value);
+        $output .= utils_format_date ($value);
       else
         {
           if ($ro)
             $output .= utils_format_date ($value);
-        else
-          $output .= trackers_field_date (
-            $field_name, ($value == 0)? null: date ("Y-m-d", $value)
+          else
+            $output .= trackers_field_date (
+              $field_name, empty ($value)? null: date ("Y-m-d", $value)
           );
         }
       break;
@@ -361,6 +357,13 @@ function trackers_field_date_operator ($field_name, $value = '', $ro = false)
     . "\" name=\"{$field_name}_op\">$options</select>\n";
 }
 
+function trackers_chunksz_control ()
+{
+  global $chunksz;
+  return html_label ('chunksz', _("Items to show at once:")) . '&nbsp;'
+    . form_input ('text', 'chunksz', $chunksz, 'size="3" maxlength="5"');
+}
+
 function trackers_field_text (
   $field_name, $value = '', $size = 0, $maxlength = 0
 )
@@ -653,6 +656,24 @@ function trackers_set_empty_field_feedback ($bad_fields, $new_item)
   fb ($msg, 1);
 }
 
+function trackers_ck_empty_fld ($field, $val, $new_item = true)
+{
+  global $previous_form_bad_fields;
+  # Only the field percent_complete is allowed to use the special value
+  # hundred.
+  if ($field == "percent_complete")
+    return;
+  $non_empty = $val !== '';
+  if (trackers_data_is_select_box ($field))
+    $non_empty = $val != 100;
+  if ($non_empty)
+    return;
+
+  if (!trackers_mandatory_field ($field, $new_item))
+    return;
+  $previous_form_bad_fields[$field] = trackers_data_get_label ($field);
+}
+
 # Check whether empty values are submitted in any mandatory fields.
 # $field_array: associative array of field_name -> value.
 # $new_item: whether checks for new items (as opposed to comments) are run.
@@ -666,65 +687,23 @@ function trackers_check_empty_fields ($field_array, $new_item = true)
   $previous_form_bad_fields = [];
 
   foreach ($field_array as $field_name => $val)
-    {
-      # Only the field percent_complete is allowed to use the special value
-      # hundred.
-      # FIXME: maybe it should not use that value at all, however it would
-      # require one more database migration. Something that should indeed be
-      # done if at some point we feel the need for one more exception.
-      if ($field_name == "percent_complete")
-        continue;
+    trackers_ck_empty_fld ($field_name, $val, $new_item);
 
-      $non_empty = $val !== '';
-      if (trackers_data_is_select_box ($field_name))
-        $non_empty = $val != 100;
-      if ($non_empty)
-        continue;
-
-      if (!trackers_mandatory_field ($field_name, $new_item))
-        continue;
-      $value = trackers_data_get_label ($field_name);
-      $previous_form_bad_fields[$field_name] = $value;
-    }
-
-  if (count ($previous_form_bad_fields) <= 0)
+  if (!count ($previous_form_bad_fields))
     return true;
   trackers_set_empty_field_feedback ($previous_form_bad_fields, $new_item);
   return false;
 }
 
-function trackers_canned_response_box (
-  $group_id, $name = 'canned_response', $checked = null
-)
+function trackers_canned_response_box ($group_id, $checked, $height, $result)
 {
   if (empty ($checked))
-    $checked = 'xzxz';
-  if (!$group_id)
-    {
-      fb (_("Error, no group_id"), 1);
-      return 0;
-    }
-  $vals = $texts = [];
-  $result = trackers_data_get_canned_responses ($group_id);
-  if (db_numrows ($result) <= 0)
-    return form_input ("hidden", "canned_response", "100")
-      . _("No canned response available");
-
-  if (db_numrows ($result) > 1)
-    {
-      $vals[] = '!multiple!';
-      $texts[] = "> " . _("Multiple Canned Responses");
-    }
-
-  while ($entry = db_fetch_array ($result))
-    {
-      $vals[] = $entry['bug_canned_id'];
-      $texts[] = $entry['title'];
-    }
-  return html_build_select_box_from_arrays (
-    $vals, $texts, $name, $checked, true, 'None', false,' Any', false,
-    _("Canned Responses")
-  );
+    $checked = [];
+  $ret = "<select name='canned_response[]' multiple='multiple' "
+    . "size='$height'>\n";
+  while ($row = db_fetch_array ($result))
+    $ret .= form_option ($row[0], $checked, $row[1]);
+  return "$ret</select>\n";
 }
 
 function trackers_artifact_is_sane (&$artifact)
@@ -873,12 +852,13 @@ function trackers_filter_notif_address (
 # item is getting closed,
 # - unless this person wants to know only if the item status changed and
 # the item status changed.
-function trackers_build_notification_list (
-  $item_id, $group_id, $changes, $artifact
-)
+function trackers_build_notification_list ($item, $changes, $artifact)
 {
+  $item_id = $item['bug_id'];
   list ($addresses, $addresses_to_skip) =
     trackers_initial_notification_list ($artifact, $item_id);
+  if (!empty ($item['originator_email']))
+    $addresses[$item['originator_email']] = true;
 
   $result = trackers_get_cc_list ($artifact, $item_id);
   while ($row = db_fetch_array ($result))
@@ -944,7 +924,7 @@ function trackers_exclude_list ($artifact, $group_id, $force_exclude, $privacy)
   if ($privacy == '2')
     {
       $result = db_execute ("
-        SELECT ${artifact}_private_exclude_address
+        SELECT {$artifact}_private_exclude_address
         FROM groups WHERE group_id = ?", [$group_id]
       );
       $exclude = db_result ($result, 0, "{$artifact}_private_exclude_address");
@@ -962,7 +942,7 @@ function trackers_followup_mail_addresses (
   # See who is going to receive the notification.
   # Plus append any other email given at the end of the list.
   $addresses =
-    trackers_build_notification_list ($bug_id, $group_id, $changes, $tracker);
+    trackers_build_notification_list ($res, $changes, $tracker);
   $to = join (',', $addresses);
   $to = trim ("$to,$more_addresses", ',');
   $from = user_getrealname (0, 1) . " <$sys_mail_replyto@$sys_mail_domain>";
@@ -1025,6 +1005,22 @@ function trackers_mail_followup (
   );
 }
 
+function trackers_add_file ($item_id, $file, $file_description, &$changes)
+{
+  if (empty ($file['tmp_name']))
+    return '';
+  if ($file['error'] != UPLOAD_ERR_OK)
+    return '';
+
+  $id = trackers_attach_file ($item_id, $file, $file_description, $changes);
+  if (!$id)
+    return '';
+  $changes['attach'][] = [
+    'name' => $file['name'], 'size' => $file['size'], 'id' => $id
+  ];
+  return "file #$id, ";
+}
+
 # Wrapper for trackers_attach_file that will find out if one or more files
 # were attached.
 function trackers_attach_several_files ($item_id, $group_id, &$changes)
@@ -1041,21 +1037,9 @@ function trackers_attach_several_files ($item_id, $group_id, &$changes)
   $files = sane_import ('files', ['pass' => $filenames]);
   extract (sane_import ('post', ['specialchars' => 'file_description']));
   foreach ($files as $file)
-    {
-      if ($file['error'] != UPLOAD_ERR_OK)
-        continue;
-
-      $file_id = trackers_attach_file (
-        $item_id, $file['tmp_name'], $file['name'], $file['type'],
-        $file['size'], $file_description, $changes
-      );
-      if (!$file_id)
-        continue;
-      $comment .= "file #$file_id, ";
-      $changes['attach'][] = [
-        'name' => $file['name'], 'size' => $file['size'], 'id' => $file_id
-      ];
-    }
+    $comment .= trackers_add_file (
+      $item_id, $file, $file_description, $changes
+    );
 
   if ($comment)
     {
@@ -1068,16 +1052,14 @@ function trackers_attach_several_files ($item_id, $group_id, &$changes)
   return [$changed, $comment];
 }
 
-function trackers_attach_file (
-  $item_id, $input_file, $input_file_name, $input_file_type,
-  $input_file_size, $file_description, &$changes
-)
+function trackers_attach_file ($item_id, $file, $file_description, &$changes)
 {
   global $sys_trackers_attachments_dir;
-
-  $input_file_name = preg_replace ('/[&<\s"\';?!*]/', '@', $input_file_name);
-
-  $user_id = (user_isloggedin () ? user_getid (): 100);
+  $input_file = $file['tmp_name'];
+  $input_file_name = preg_replace ('/[&<\s"\';?!*]/', '@', $file['name']);
+  $input_file_type = $file['type'];
+  $input_file_size = $file['size'];
+  $user_id = (user_isloggedin ()? user_getid (): 100);
 
   if (!is_writable ($sys_trackers_attachments_dir))
     {
@@ -1415,7 +1397,7 @@ function trackers_add_sort_criteria ($criteria_list, $order, $msort)
   $found = false;
   if ($criteria_list)
     {
-      $arr = explode(',', $criteria_list);
+      $arr = explode (',', $criteria_list);
       $i = 0;
       foreach ($arr as $attr)
         {
@@ -1433,19 +1415,18 @@ function trackers_add_sort_criteria ($criteria_list, $order, $msort)
         }
     }
 
-  if (!$found)
-    {
-      if (!$msort)
-        unset ($arr);
-      if (
-        $order == 'severity' || $order == 'hours'
-        || trackers_data_is_date_field ($order)
-      )
-        # Severity, effort and dates sorted in descending order by default.
-        $arr[] = "$order<";
-      else
-        $arr[] = "$order>";
-    }
+  if ($found)
+    return join (',', $arr);
+  if (!$msort)
+    $arr = [];
+  if (
+    $order == 'severity' || $order == 'hours'
+    || trackers_data_is_date_field ($order)
+  )
+    # Severity, effort and dates sorted in descending order by default.
+    $arr[] = "$order<";
+  else
+    $arr[] = "$order>";
   return join (',', $arr);
 }
 
@@ -1453,9 +1434,10 @@ function trackers_add_sort_criteria ($criteria_list, $order, $msort)
 function trackers_criteria_sanitize ($criteria_list)
 {
   $criteria = explode (',', $criteria_list);
-  $fields = [];
+  $fields = ['bug_id' => 1, 'priority' => 1]; # These fields are always present.
   while ($field = trackers_list_all_fields ())
-    $fields[] = $field;
+    $fields[$field] = 1;
+  $fields = array_keys ($fields);
   $regexp = "/^(" . join ('|', $fields) . ')[<>]?$/';
   $criteria_filtered = [];
   foreach ($criteria as $cr)
@@ -1482,38 +1464,47 @@ function trackers_criteria_list_to_query ($criteria_list)
   return $criteria_list;
 }
 
-# Return image name and alt text for sorting order.
-function trackers_sorting_order ($crit)
+function trackers_sorting_order_img ($crit)
 {
+  #TRANSLATORS: this string specifies sorting order.
+  $so = ['image' => 'up', 'text' => _('up')];
   if (substr ($crit, -1) == '>')
     #TRANSLATORS: this string specifies sorting order.
-    return ['image' => 'down', 'text' => _('down')];
-  #TRANSLATORS: this string specifies sorting order.
-  return ['image' => 'up', 'text' => _('up')];
+    $so = ['image' => 'down', 'text' => _('down')];
+  $img_src = "arrows/{$so['image']}.png";
+  return html_image ($img_src,  ['alt' => $so['text'], 'class' => 'icon']);
+}
+
+# Return a single link from the list of criteria
+# built in trackers_criteria_list_to_text ().
+function trackers_sorting_link ($url, $morder, $crit)
+{
+  $field = str_replace (['<', '>'], '', $crit);
+  return "<a href=\"$url&amp;morder=$morder#results\">"
+    . trackers_data_get_label ($field) . '</a>'
+    . trackers_sorting_order_img ($crit);
 }
 
 # Transform criteria list to readable text statement.
 # $url must not contain the morder parameter.
 function trackers_criteria_list_to_text ($criteria_list, $url)
 {
-  if ($criteria_list)
+  if (empty ($criteria_list))
+    return '';
+  $morder = '';
+  foreach (explode (',', $criteria_list) as $crit)
     {
-      $arr = explode(',', $criteria_list);
-      $morder = '';
-
-      foreach ($arr as $crit)
-        {
-          $morder .= ($morder? ",$crit": $crit);
-          $attr = str_replace('>', '', $crit);
-          $attr = str_replace('<', '', $attr);
-          $so = trackers_sorting_order ($crit);
-          $img_src = 'arrows/' . $so['image'] . '.png';
-          $arr_text[] = "<a href=\"$url&amp;morder=$morder#results\">"
-            . trackers_data_get_label ($attr) . '</a>'
-            . html_image ($img_src,  ['alt' => $so['text']]);
-        }
+      $morder .= $crit;
+      $links[] = trackers_sorting_link ($url, $morder, $crit);
+      $morder .= ',';
     }
-  return join (' &gt; ', $arr_text);
+  # The links cut the sequence of ordering at the current field,
+  # which makes no sense for the last item, so we make it change
+  # the order asc <-> desc.
+  $anc = '#results';
+  $last = strtr (end ($links), [">$anc" => "<$anc", "<$anc" => ">$anc"]);
+  $links [key ($links)] = $last;
+  return join (' &gt; ', $links);
 }
 
 function trackers_build_match_expression ($field, &$to_match)
@@ -1662,14 +1653,6 @@ function trackers_build_match_expression ($field, &$to_match)
   return [$expr, $params];
 }
 
-# The function moved to data.
-function trackers_delete_file (
-  $group_id = false, $item_id = false, $item_file_id = false
-)
-{
-  return trackers_data_delete_file ($group_id, $item_id, $item_file_id);
-}
-
 # Register a msg id for an item update notification.
 function trackers_register_msgid ($msgid, $artifact, $item_id)
 {
@@ -1682,24 +1665,17 @@ function trackers_register_msgid ($msgid, $artifact, $item_id)
   );
 }
 
-# Get a list, separated  a msg id for an item update notification.
-function trackers_get_msgid ($artifact, $item_id, $latest = "")
+# Get a list of msg ids for item update notification
+# (the References and In-Reply-To headers), in the reverse chronological order.
+function trackers_get_msgid ($artifact, $item_id)
 {
-  if ($latest)
-    $latest = "ORDER BY id DESC LIMIT 1";
-
   $result = db_execute ("
-    SELECT msg_id FROM trackers_msgid
-    WHERE artifact = ?  AND item_id = ? $latest",
-    [$artifact, $item_id]
+    SELECT msg_id FROM trackers_msgid WHERE artifact = ? AND item_id = ?
+    ORDER BY id DESC", [$artifact, $item_id]
   );
-  $list = '';
-  while ($id = db_fetch_array ($result))
-    {
-      if (isset ($list))
-        $list .= " ";
-      $list .= "<{$id['msg_id']}>";
-    }
-  return $list;
+  $msg_ids = [];
+  while ($row = db_fetch_array ($result))
+    $msg_ids[] = "<{$row['msg_id']}>";
+  return $msg_ids;
 }
 ?>
