@@ -6,7 +6,7 @@
 # Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -212,8 +212,8 @@ function trackers_transition_update_item (
           if ($field != 'close_date')
             {
               # TRANSLATORS: the argument is field name.
-              sprintf (_("Automatic update of %s due to transitions settings"),
-                trackers_data_get_label($field)
+              $msg = sprintf (_("Automatic update of %s due to transitions settings"),
+                trackers_data_get_label ($field)
               );
               fb ($msg);
             }
