@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -41,36 +41,30 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-# Count the remaining votes of a given user.
-function trackers_votes_user_remains_count ($user_id)
+# Return the remaining amount of votes for the current user.
+function trackers_votes_remaining ()
 {
   $total = 100;
-  $result = db_execute ("
-    SELECT howmuch FROM user_votes WHERE user_id = ?", [$user_id]
+  $result = db_execute (
+    "SELECT SUM(howmuch) AS sum FROM user_votes WHERE user_id = ?",
+    [user_getid ()]
   );
 
   if (db_numrows ($result))
-    {
-      while ($row = db_fetch_array ($result))
-        $total = $total - $row['howmuch'];
-    }
+    $total -= db_result ($result, 0, 'sum');
 
-  # Total < 0 does not make sense
   if ($total < 0)
-    {
-      fb (_("You appear to have less than 0 votes remaining. There's a bug\n"
-            . "somewhere, please contact the administrators"), 1);
-    }
+    return 0;
   return $total;
 }
 
-# Count the number of vote of a given user of a given item.
-function trackers_votes_user_giventoitem_count ($user_id, $tracker, $item_id)
+# Return the votes of the current user given to the item.
+function trackers_get_user_votes ($tracker, $item_id)
 {
   $result = db_execute ("
     SELECT howmuch FROM user_votes
     WHERE user_id = ? AND tracker = ? AND item_id = ? LIMIT 1",
-    [$user_id, $tracker, $item_id]
+    [user_getid (), $tracker, $item_id]
   );
 
   if (!db_numrows ($result))
@@ -88,95 +82,106 @@ function trackers_votes_erase_vote ($tracker, $item_id, $vote)
   );
   $res = db_execute ("SELECT vote FROM $tracker WHERE bug_id = ?", [$item_id]);
   $new_vote = db_result ($res, 0, 'vote') - $vote;
-  db_execute ("
-    UPDATE $tracker SET vote = ? WHERE bug_id = ?", [$new_vote, $item_id]
+  db_execute (
+    "UPDATE $tracker SET vote = ? WHERE bug_id = ?", [$new_vote, $item_id]
   );
   fb (_("Vote erased"));
 }
 
+# Make sure the new vote count doesn't overflow the total allowed
+# vote count for the user; return the resulting increment.
+function trackers_votes_diff ($old_vote, &$new_vote)
+{
+  # Check the diff between the registered vote and the new vote.
+  $diff_vote = $new_vote - $old_vote;
+
+  # If new vote equal to the current vote, nothing to do.
+  if (!$diff_vote)
+    return $diff_vote;
+
+  # Check whether the user have not specified more votes than he actually
+  # got available.
+  $remains = trackers_votes_remaining ();
+  if ($remains < $diff_vote)
+    {
+      # If so, set the diff_vote and new_vote as the maximum possible.
+      $diff_vote = $remains;
+      $new_vote = $diff_vote + $old_vote;
+    }
+  return $diff_vote;
+}
+
+# Update user_votes table, add CC to tracker item if needed.
+# Return true on failure.
+function trackers_votes_insert_vote ($old_vote, $new_vote, $tracker, $item_id)
+{
+  if ($old_vote)
+    $res = db_execute ("
+      UPDATE user_votes SET howmuch = ?
+      WHERE user_id = ? AND tracker = ? AND item_id = ?",
+      [$new_vote, user_getid (), $tracker, $item_id]
+    );
+  else
+    {
+      $res = db_autoexecute (
+        'user_votes',
+        [
+          'user_id' => user_getid (), 'tracker' => $tracker,
+          'item_id' => $item_id, 'howmuch' => $new_vote
+        ], DB_AUTOQUERY_INSERT
+      );
+      trackers_add_cc ($item_id, user_getname (), "-VOT-");
+    }
+  return db_affected_rows ($res) < 1;
+}
+
+# Update vote count in tracker table.
+function trackers_votes_inc_item_vote ($tracker, $item_id, $diff_vote)
+{
+  # Add the new vote to the item proper info table.
+  $res = db_execute (
+    "SELECT vote FROM $tracker WHERE bug_id = ?", [$item_id]
+  );
+  $item_vote = db_result ($res, 0, 'vote') + $diff_vote;
+  $res = db_execute ("
+    UPDATE $tracker SET vote = ? WHERE bug_id = ?", [$item_vote, $item_id]
+  );
+  if (db_affected_rows ($res) < 1)
+    {
+      # In case of problem, kept unmodified the item proper info.
+      fb (_("Unable to finally record the vote, please report to admins"), 1);
+      return;
+    }
+  # If we arrive here, everything went properly.
+  if ($diff_vote > 0)
+    $diff_vote = "+$diff_vote";
+  fb (_("Vote recorded") . " ($diff_vote)");
+}
+
 # Update update votes in the database.
 function trackers_votes_update ($item_id, $new_vote, $tracker = null)
 {
+  if (!user_isloggedin ())
+    return;
   if (!$tracker)
     $tracker = ARTIFACT;
 
-  # If the user already voted for this item:
-  #   - if he voted 0, we must simply remove the vote,
-  #   - if he voted something else, we must add or remove the diff.
-
-  $old_votes = trackers_votes_user_giventoitem_count (
-    user_getid (), $tracker, $item_id
-  );
+  $old_vote = trackers_get_user_votes ($tracker, $item_id);
   if ($new_vote < 1)
     {
-      if ($old_votes)
-        trackers_votes_erase_vote ($tracker, $item_id, $old_votes);
-      return false;
+      if ($old_vote)
+        trackers_votes_erase_vote ($tracker, $item_id, $old_vote);
+      return;
     }
-  # Check the diff between the registered vote and the new vote.
-  $diff_vote = $new_vote - $old_votes;
-
-  # If new vote equal to the current vote, nothing to do.
+  $diff_vote = trackers_votes_diff ($old_vote, $new_vote);
   if (!$diff_vote)
-    return true;
+    return;
 
-  # Check whether the user have not specified more votes than he actually
-  # got available.
-  $remains = trackers_votes_user_remains_count (user_getid ());
-  if ($remains < $diff_vote)
+  if (trackers_votes_insert_vote ($old_vote, $new_vote, $tracker, $item_id))
     {
-      # If so, set the diff_vote and new_vote as the maximum possible.
-      $diff_vote = $remains;
-      $new_vote = $diff_vote + $old_votes;
-    }
-
-  # If the vote is new, we do a SQL INSERT, otherwise a SQL UPDATE
-  # in the user_votes table.
-  if ($old_votes)
-    $res_insert = db_execute ("
-      UPDATE user_votes SET howmuch = ?
-      WHERE user_id=? AND tracker = ? AND item_id = ?",
-      [$new_vote, user_getid(), $tracker, $item_id]
-    );
-  else
-    $res_insert = db_autoexecute (
-      'user_votes',
-      [
-        'user_id' => user_getid (),
-        'tracker' => $tracker,
-        'item_id' => $item_id,
-        'howmuch' => $new_vote
-      ], DB_AUTOQUERY_INSERT
-    );
-
-  trackers_add_cc ($item_id, user_getname (), "-VOT-");
-
-  if (db_affected_rows($res_insert) < 1)
-    {
-      # In case of problem, kept unmodified the item proper info.
       fb (_("Unable to record the vote, please report to admins"), 1);
-      return false;
+      return;
     }
-
-  # Add the new vote to the item proper info table.
-  $res_get = db_execute (
-    "SELECT vote FROM $tracker WHERE bug_id = ?", [$item_id]
-  );
-  $real_new_vote = db_result ($res_get, 0, 'vote') + $diff_vote;
-  $res_update = db_execute ("
-    UPDATE $tracker SET vote = ? WHERE bug_id = ?", [$real_new_vote, $item_id]
-  );
-  if (db_affected_rows ($res_update) < 1)
-    {
-      # In case of problem, kept unmodified the item proper info.
-      fb (_("Unable to finally record the vote, please report to admins"), 1);
-      return false;
-    }
-
-  # If we arrive here, everything went properly.
-  if ($diff_vote > 0)
-    $diff_vote = "+$diff_vote";
-  fb (_("Vote recorded") . " ($diff_vote)");
-  return true;
+  trackers_votes_inc_item_vote ($tracker, $item_id, $diff_vote);
 }
 ?>
