@@ -7,7 +7,7 @@
 # Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -44,7 +44,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 extract (sane_import ('request',
-  ['hash' => 'form_id', 'array' => [['prefill', [null, 'specialchars']]]]
+  ['array' => [['prefill', [null, 'specialchars']]]]
 ));
 
 if (!group_restrictions_check ($group_id, ARTIFACT))
@@ -73,8 +73,8 @@ if ($preamble)
 print '<h2>' . _("Details") . "</h2>\n";
 
 # Beginning of the submission form with fixed fields.
-print form_header ($php_self, $form_id, "post",
-  'enctype="multipart/form-data" name="trackers_form"'
+print form_header (
+  null, "post", 'enctype="multipart/form-data" name="trackers_form"'
 );
 print form_hidden (["func" => "postadditem", 'group_id' => $group_id]);
 print "\n<table cellpadding='0' width='100%'>";
@@ -119,10 +119,11 @@ while ($field_name = trackers_list_all_fields ())
       $field_name, $group_id, false, false
     );
     if ($field_name == 'details')
-      $label .=
-        ' <span class="preinput">' . markup_info ("full")
-        . "</span>&nbsp;\n&nbsp;"
-        . form_submit (_('Preview'), 'preview', false, true);
+      {
+        $GLOBALS['int_trapisset'] = true;
+        $label .= ' <span class="preinput">' . markup_info ("full")
+          . "</span>&nbsp;\n&nbsp;" . form_submit (_('Preview'), 'preview');
+      }
 
     $star = '';
     $mandatory_flag = trackers_data_mandatory_flag ($field_name);
@@ -228,7 +229,7 @@ print '<span class="preinput">' . _("Comment:") . "</span><br />\n"
   . "\n</p>\n";
 
 # Cc addresses.
-if (user_isloggedin ())
+if ($is_trackeradmin)
   {
     print "<p>&nbsp;</p>\n";
     print '<h2>' . _("Mail Notification CC") . "</h2>\n";
@@ -266,9 +267,11 @@ if (!user_isloggedin ())
     . "\n" . form_input ('text', 'check', $check) . "</p>\n";
 
 print '<div align="center">';
+$int_trapisset = true;
+print form_submit (_('Preview'), 'preview') . '&nbsp;&nbsp;';
 print form_submit (false, "submit", 'class="bold"');
 print "</div>\n";
 print "</form>\n";
 
-trackers_footer ([]);
+trackers_footer ();
 ?>
