@@ -6,7 +6,7 @@
 # Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -42,10 +42,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-extract (sane_import ('get',
+extract (sane_import ('request',
   [
     'funcs' => 'func',
-    'digits' =>  'dependencies_of_item',
+    'digits' =>  ['dependencies_of_item'],
     'artifact' => 'dependencies_of_tracker',
     'array' =>
       [
@@ -55,6 +55,8 @@ extract (sane_import ('get',
   ]
 ));
 
+require_once ('../include/trackers/view-dependencies.php');
+
 if ($func == "digest")
   {
     $browse_preamble = '<p>'
@@ -69,94 +71,122 @@ if ($func == "digest")
           . "of this page."
         )
       . "</p>\n";
-    goto end_of_file;
+    include '../include/trackers_run/browse.php';
+    exit (0);
   }
+
+# Select items to digest, if we are supposed to digest dependencies.
+function select_items_by_deps ($deps_of_item, $deps_of_tracker)
+{
+  global $items_for_digest;
+  if (!($deps_of_item && $deps_of_tracker))
+    return;
+  $res_deps =
+    db_execute ("
+      SELECT is_dependent_on_item_id FROM {$deps_of_tracker}_dependencies
+      WHERE item_id = ? AND is_dependent_on_item_id_artifact = ?
+      ORDER by is_dependent_on_item_id", [$deps_of_item, ARTIFACT]
+    );
+  $items_for_digest = [];
+  while ($deps = db_fetch_array ($res_deps))
+    $items_for_digest[] = $deps['is_dependent_on_item_id'];
+}
+function print_field_selection_head ($group)
+{
+  global $items_for_digest;
+  trackers_header (['title' => _("Digest items: field selection")]);
+  print form_tag (['method' => 'get'])
+    . form_hidden (['group' => $group, 'func' => 'digestget']);
+
+  # Keep track of the selected items.
+  $count = 0;
+  foreach ($items_for_digest as $item)
+    {
+      print form_hidden (["items_for_digest[]" => $item]);
+      $count++;
+    }
+
+  print "\n\n<p>";
+  printf (
+    ngettext (
+      "You selected %s item for this digest.",
+      "You selected %s items for this digest.", $count),
+    $count
+  );
+  print ' '
+   . _("Now you must unselect fields you do not want to be included "
+       . "in the digest.")
+   . "</p>\n";
+}
+function print_altrow ($i)
+{
+  print '<div class="' . utils_altrow ($i) . '">';
+}
+function print_field_selection ($field_name, $i)
+{
+  # Open/Close and group id are meaningless in this context:
+  # they'll be on the output page in any cases.
+  if (in_array ($field_name, ['group_id', 'status_id']))
+    return 0;
+  if (!trackers_data_is_used ($field_name))
+    return 0;
+
+  # Item ID is mandatory.
+  if ($field_name == "bug_id")
+      {
+        print form_hidden (["field_used[$field_name]" => "1"])
+          . "\n";
+        return 0;
+      }
+  print_altrow ($i);
+  print form_checkbox ("field_used[$field_name]", 1)
+    . '&nbsp;&nbsp;' . trackers_data_get_label ($field_name)
+    . ' <span class="smaller"><em>- '
+    . trackers_data_get_description ($field_name)
+    . "</em></span></div>\n";
+  return 1;
+}
+function print_all_fields_selection ()
+{
+  $i = 0;
+  while ($field_name = trackers_list_all_fields ())
+    $i += print_field_selection ($field_name, $i);
+  return $i;
+}
+function print_select_latest_comment ($i)
+{
+  print_altrow ($i);
+  print form_checkbox ("field_used[latestcomment]", 1) . '&nbsp;&nbsp;'
+    . _("Latest Comment") . ' <span class="smaller"><em>- '
+    . _("Latest comment posted about the item.") . "</em></span></div>\n";
+}
+function print_select_dependencies ($i)
+{
+  print_altrow ($i);
+  print form_checkbox ("field_used[dependencies]", 1) . '&nbsp;&nbsp;'
+    . _("Dependencies") . ' <span class="smaller"><em>- '
+    . _("List of dependencies.") . "</em></span></div>\n";
+}
 if ($func == "digestselectfield")
   {
-    # Determines items to digest, if we are supposed to digest dependencies.
-    if ($dependencies_of_item && $dependencies_of_tracker)
-      {
-        $res_deps =
-          db_execute ("
-            SELECT is_dependent_on_item_id
-            FROM ${dependencies_of_tracker}_dependencies
-            WHERE item_id = ? AND is_dependent_on_item_id_artifact = ?
-            ORDER by is_dependent_on_item_id",
-            [$dependencies_of_item, ARTIFACT]
-          );
-        $items_for_digest = [];
-        while ($deps = db_fetch_array ($res_deps))
-          $items_for_digest[] = $deps['is_dependent_on_item_id'];
-      }
+    select_items_by_deps ($dependencies_of_item, $dependencies_of_tracker);
 
     if (!is_array ($items_for_digest))
       exit_error (_("No items selected for digest"));
 
-    trackers_header (['title' => _("Digest Items: Fields Selection")]);
-    print form_tag (['method' => 'get'])
-      . form_hidden (['group' => $group, 'func' => 'digestget']);
-
-    # Keep track of the selected items.
-    $count = 0;
-    foreach ($items_for_digest as $item)
-      {
-        print form_input ("hidden", "items_for_digest[]", $item);
-        $count++;
-      }
-
-    print "\n\n<p>";
-    printf (
-      ngettext (
-        "You selected %s item for this digest.",
-        "You selected %s items for this digest.", $count),
-      $count
-    );
-    print ' '
-     . _("Now you must unselect fields you do not want to be included "
-         . "in the digest.")
-     . "</p>\n";
-
-    $i = 0;
-    # Select fields.
-    while ($field_name = trackers_list_all_fields ())
-      {
-        if (!trackers_data_is_used ($field_name))
-          continue;
-        # Open/Close and Group id are meaningless in this context:
-        # they'll be on the output page in any cases.
-        if ($field_name == 'group_id' || $field_name == 'status_id')
-          continue;
-
-        # Item ID is mandatory.
-        if ($field_name == "bug_id")
-            {
-              print form_hidden (["field_used[$field_name]" => "1"])
-                . "\n";
-              continue;
-            }
-
-        print '<div class="' . utils_altrow ($i) . '">'
-          . form_checkbox ("field_used[$field_name]", 1)
-          . '&nbsp;&nbsp;' . trackers_data_get_label ($field_name)
-          . ' <span class="smaller"><em>- '
-          . trackers_data_get_description ($field_name)
-          . "</em></span></div>\n";
-          $i++;
-      }
-    # Comments is not an authentic field but could be useful. We allow
-    # addition of the latest comment.
-    print '<div class="' . utils_altrow ($i) . '">'
-      . form_checkbox ("field_used[latestcomment]", 1) . '&nbsp;&nbsp;'
-      . _("Latest Comment") . ' <span class="smaller"><em>- '
-      . _("Latest comment posted about the item.") . "</em></span></div>\n";
+    print_field_selection_head ($group);
+    $i = print_all_fields_selection ();
+    # The rest are not fields, but could be useful.
+    print_select_latest_comment ($i++);
+    print_select_dependencies ($i);
 
     print form_footer (_("Submit"));
-    trackers_footer ([]);
-    goto end_of_file;
+    trackers_footer ();
+    exit (0);
   } # if ($func == "digestselectfield")
 
 if ($func != "digestget")
-  goto end_of_file;
+  exit (0);
 
 if (!is_array ($items_for_digest))
   exit_error (_("No items selected for digest"));
@@ -168,11 +198,30 @@ trackers_header (
   ['title' => _("Digest") . ' - ' . utils_format_date (time ())]
 );
 
+function show_dependencies ($item)
+{
+  global $dependencies, $field_used;
+  if (!isset ($field_used["dependencies"]))
+    return;
+  if ($field_used["dependencies"] != 1)
+    return;
+  print '<p class="clearr"><span class="preinput">'
+    . _("Dependencies") . "</span></p>\n";
+  if (empty ($dependencies[$item]))
+    return;
+  print "<ul>\n";
+  foreach ($dependencies[$item] as $d)
+    trackers_show_dep ($d);
+  print "</ul>\n";
+}
+
+if (isset ($field_used["dependencies"]) && $field_used["dependencies"] == 1)
+  $dependencies = trackers_list_dependencies ($items_for_digest);
+
 # Browse the list of selected item.
 $i = 0;
 foreach ($items_for_digest as $item)
   {
-    $i++;
     $result =
       db_execute ("SELECT * FROM " . ARTIFACT . " WHERE bug_id = ?", [$item]);
 
@@ -183,41 +232,25 @@ foreach ($items_for_digest as $item)
     # Normally, the user should not even been able to select this item.
     # But someone nasty could forge the arguments of the script... So its
     # better to check everytime.
-    if ($res_arr['privacy'] == "2"
-        && !member_check_private (0, $res_arr['group_id']))
+    if (trackers_item_access_denied ($res_arr))
       continue;
 
     # Show summary if requested.
-    $summary = '';
-    if (isset ($field_used['summary']) && $field_used['summary'] == 1)
-      $summary = $res_arr['summary'];
-
-    # Show if the item is closed with an icon.
-    if ($res_arr['status_id'] != 1)
-      {
-        $img_file = 'ok.png'; $img_alt = _("Closed Item");
-      }
-    else
-      {
-        $img_file = 'wrong.png'; $img_alt = _("Open Item");
-      }
-    $icon = html_image ("bool/$img_file", ['alt' => $img_alt]);
-
-    print '<div class="' . utils_altrow ($i) . '">';
-    print '<span class="large"><span class="'
-     . utils_get_priority_color ($res_arr['priority'], $res_arr['status_id'])
-     . "\">$icon&nbsp; "
-     . utils_link ("?func=detailitem&amp;item_id=$item", ARTIFACT . " #$item")
-     . ": &nbsp;$summary &nbsp;</span></span><br /><br />\n";
+    if (!(isset ($field_used['summary']) && $field_used['summary'] == 1))
+      $res_arr['summary'] = '';
+    $res_arr['tracker'] = ARTIFACT;
+    print '<div class="' . utils_altrow ($i++) . '"><span class="large">';
+    trackers_print_item_link ($res_arr);
+    print "</span><br /><br />\n";
 
     $field_count = 0;
     $halves = ['', ''];
     while ($field_name = trackers_list_all_fields ())
       {
-        # Some field can be ignored in any cases.
-        if (in_array ($field_name,
-              ["status_id", "summary", "bug_id", "details", "comment_type_id"])
-        )
+        # Some fields can be ignored in any cases.
+        $ignore_fields =
+          ["status_id", "summary", "bug_id", "details", "comment_type_id"];
+        if (in_array ($field_name, $ignore_fields))
           continue;
 
         # Check the fields.
@@ -305,9 +338,10 @@ foreach ($items_for_digest as $item)
             print '</span> ' . markup_rich ($last_comment) . "</div>\n";
           }
       }
+    show_dependencies ($item);
     print "<p class='clearr'>&nbsp;</p>\n</div>\n\n";
   } # foreach ($items_for_digest as $item)
-trackers_footer ([]);
 
-end_of_file:
+print trackers_warn_about_hidden ();
+trackers_footer ();
 ?>
