@@ -7,7 +7,7 @@
 # Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -52,6 +52,7 @@ require_directory ("search"); # Need search functions.
 
 $fields_per_line = 2;
 $max_size = 40;
+$max_rows = 25;
 $ro_fields = !$is_trackeradmin;
 
 $result = db_execute ("
@@ -61,7 +62,7 @@ $result = db_execute ("
 
 if (db_numrows ($result)  <= 0)
   {
-    trackers_footer ([]);
+    trackers_footer ();
     exit (0);
   }
 $res_arr = db_fetch_array ($result);
@@ -115,16 +116,16 @@ if (!group_restrictions_check ($group_id, ARTIFACT, TRACKER_EVENT_COMMENT))
     $enable_comments = false;
   }
 
-trackers_header ([
-  'title' =>
-     "$item_name, " . utils_cutstring ($res_arr['summary'])
-]);
+trackers_header (
+  ['title' => "$item_name, " . utils_cutstring ($res_arr['summary'])]
+);
 
 # Check if the user have a specific role.
-$check_member = function ($group_id, $artifact, $role, $strict = 1)
+$check_member = function ($role)
 {
-  $flag = member_create_tracker_flag ($artifact) . $role;
-  return member_check (0, $group_id, $flag,  $strict);
+  global $group_id;
+  $flag = member_create_tracker_flag (ARTIFACT) . $role;
+  return member_check (0, $group_id, $flag);
 };
 $member_help = function ($title, $arr)
 {
@@ -132,7 +133,8 @@ $member_help = function ($title, $arr)
   print help ($title, $arr);
   print "</p>\n";
 };
-if ($check_member ($group_id, ARTIFACT, '2'))
+$is_manager = $check_member ('3');
+if ($check_member ('2'))
   $member_help (
     _("You are both technician and manager for this tracker."),
     [
@@ -141,28 +143,29 @@ if ($check_member ($group_id, ARTIFACT, '2'))
      _("manager") => _("fully manage the items"),
     ]
   );
-elseif ($check_member ($group_id, ARTIFACT, '1'))
+elseif ($check_member ('1'))
   $member_help (
     _("You are technician for this tracker."),
     [
       _("technician") =>
-        _("you can be assigned tracker's items, but you cannot reassign\n"
-          . "items, change priority nor open/close")
+        _("you can be assigned tracker's items, but you cannot reassign "
+          . "items, change priority, open nor close")
     ]
   );
-elseif ($check_member ($group_id, ARTIFACT, '3'))
+elseif ($is_manager)
   $member_help (
     _("You are manager for this tracker."),
     [
       _("manager") =>
-        _("you can fully manage the trackers items, including assigning\n"
-          . "items to technicians, reassign items over trackers and "
-          . "projects, changing\npriority and open/close items")
+        _("you can fully manage the trackers items, including assigning "
+          . "items to technicians, reassigning items over trackers and "
+          . "groups, changing priority, opening and closing items")
     ]
   );
+unset ($check_member);
 
 if (!empty ($private_intro))
-  print '<p>' . $private_intro . "</p>\n";
+  print "<p>$private_intro</p>\n";
 
 $class = utils_get_priority_color (
   $res_arr['priority'], $res_arr['status_id']
@@ -174,8 +177,7 @@ print $res_arr['summary'] . "</h1>\n";
 if ($enable_comments)
   {
     print form_header (
-      $_SERVER['PHP_SELF'], $form_id, "post",
-      'enctype="multipart/form-data" name="item_form"'
+      null, "post", 'enctype="multipart/form-data" name="item_form"'
     );
     print form_hidden (
       ["func" => "postmoditem", "group_id" => $group_id, "item_id" => $item_id]
@@ -187,50 +189,60 @@ if ($enable_comments)
 #
 #  | Label:  Value________| Label:  Value______ |
 #  | Label:  Value_____________________________ |
-#
-#  So we have 4 column large via colspan.
+$button_attr =
+  "colspan='$fields_per_line' width='50%' align='center' valign='top'";
 
 print "\n\n<table cellpadding='0' width='100%'>\n"
   . "<tr>\n<td class='preinput' width='15%'>"
   . _("Submitter:") . "&nbsp;</td>\n<td width='35%'>"
   . utils_user_link (user_getname ($submitter), user_getrealname ($submitter))
-  . "</td>\n<td colspan=\"" . ($fields_per_line)
-  . '" width="50%" align="center" valign="top"><span class="noprint">'
-  . form_submit (_("Submit Changes and Browse Items"), "submit", 'class="bold"')
-  . "</span></td>\n</tr>\n<tr>\n"
-  . '<td class="preinput" width="15%">'
+  . "</td>\n<td $button_attr><span class='noprint'>"
+  . form_submit (_("Submit changes and browse items"), "submit", 'class="bold"')
+  . "</span></td>\n</tr>\n<tr>\n<td class='preinput' width='15%'>"
   # TRANSLATORS: This is a label for dates.
   . _("Submitted:") . "&nbsp;</td>\n<td width='35%'>"
   . utils_format_date ($res_arr['date'])
-  . "</td>\n<td colspan=\"" . ($fields_per_line)
-  . '" width="50%" align="center" valign="top"><span class="noprint">'
-  . form_submit (_("Submit Changes and Return to this Item"), "submitreturn")
+  . "</td>\n<td $button_attr><span class='noprint'>"
+  . form_submit (_("Submit changes and return to this item"), "submitreturn")
   . "</span></td>\n</tr>\n";
-
+print "\n<tr>\n<td class='preinput' width='15%'>";
 $votes = $res_arr['vote'];
 if ($votes)
-  # Display vote here if any, anything else is handled below.
-  print "\n<tr>\n"
-    . '<td class="preinput" width="15%">' . _("Votes:")
-    . "&nbsp;</td>\n<td width='35%'><a href='#votes'>"
-    . "$votes</a></td>\n<td colspan=\""
-    . ($fields_per_line) . "\" width='50%'>&nbsp;</td>\n</tr>\n";
+  print _("Votes:")
+    . "</td>\n<td width='35%'><a href='#votes'>$votes</a></td>\n";
+else
+  print "&nbsp;</td>\n<td width='35%'>&nbsp;</td>\n";
+print "<td $button_attr><span class='noprint'>"
+  . form_submit (_('Preview'), 'preview') . "</span></td>\n</tr>\n";
 
 print '<tr><td colspan="' . ($fields_per_line * 2) . "\">&nbsp;</td></tr>\n";
 
-# Now display the variable part of the field list (depend on the project).
+# Now display the variable part of the field list (depend on the group).
 # Some fields must be displayed differently according to the user role.
-$is_manager = $check_member ($group_id, ARTIFACT, '3', 0);
 
-# Variables that will be used afterwards.
+function mandatory_sign ($submitter, $field)
+{
+  global $group_id, $enable_comments;
+  if (!$enable_comments)
+    return '';
+  $star = '<span class="warn"> *</span>';
+  $flag = trackers_data_mandatory_flag ($field);
+  if ($flag == 3)
+    return $star;
+  if ($flag != 0)
+    return '';
+  if (trackers_check_is_shown_to_submitter ($field, $group_id, $submitter))
+    return $star;
+  return '';
+}
+
 $item_assigned_to = null;
-
 $i = 0; # Field counter.
 $j = 0; # Background selector.
 
 while ($field_name = trackers_list_all_fields ())
   {
-    # If the field is not used by the project, skip it.
+    # If the field is not used by the group, skip it.
     if (!trackers_data_is_used ($field_name))
       continue;
 
@@ -248,7 +260,7 @@ while ($field_name = trackers_list_all_fields ())
           continue;
       }
 
-    #  Print the originator email field only if the submitted was anonymous.
+    #  Print the originator email field only if the submitter was anonymous.
     if ($field_name == 'originator_email' && $submitter != '100')
       continue;
 
@@ -261,14 +273,13 @@ while ($field_name = trackers_list_all_fields ())
 
     # Look for the field value in the database only if we missing
     # its values. If we already have a value, we are probably in
-    # step 2 of a search on item/group (dependency, reassignation).
+    # step 2 of a search.
 
     # If nocache is set, we were explicetely asked to rely only
     # on database content.
     if (!isset ($nocache))
       $nocache = false;
-    if ((empty ($$field_name) || $nocache)
-        && !($preview && $is_trackeradmin))
+    if ((empty ($$field_name) || $nocache) && !($preview && $is_trackeradmin))
       $field_value = $res_arr[$field_name];
     else
       {
@@ -284,9 +295,9 @@ while ($field_name = trackers_list_all_fields ())
         $field_value = utils_specialchars ($$field_name);
       }
     list ($sz,) = trackers_data_get_display_size ($field_name);
-    $label = trackers_field_label_display ($field_name, $group_id,
-                                           false, false);
-    # Save the assigned to value for later.
+    $label = trackers_field_label_display (
+      $field_name, $group_id, false, false
+    );
     if ($field_name == 'assigned_to')
       {
         $item_assigned_to = trackers_field_display (
@@ -296,7 +307,6 @@ while ($field_name = trackers_list_all_fields ())
           user_getname ($field_value), user_getrealname ($field_value)
         );
       }
-
     # Some fields must be displayed read-only,
     # assigned_to, status_id and priority too, for technicians
     # (if super_user, do nothing).
@@ -304,88 +314,61 @@ while ($field_name = trackers_list_all_fields ())
         && (in_array ($field_name,
             ['status_id', 'assigned_to', 'priority', 'originator_email'])))
       {
-        $value = trackers_field_display ($field_name, $group_id, $field_value,
-          false, false, true
+        $value = trackers_field_display (
+          $field_name, $group_id, $field_value, false, false, true
         );
         if ($field_name == 'originator_email')
           $value = utils_email_basic ($value);
       }
     else
-      $value = trackers_field_display ($field_name, $group_id, $field_value,
-        false, false, $ro_fields, false, false, _("None"), false, _("Any"),
-        true
+      $value = trackers_field_display (
+        $field_name, $group_id, $field_value, false, false,
+        $ro_fields, false, false, _("None"), false, _("Any"), true
       );
 
-    # Check if the field is mandatory.
-    $star = '';
-    $mandatory_flag = trackers_data_mandatory_flag ($field_name);
-    if ($mandatory_flag == 3
-        || ($mandatory_flag == 0
-            && trackers_check_is_shown_to_submitter (
-                 $field_name, $group_id, $submitter))
-    )
-      if ($enable_comments)
-        $star = '<span class="warn"> *</span>';
-
-    # Fields colors.
-    $field_class = '';
-    $row_class = '';
+    $label .= mandatory_sign ($submitter, $field_name);
+    $field_class = $row_class = '';
     if ($j % 2 && $field_name != 'details')
-      {
-        # We keep the original submission with the default
-        # background color, for lisibility sake.
-        #
-        # We also use the boxitem background color only one time
-        # out of two, to keep the page light.
-        $row_class = ' class="' . utils_altrow ($j + 1) . '"';
-      }
+      # We keep the original submission with the default background color.
+      # We also use the boxitem background color only one time
+      # out of two, to keep the page light.
+      $row_class = ' class="' . utils_altrow ($j + 1) . '"';
 
     # If we are working on the cookbook, present checkboxes to
     # defines context before the summary line;
     if (CONTEXT == 'cookbook' && $field_name == 'summary')
-      {
-        cookbook_print_form ();
-      }
+      cookbook_print_form ();
 
-    # We highlight fields that were not properly/completely
-    # filled.
     if ($previous_form_bad_fields
         && array_key_exists ($field_name, $previous_form_bad_fields))
-      {
-        $field_class = ' class="highlight"';
-      }
+      $field_class = ' class="highlight"';
     $td = "<td valign='middle'$field_class";
 
     if ($sz > $max_size)
       {
         # Field getting one line for itself.
-
         # Each time prepare the change of the background color.
         $j++;
 
-        print "\n<tr$row_class>$td width='15%'>"
-          . "$label$star</td>\n$td colspan=\""
+        print "\n<tr$row_class>$td width='15%'>$label</td>\n$td colspan=\""
           . (2 * $fields_per_line - 1) . '" width="75%">'
           . "$value</td>\n</tr>\n";
           $i = 0;
+          continue;
       }
-    else
+    # Field getting half of a line for itself.
+    if (!($i % $fields_per_line))
       {
-        # Field getting half of a line for itself.
-        if (!($i % $fields_per_line))
-          {
-            # Every one out of two, prepare the background color change.
-            # We do that at this moment because we cannot be sure
-            # there will be another field on this line.
-            $j++;
-          }
-
-        print ($i % $fields_per_line? '': "\n<tr$row_class>");
-        print "$td width='15%'>$label$star</td>\n$td width='35%'>"
-          . "$value</td>\n";
-        $i++;
-        print ($i % $fields_per_line? '': "</tr>\n");
+        # Every one out of two, prepare the background color change.
+        # We do that at this moment because we cannot be sure
+        # there will be another field on this line.
+        $j++;
       }
+    if (!($i % $fields_per_line))
+      print  "\n<tr$row_class>";
+    print "$td width='15%'>$label</td>\n$td width='35%'>$value</td>\n";
+    if (!(++$i % $fields_per_line))
+      print "</tr>\n";
   } # while ($field_name = trackers_list_all_fields ())
 
 print "</table>\n";
@@ -398,124 +381,113 @@ $is_deployed = [];
 $is_deployed["postcomment"] = false;
 if ($preview)
   $is_deployed["postcomment"] = $enable_comments;
-$is_deployed["discussion"] = true;
-$is_deployed["attached"] = true;
+$is_deployed["discussion"] = $is_deployed["attached"] = true;
 $is_deployed["dependencies"] = true;
-$is_deployed["cc"] = false;
-$is_deployed["votes"] = false;
-$is_deployed["reassign"] = false;
+$is_deployed["cc"] = $is_deployed["votes"] = $is_deployed["reassign"] = false;
 
 # If at the second step of any two-step activity (add deps, reassign,
 # multiple canned answer), deploy only the relevant:
 # first set them all to false without question and then set to true only
 # the relevant.
-if ($depends_search || $canned_response == "!multiple!"
-    || $reassign_change_project_search)
+if ($depends_search || $reassign_change_group_search)
   {
     foreach ($is_deployed as $key => $value)
       $is_deployed[$key] = false;
 
     if ($depends_search)
       $is_deployed["dependencies"] = true;
-    if ($canned_response == "!multiple!")
-      $is_deployed["postcomment"] = true;
-    if ($reassign_change_project_search)
+    if ($reassign_change_group_search)
       $is_deployed["reassign"] = true;
   }
 
-$canned_text = trackers_data_append_canned_response ('', $canned_response);
-
 if ($comment === null)
   $comment = '';
 
 if (isset ($quote_no))
   {
     $quote = trackers_data_quote_comment ($item_id, $quote_no);
+    $cr = $canned_response;
     if ($quote === false)
       {
         # No comment to quote found, probably quoting the preview.
         $preview = true;
-        $quote = $canned_text;
-        if (!empty ($canned_text))
-          $canned_response = '!multiple!';
-        $canned_text = '';
+        $quote = '';
+        if (!empty ($canned_response))
+          $canned_response = [];
       }
-    $comment .= $quote;
+    $comment = trackers_data_append_canned_response ("$comment$quote", $cr);
   }
 if (!empty ($comment))
   $is_deployed['postcomment'] = $enable_comments;
 
-function print_comment_types ($group_id, $comment_type_id)
+function print_comment_types ($group_id, $comment_type_id, $comment_types)
 {
   global $preview, $anon_check_failed;
 
-  $comment_types =
-    trackers_data_get_field_predefined_values ('comment_type_id', $group_id);
   if (db_numrows ($comment_types) <= 1)
     {
       unset ($GLOBALS['comment_type_id']);
-      return;
+      return 0;
     }
-  print "<label for='comment_type_id'>". _("Comment type:") . "</label>\n";
+  print "<span class='preinput'>";
+  print html_label ('comment_type_id', _("Comment type:")) . "</span>\n";
 
   $checked = '';
   if (($preview || !empty ($anon_check_failed)) && !empty ($comment_type_id))
     $checked = $comment_type_id;
   $box = trackers_field_box ('comment_type_id', '', $group_id, $checked, true);
   print "$box<br />\n";
+  return 1;
 }
 
-function print_canned_box ($group_id, $canned)
+function print_canned_box ($group_id, $canned, $size, $res_canned)
 {
   global $sys_home;
-  print "<label for='canned_response'>" . _("Canned response:") . "</label>\n";
-  print trackers_canned_response_box ($group_id, 'canned_response', $canned);
-  if (!user_ismember ($group_id, 'A'))
+  $group_admin = user_ismember ($group_id, 'A');
+  print "<span class='preinput'>";
+  print html_label ('canned_response[]', _("Canned response:"))
+    . "</span><br />\n";
+  print trackers_canned_response_box ($group_id, $canned, $size, $res_canned)
+    . "<br />\n";
+  if (!$group_admin)
     return;
   print "&nbsp;&nbsp;&nbsp;<a class='smaller' href=\"$sys_home"
     . ARTIFACT . "/admin/field_values.php?group_id=$group_id"
     . '&amp;create_canned=1">' . _("Define a new canned response") . '</a>';
 }
 
-function print_canned_checkboxes ($group_id, $canned_response)
-{
-  print _("Canned response:") . "\n";
-  $result = trackers_data_get_canned_responses ($group_id);
-  if (db_numrows ($result) <= 0)
-    {
-      print '<span class="warn">'
-        . _("Strangely enough, there is no canned response available.")
-        . '</span>';
-      return;
-    }
-  print '<div>';
-  $cra = is_array ($canned_response);
-  while ($canned = db_fetch_array ($result))
-    {
-      $id = $canned['bug_canned_id'];
-      $ck = $cra && in_array ($id, $canned_response);
-      print '&nbsp;&nbsp;&nbsp;';
-      print form_checkbox ("canned_response[]", $ck, ['value' => $id]);
-      print " {$canned['title']}<br />\n";
-    }
-  print "</div>\n";
-}
-
-function print_canned_selector ($group_id, $canned_response)
-{
-  if ($canned_response == "!multiple!" || is_array ($canned_response))
-    print_canned_checkboxes ($group_id, $canned_response);
-  else
-    print_canned_box ($group_id, $canned_response);
-}
-
-function print_comment_type_and_canned ($group_id, $canned_response, $ct_id)
+function print_comment_type_and_canned (
+  $group_id, $canned_response, $ct_id, $res_canned
+)
 {
+  global $sys_home;
   if (!user_ismember ($group_id))
     return;
-  print '<p class="noprint"><span class="preinput">';
-  print_comment_types ($group_id, $ct_id);
-  print_canned_selector ($group_id, $canned_response);
+  $canned_num = db_numrows ($res_canned);
+  $comment_types =
+    trackers_data_get_field_predefined_values ('comment_type_id', $group_id);
+  if ($canned_num == 0 && db_numrows ($comment_types) < 2)
+    return;
+  print "<p class='noprint'>";
+  if ($canned_num)
+    print "<br />\n";
+  $n = print_comment_types ($group_id, $ct_id, $comment_types);
+  if ($canned_num)
+    print_canned_box ($group_id, $canned_response, 11 - $n, $res_canned);
+  print "</p>\n";
+}
+
+function print_comment_box ($group_id, $comment, $have_canned)
+{
+  $float = '';
+  if (user_ismember ($group_id) && $have_canned)
+    $float = ' floatleft';
+  print "<p class='noprint$float'><span class='preinput'> "
+    . _("Add a New Comment") . ' ' . markup_info ("rich");
+  print form_submit (_('Preview'), 'preview')
+    . "</span><br />&nbsp;&nbsp;&nbsp;\n";
+  print trackers_field_textarea ('comment', utils_specialchars ($comment),
+    0, 0, _("New comment"));
   print "</p>\n";
 }
 
@@ -527,15 +499,11 @@ if ($enable_comments)
     if (!empty ($preambles[ARTIFACT . '_comment_preamble']))
       print markup_rich ($preambles[ARTIFACT . '_comment_preamble']);
 
-    print '<p class="noprint"><span class="preinput"> ' . _("Add a New Comment")
-      . ' ' . markup_info ("rich");
-    print form_submit (_('Preview'), 'preview')
-      . "</span><br />&nbsp;&nbsp;&nbsp;\n";
-    print trackers_field_textarea ('comment', utils_specialchars ($comment),
-      0, 0, _("New comment"));
-    print "</p>\n";
-    print_comment_type_and_canned ($group_id, $canned_response,
-      $comment_type_id
+    $res_canned = trackers_data_get_canned_responses ($group_id);
+    $canned_num = db_numrows ($res_canned);
+    print_comment_box ($group_id, $comment, $canned_num);
+    print_comment_type_and_canned (
+      $group_id, $canned_response, $comment_type_id, $res_canned
     );
     print html_hidsubpart_footer ();
   } # $enable_comments
@@ -547,10 +515,11 @@ if ($item_discussion_lock)
         . _("Your privileges however allow to override the lock.");
     print "</p>\n";
   }
-
 print html_hidsubpart_header ("discussion", _("Discussion"));
+if ($revert_comment_order)
+  print form_hidden (['revert_order' => 1]);
 
-$new_comment = false;
+$new_comment = [];
 if ($preview)
   {
     $new_comment['user_id'] = user_getid ();
@@ -564,7 +533,7 @@ if ($preview)
         trackers_data_get_cached_field_value (
           'comment_type_id', $group_id, $comment_type_id
         );
-    $comm = $comment . $canned_text;
+    $comm = trackers_data_append_canned_response ($comment, $canned_response);
     if (!empty ($comm))
       $comm = trackers_encode_value (utils_specialchars ($comm));
     $new_comment['old_value'] = $comm;
@@ -572,7 +541,7 @@ if ($preview)
     $new_comment['spamscore'] = '0';
   }
 print show_item_details (
-  $item_id, $group_id, 0, $item_assigned_to, $new_comment, $enable_comments
+  $item_id, $group_id, $item_assigned_to, $new_comment, $enable_comments
 );
 print "<p>&nbsp;</p>\n";
 print html_hidsubpart_footer ();
@@ -646,62 +615,45 @@ if ($is_trackeradmin)
 
     # Generate the list of searchable trackers.
     $tracker_list = [
-      'all'     => _("Any Tracker"),
-      'support' => _("The Support Tracker Only"),
-      'bugs'    => _("The Bug Tracker Only"),
-      'task'    => _("The Task Manager Only"),
-      'patch'   => _("The Patch Manager Only"),
+      'all'     => _("any tracker"),
+      'support' => _("the support tracker only"),
+      'bugs'    => _("the bug tracker only"),
+      'task'    => _("the task manager only"),
+      'patch'   => _("the patch manager only"),
     ];
 
     foreach ($tracker_list as $option_value => $text)
-      {
-        $selected = '';
-        if ($option_value == $depends_search_only_artifact)
-          $selected = ' selected="selected"';
-        $tracker_select .=
-          "<option value=\"$option_value\"$selected>$text</option>\n";
-      }
+      $tracker_select .=
+        form_option ($option_value, $depends_search_only_artifact, $text);
     $tracker_select .= "</select>\n";
 
-    $group_select = '<select title="' . _("Wether to search in any project")
-                    . '" name="depends_search_only_project">';
+    $group_select = '<select title="' . _("Wether to search in any group")
+      . '" name="depends_search_only_group">';
 
-    # By default, search restricted to the project (lighter for the CPU,
+    # By default, search restricted to the group (lighter for the CPU,
     # probably also more accurate).
-    $selected = '';
-    if ($depends_search_only_project == "any")
-      $selected = ' selected="selected"';
-    $group_select .= "<option value='any'$selected>"
+    $group_select .=
       # TRANSLATORS: this string is used in the context like
-      # "search an item of [The Bug Tracker Only] of [Any Project]".
-      . _("Any Project")
-      . "</option>\n";
-
-    # Not yet a select? It means we are in the default case.
-    if ($selected)
-      $selected = '';
-    else
-      $selected = ' selected="selected"';
-
+      # "search an item of [the bug tracker only] of [any group]".
+      form_option ('any', $depends_search_only_group, _("any group"));
+    $selected = 'val';
+    if ($depends_search_only_group != 'any')
+      $selected = 'notany';
     # TRANSLATORS: this string is used in the context like
-    # "search an item of [The Bug Tracker Only] of [This Project Only]".
-    $group_select .= "<option value='notany'$selected >"
-      . _("This Project Only") . "</option>\n</select>&nbsp;";
+    # "search an item of [the bug tracker only] of [this group only]".
+    $group_select .= form_option ('notany', $selected, _("this group only"))
+      . "</select>&nbsp;";
 
-    # TRANSLATORS: the first argument is tracker type (like The Bug Tracker),
-    # the second argument is either 'This Project Only' or 'Any Project'.
+    # TRANSLATORS: the first argument is tracker type (like the bug tracker),
+    # the second argument is either 'this group only' or 'any group'.
     printf (_('Of %1$s of %2$s'), $tracker_select, $group_select);
 
     if ($depends_search)
-      {
-        # Print a specific message if we are already at step 2 of filling
-        # a dependency.
-        print form_submit (_("New search"), "submit");
-      }
+      print form_submit (_("New search"), "submit");
     else
       print form_submit (_("Search"), "submit");
 
-    # Search results, if we are already at step 2 of filling.
+    # Search results, if we are already at step 2.
     if ($depends_search)
       {
         print "</p>\n<p><span class='preinput'>";
@@ -727,7 +679,7 @@ if ($is_trackeradmin)
             # Actually search on each asked trackers.
             foreach ($artifacts as $num => $tracker)
               {
-                if ($depends_search_only_project == "notany")
+                if ($depends_search_only_group == "notany")
                   $GLOBALS['only_group_id'] = $group_id;
 
                 # Do not ask for all words,
@@ -744,23 +696,23 @@ if ($is_trackeradmin)
                              $res_group) = db_fetch_array ($result_search))
                   {
                     # Avoid item depending on itself.
-                    # Hide private items. For now, they are excluded for
-                    # dependencies. We'll implement that later if necessary.
-                    if ($res_privacy == 2)
+                    # Hide private items unless accessible.
+                    if (
+                      $res_privacy == 2 && !member_check_private (0, $res_group)
+                    )
                       continue;
                     if ($res_id != $item_id || $tracker != ARTIFACT)
                       {
                          # Right now only print id, summary and group.
                          # We may change that depending on users feedback.
                          print "<br />\n";
+                         $label = "$tracker #$res_id: $res_summary, "
+                           . _("group") . ' ' . group_getname ($res_group);
                          print '&nbsp;&nbsp;&nbsp;'
                            . form_checkbox (
                                "dependent_on_{$tracker}[]", 0,
-                               ['value' => $res_id]
-                             )
-                           . " $tracker # $res_id: $res_summary";
-                         print ', ' . _("group") . ' '
-                           . group_getname ($res_group);
+                               ['value' => $res_id, 'label' => $label]
+                             );
                       }
                     }
               } # foreach ($artifacts as $num => $tracker)
@@ -783,7 +735,7 @@ print html_hidsubpart_footer ();
 
 print
   html_hidsubpart_header ("cc", _("Mail Notification Carbon-Copy List"));
-if (user_isloggedin() && !$item_discussion_lock)
+if ($is_trackeradmin)
   {
     print '<p class="noprint">';
     # TRANSLATORS: the argument is site name (like Savannah).
@@ -794,13 +746,13 @@ if (user_isloggedin() && !$item_discussion_lock)
     );
 
     print "</p>\n"
-      . "<p class='noprint'><span class='preinput'><label for='add_cc'>"
-      . _("Add Email Addresses (comma as separator):")
-      . "</label></span><br />\n&nbsp;&nbsp;&nbsp;"
+      . "<p class='noprint'><span class='preinput'>"
+      . html_label ('add_cc', _("Add Email Addresses (comma as separator):"))
+      . "</span><br />\n&nbsp;&nbsp;&nbsp;"
       . form_input ('text', 'add_cc', $add_cc,  'size="40"')
-      . '&nbsp;&nbsp;&nbsp;'
-      . "\n<br />\n<span class='preinput'><label for='cc_comment'>"
-      . _("Comment:") . "</label></span><br />\n&nbsp;&nbsp;&nbsp;"
+      . "&nbsp;&nbsp;&nbsp;\n<br />\n<span class='preinput'>"
+      . html_label ('cc_comment', _("Comment:"))
+      . "</span><br />\n&nbsp;&nbsp;&nbsp;"
       . form_input ('text', "cc_comment", $cc_comment,
           'size="40" maxlength="255"')
       . "\n";
@@ -838,7 +790,7 @@ $display_votes = function ($group_id, $item_id, $votes,  $new_vote, $lock)
   if (!(trackers_data_is_showed_on_add ("vote")
       || member_check (user_getid(), $group_id)))
     {
-      print '<span class="warn">' . _("Only project members can vote.")
+      print '<span class="warn">' . _("Only group members can vote.")
         . "</span>$end";
       return;
     }
@@ -848,20 +800,16 @@ $display_votes = function ($group_id, $item_id, $votes,  $new_vote, $lock)
          . "</span>$end";
        return;
     }
-  $votes_given = trackers_votes_user_giventoitem_count (
-    user_getid (), ARTIFACT, $item_id
-  );
-  $votes_remaining =
-    trackers_votes_user_remains_count (user_getid ()) + $votes_given;
+  $votes_given = trackers_get_user_votes (ARTIFACT, $item_id);
+  $votes_remaining = trackers_votes_remaining () + $votes_given;
   if (!$new_vote)
     $new_vote = $votes_given;
 
   # Show how many vote he already gave and allows to remove
   # or give more votes.
   # The number of remaining points must be 100 - others votes.
-  print '<span class="preinput"><label for="new_vote">'
-    . _("Your vote:")
-    . "</label></span><br />\n&nbsp;&nbsp;&nbsp;"
+  print '<span class="preinput">' . html_label ('new_vote', _("Your vote:"))
+    . "</span><br />\n&nbsp;&nbsp;&nbsp;"
     . '<input type="text" name="new_vote" id="new_vote" '
     . "size='3' maxlength='3' value='$new_vote' /> ";
   printf (
@@ -879,7 +827,7 @@ unset ($display_votes);
 
 # Reassign an item, if manager of the tracker.
 # Not possible on the cookbook manager, cookbook entries are too specific.
-if ($check_member ($group_id, ARTIFACT, '3') && ARTIFACT != "cookbook")
+if ($is_manager && ARTIFACT != "cookbook")
   {
     # No point in having this part printable.
     print '<span class="noprint">';
@@ -890,9 +838,8 @@ if ($check_member ($group_id, ARTIFACT, '3') && ARTIFACT != "cookbook")
         $checked = '';
         if (!$GLOBALS['reassign_change_artifact'] && ARTIFACT == $art
             || $GLOBALS['reassign_change_artifact'] == $art)
-          $checked = ' selected="selected"';
-        $ret = "<option value=\"$art\"$checked>$title</option>\n";
-        return $ret;
+          $checked = $art;
+        return form_option ($art, $checked, $title);
       }
     $tracker_select = '<select title="' . _("Tracker to reassign to")
                       . '" name="reassign_change_artifact">';
@@ -912,100 +859,81 @@ if ($check_member ($group_id, ARTIFACT, '3') && ARTIFACT != "cookbook")
 
     print "<br /><br />\n<span class='preinput'>";
 
-    if (!$reassign_change_project_search)
-      print _("Move to the project:");
+    if ($reassign_change_group_search)
+      print _("New search, in case the previous one was not satisfactory\n"
+              . "(to reassign the item to another group):");
     else
-      {
-        # Print a specific message if we are already at step 2 of
-        # reassignation to another project.
-        print _("New search, in case the previous one was not satisfactory\n"
-                . "(to reassign the item to another project):");
-      }
+      print _("Move to the group:");
 
     print "</span><br />\n&nbsp;&nbsp;&nbsp;"
-      . '<input type="text" title="' . _("Project to reassign item to")
-      . '" name="reassign_change_project_search" size="40" maxlength="255" />';
-    if (!$reassign_change_project_search)
-      print form_submit (_("Search"), "submit");
+      . '<input type="text" title="' . _("Group to reassign item to")
+      . '" name="reassign_change_group_search" size="40" maxlength="255" />';
+    if ($reassign_change_group_search)
+      print form_submit (_("New search"), "submit");
     else
-      {
-        # Print a specific message if we are already at step 2 of filling
-        # a ressign.
-        print form_submit (_("New search"), "submit");
-      }
+      print form_submit (_("Search"), "submit");
 
-    # Search results, if we are already at step 2 of filling.
-    if ($reassign_change_project_search)
+    # Search results, if we are already at step 2.
+    if ($reassign_change_group_search)
       {
         print "\n<p><span class='preinput'>";
         printf (
-          _("To which project this bug should be reassigned to? This is\n"
+          _("To which group this bug should be reassigned to? This is\n"
             . "the result of your search of '%s' in the database:"),
-          utils_specialchars ($reassign_change_project_search));
+          utils_specialchars ($reassign_change_group_search));
         print '</span>';
 
         # Print a null-option, someone may change his mine without having
         # to use the back button of his browser.
         print "<br />\n&nbsp;&nbsp;&nbsp;"
-          . '<input type="radio" name="reassign_change_project" '
+          . '<input type="radio" name="reassign_change_group" '
           . 'value="0" checked="checked" /> '
-          . _("Do not reassign to another project.");
+          . _("Do not reassign to another group.");
 
-        $success = false;
-        $result_search =
-          search_run ($reassign_change_project_search, "soft", 0);
-        $success = db_numrows ($result_search);
-
-        # Print the result, if existing.
-        if (db_numrows ($result_search) != 0)
+        $res = search_run ($reassign_change_group_search, "soft", 0);
+        $list_is_empty = true;
+        while (list ($grp_name, $ug_name, $grp_id) = db_fetch_array ($res))
           {
-            while (list ($res_group_name, $res_unix_group_name, $res_group_id)
-                   = db_fetch_array ($result_search))
-              {
-                # Not reassigning to itself.
-                if ($res_unix_group_name == $group)
-                  continue;
-                print "<br />\n&nbsp;&nbsp;&nbsp;"
-                  . form_input (
-                      "radio", "reassign_change_project", $res_unix_group_name
-                    )
-                  . " [$res_unix_group_name, #$res_group_id] $res_group_name";
-              }
+            if ($grp_id == $group_id) # Don't reassign to itself.
+              continue;
+            $list_is_empty = false;
+            print "<br />\n&nbsp;&nbsp;&nbsp;"
+              . form_input ("radio", "reassign_change_group", $ug_name)
+              . " [$ug_name, #$grp_id] $grp_name";
           }
-
-        if (!$success)
-          {
-            print "<br />\n<span class='warn'>";
-            print _("None found. Please note that only search words of more\n"
-                    . "than three characters are valid.");
-            print '</span>';
-          }
-      } # if ($reassign_change_project_search)
+        if ($list_is_empty)
+          print "<br />\n<span class='warn'>"
+            . _("None found. Please note that only search words of more\n"
+                . "than three characters are valid.")
+            . '</span>';
+      } # if ($reassign_change_group_search)
     print html_hidsubpart_footer ();
     print '</span>';
-  } # if ($check_member ($group_id, ARTIFACT, '3') && ARTIFACT != "cookbook")
+  } # if ($is_manager && ARTIFACT != "cookbook")
 
 if ($enable_comments)
   {
     # Minimal anti-spam.
     if (!user_isloggedin ())
-      print '<p class="noprint"><label for="check">'
-        . _("Please enter the title of <a\n"
-            . "href=\"https://en.wikipedia.org/wiki/George_Orwell\">"
-            . "George Orwell</a>'s famous\ndystopian book (it's a date):")
-        . "</label> <input type='text' id='check' name='check' /></p>\n";
+      print '<p class="noprint">'
+        . html_label ("check",
+            _("Please enter the title of <a\n"
+              . "href=\"https://en.wikipedia.org/wiki/George_Orwell\">"
+              . "George Orwell</a>'s famous\ndystopian book (it's a date):")
+          )
+        . " <input type='text' id='check' name='check' /></p>\n";
 
-    print "<p>&nbsp;</p>\n";
     print '<div align="center" class="noprint">'
-      . form_submit (_("Submit Changes and Browse Items"), "submit", 'class="bold"')
+      . form_submit (_("Preview"), "preview")
       . ' '
-      . form_submit (_("Submit Changes and Return to this Item"), "submitreturn")
+      . form_submit (_("Submit changes and browse items"), "submit", 'class="bold"')
+      . ' '
+      . form_submit (_("Submit changes and return to this item"), "submitreturn")
       . "</div>\n</form>\n";
   }
-print "<p>&nbsp;</p><p>&nbsp;</p>\n";
 print html_hidsubpart_header ("history", _("History"));
 show_item_history ($item_id, $group_id);
 print html_hidsubpart_footer ();
 
-trackers_footer ([]);
+trackers_footer ();
 ?>
