@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -335,7 +335,7 @@ function user_get_preference ($preference_name, $user_id = false)
 }
 
 # Find out if the user use the vote, very similar to
-# trackers_votes_user_remains_count.
+# trackers_votes_remaining.
 function user_use_votes ($user_id = false)
 {
   if (!$user_id)
@@ -400,11 +400,10 @@ $user_history_field_names = "(
 function user_has_history ($user_id)
 {
   global $user_history_field_names;
-  $trackers = ['bugs', 'support', 'task', 'patch', 'cookbook'];
   $name = user_fetch_name ($user_id);
   if ($name == '')
     return false;
-  foreach ($trackers as $tr)
+  foreach (utils_get_tracker_list () as $tr)
     {
       $result = db_execute (
         "SELECT bug_id FROM $tr WHERE submitted_by = ? LIMIT 1", [$user_id]
