@@ -6,7 +6,7 @@
 # Copyright (C) 2002-2006 Tobias Toedter <t.toedter--gmx.net>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -247,9 +247,9 @@ if (function_exists ("strftime"))
     # Used until strftime is dropped from PHP.
     function utils_strftime ($timestamp, $format)
     {
-      $old_level = error_reporting (E_ALL & ~E_DEPRECATED);
+      $state = utils_disable_warnings (E_DEPRECATED);
       $ret = strftime ($format, $timestamp);
-      error_reporting ($old_level);
+      utils_restore_warnings ($state);
       return $ret;
     }
   }
@@ -277,7 +277,7 @@ else # !function_exists ("strftime")
 # @see utils_date_to_unixtime()
 function utils_format_date ($timestamp, $format = "default")
 {
-  if ($timestamp == 0)
+  if (empty ($timestamp))
     return '-';
 
   $tm = localtime ($timestamp, true);
@@ -470,6 +470,11 @@ function show_priority_colors_key ()
   print  "</p>\n";
 }
 
+function utils_get_tracker_list ()
+{
+  return ['bugs', 'support', 'task', 'patch', 'cookbook'];
+}
+
 function utils_get_tracker_icon ($tracker)
 {
   if ($tracker == "bugs")
@@ -630,16 +635,17 @@ function utils_split_emails ($addresses)
   return explode (',', $addresses);
 }
 
-# Email Verification.
 function validate_email ($address)
 {
-  # FIXME: this allows in domain names some characters that are not allowed
+  if (empty ($address))
+    return false;
+  # FIXME: this allows some characters in domain names that are not allowed.
   return (preg_match (',^[-!#$%&\'*+\\./0-9=?A-Z^_`a-z{|}~]+'. '@'
                       . '[-!#$%&\'*+\\/0-9=?A-Z^_`a-z{|}~]+\.'
                       . '[-!#$%&\'*+\\./0-9=?A-Z^_`a-z{|}~]+$,', $address));
 }
 
-# Verification of comma separated list of email addresses.
+# Verify comma-separated list of email addresses.
 function validate_emails ($addresses)
 {
   $arr = utils_split_emails ($addresses);
@@ -708,16 +714,6 @@ function util_die ($msg)
   die ();
 }
 
-function util_feedback ($msg, $error = 0)
-{
-  fb ($msg, $error);
-}
-
-function feedback ($msg, $error = 0)
-{
-  fb ($msg, $error);
-}
-
 # Add feedback information.
 function fb ($msg, $error = 0)
 {
@@ -783,8 +779,10 @@ function utils_setcookie ($name, $value, $expire, $secure = false)
 
 function utils_set_csp_headers ()
 {
-  if (!empty ($GLOBALS['skip_csp_headers']) && $GLOBALS['skip_csp_headers'])
+  global $skip_csp_headers;
+  if (!empty ($skip_csp_headers))
     return;
+  $skip_csp_headers = true; # Only set the headers once.
   # Set up proper use of UTF-8, even if the webserver doesn't serve it by default.
   header('Content-Type: text/html; charset=utf-8');
   # Disallow embedding in any frames.
@@ -888,17 +886,26 @@ function utils_run_proc ($cmd, &$out, &$err, $aux = [])
   return $res;
 }
 
+function utils_disable_warnings ($level = E_ALL, $dry_run = false)
+{
+  if ($dry_run)
+    return null;
+  return [error_reporting (E_ALL ^ $level)];
+}
+
+function utils_restore_warnings ($state)
+{
+  if ($state !== null)
+    error_reporting ($state[0]);
+}
+
 # Try to move $tmp_path to $path without overwriting if the latter exists;
 # return $path when successful, $tmp_path otherwise.
 function utils_try_move ($tmp_path, $path)
 {
-  $link_error_handler = function ($errno, $errstr, $errfile, $errline)
-  {
-    # Ignore warning.
-  };
-  $old_handler = set_error_handler ($link_error_handler, E_WARNING);
+  $error_state = utils_disable_warnings (E_WARNING);
   $res = link ($tmp_path, $path);
-  set_error_handler ($old_handler, E_WARNING);
+  utils_restore_warnings ($error_state);
   if (!$res) # Already exists; fallback to temporary file name.
     return $tmp_path;
   unlink ($tmp_path);
@@ -955,7 +962,7 @@ function utils_make_upload_file ($tarball_name, &$errors)
       $errors = "$res: $err";
       return null;
     }
-  $out = substr ($out, 0, strlen ($out) - 1); # Remove trailing "\n".
+  $out = substr ($out, 0, -1); # Remove trailing "\n".
   return utils_try_move ($out, $path);
 }
 
@@ -965,9 +972,14 @@ function utils_str_join ($separator, $str, $n)
   return str_repeat ("$str$separator", $n - 1) . $str;
 }
 
-function utils_srand ()
+# Return a random number from 0 to $end.
+# For sensitive tokens, use random_bytes instead.
+function utils_mt_rand ($end = 1000000)
 {
-  mt_srand ((int)((double)microtime () * 1000000));
+  $micro = 1000000;
+  $t = (int)(microtime (true) * $micro);
+  mt_srand ($t % $micro);
+  return mt_rand (0, $end);
 }
 
 function utils_placeholders ($array)
@@ -1023,5 +1035,12 @@ function utils_urlencode ($string)
     $string = '';
   return urlencode ($string);
 }
+function utils_disable_cache ()
+{
+  header ("Expires: Wed, 11 Nov 1998 11:11:11 GMT");
+  header ("Cache-Control: max-age=0");
+  header ("Cache-Control: no-cache", false);
+  header ("Cache-Control: must-revalidate", false);
+}
 } # namespace {
 ?>
