@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -50,9 +50,10 @@ define ('PUBLIC_UNLINK', 10);
 
 $key_func = ['preg', '/^(\d+|new)$/'];
 $list_name_func = ['name', ['min_len' => 0, 'max_len' => 80]];
+$submit_buttons = ['post_changes', 'add_list'];
 extract (sane_import ('post',
   [
-    'true' => ['post_changes', 'add_list'],
+    'true' => $submit_buttons,
     'digits' => 'newlist_format_index',
     'array' =>
       [
@@ -64,6 +65,7 @@ extract (sane_import ('post',
       ],
   ]
 ));
+form_check ($submit_buttons);
 
 if (!$group_id)
   exit_no_group ();
@@ -242,7 +244,7 @@ print
     . "reflected here.");
 print "</p>\n";
 
-print form_header ($_SERVER['PHP_SELF']);
+print form_header ();
 print form_hidden (["post_changes" => "y", "group_id" => $group_id]);
 
 while ($row = db_fetch_array ($result))
