@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -44,7 +44,7 @@
 require_once ('../../include/init.php');
 session_require (['isloggedin' => '1']);
 
-$trackers = ['bugs', 'task', 'patch', 'support', 'cookbook'];
+$trackers = utils_get_tracker_list ();
 $user_id = user_getid ();
 $user_email = user_getemail ();
 $user_name = user_getname ();
@@ -101,7 +101,7 @@ foreach ($trackers as $tracker)
   {
     $result = db_execute ("
       SELECT g.unix_group_name, g.group_name, t.group_id
-      FROM groups g, $tracker t, ${tracker}_cc cc
+      FROM groups g, $tracker t, {$tracker}_cc cc
       WHERE
         g.group_id = t.group_id AND t.bug_id = cc.bug_id
         AND cc.email IN (?, ?, ?)
