@@ -7,7 +7,7 @@
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
 # Copyright (C) 2008-2017, 2020 Karl Berry
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -50,6 +50,7 @@ require_once ('../../include/gpg.php');
 require (utils_get_content_filename ("gpg-sample"));
 
 session_require (['isloggedin' => '1']);
+$submit_buttons = ['update', 'test_gpg_key'];
 extract (sane_import ('request',
   [
     'strings' =>
@@ -60,11 +61,13 @@ extract (sane_import ('request',
         ],
         ['step', ['confirm', 'confirm2', 'discard']],
       ],
-    'true' => ['update', 'test_gpg_key'],
-    'hash' => ['session_hash', 'confirm_hash', 'form_id'],
+    'true' => $submit_buttons,
+    'hash' => ['session_hash', 'confirm_hash'],
   ]
 ));
 
+form_check ($submit_buttons);
+
 if (!$item)
   exit_missing_param ();
 
@@ -104,9 +107,6 @@ if ($item == 'delete')
 # Update the database.
 if ($update)
   {
-    if (!form_check ($form_id))
-      exit_error (_("Exiting"));
-
     # Update the database and redirect to account conf page.
     if ($item == "realname")
       {
@@ -283,8 +283,7 @@ if ($update)
                       sprintf (_("-- the %s team."), $sys_name) . "\n";
 
                     $success = sendmail_mail (
-                      [ 'from' => "$sys_mail_replyto@$sys_mail_domain",
-                        'to' => $newvalue],
+                      ['to' => $newvalue],
                       [ 'subject' => $sys_name . ' ' . _("Verification"),
                         'body' => $message]
                     );
@@ -301,8 +300,7 @@ if ($update)
                     # The next step is probably to print the mail change
                     # request on account with the possibility to discard.
                     sendmail_mail (
-                      [ 'from' => "$sys_mail_replyto@$sys_mail_domain",
-                        'to' => $row_user['email']],
+                      ['to' => $row_user['email']],
                       [ 'subject' => $sys_name . ' ' . _("Verification"),
                         'body' => $warning_message]
                     );
@@ -445,8 +443,7 @@ if ($update)
                 # TRANSLATORS: the argument is site name (like Savannah).
                 $message .= sprintf (_("-- the %s team."), $sys_name) . "\n";
                 $success = sendmail_mail (
-                  [ 'from' => "$sys_mail_replyto@$sys_mail_domain",
-                    'to' => $row_user['email']],
+                  ['to' => $row_user['email']],
                   [ 'subject' => $sys_name . ' ' . _("Verification"),
                     'body' => $message]
                 );
@@ -553,7 +550,7 @@ elseif ($item == "timezone")
 elseif ($item == "password")
   {
     $title = _("Change Password");
-    $preamble = account_password_help();
+    $preamble = account_password_help ();
     $input_titles = [
       _("Current password:"), _("New password / passphrase:"),
       _("Re-type new password:"),
@@ -619,8 +616,7 @@ elseif ($item == "email")
         $input_titles = [_('Confirmation hash:')];
         $input_specific = "<input type='text' readonly='readonly' "
           . "name='confirm_hash' value='$confirm_hash' />";
-        $input_specific .=
-          "<input type='hidden' name='step' value='confirm2' />";
+        $input_specific .= form_hidden (['step' => 'confirm2']);
       }
     elseif ($step == "discard")
       {
@@ -652,7 +648,7 @@ elseif ($item == "delete")
         $input_titles = [_('Confirmation hash:')];
         $input_specific = "<input type='text' readonly='readonly' "
           . 'name="confirm_hash" value="' . $confirm_hash . '" />'
-          . "<input type='hidden' name='step' value='confirm2' />";
+          . form_hidden (['step' => 'confirm2']);
       }
     elseif ($step == 'discard')
       {
@@ -660,7 +656,7 @@ elseif ($item == "delete")
         $input_titles = [_('Discard hash:')];
         $input_specific = "<input type='text' readonly='readonly' "
           . "name='confirm_hash' value='$confirm_hash' />"
-          . "<input type='hidden' name='step' value='discard' />";
+          . form_hidden (['step' => 'discard']);
       }
   }
 
@@ -674,7 +670,7 @@ if (empty ($input_titles[0]))
 if ($preamble)
   print "<p>$preamble</p>\n";
 
-print form_header ($_SERVER['PHP_SELF'], false, "post");
+print form_header ();
 
 $input_spec = [$input_specific];
 for ($i = 0; $i < 3; $i++)
@@ -697,7 +693,7 @@ for ($i = 0; $i < 3; $i++)
     print "<br />\n";
   }
 
-print "<input type='hidden' name='item' value=\"$item\" />\n";
+print form_hidden (['item' => $item]);
 print '<p>' . form_submit (_("Update")) . "</p>\n</form>\n";
 site_user_footer ([]);
 ?>
