@@ -4,7 +4,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -39,19 +39,22 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-require_once ('../../include/sane.php');
-require_once ('../../include/utils.php');
-require_once ('../../include/form.php');
+foreach (['sane', 'utils', 'form'] as $i)
+  require_once ("../../include/$i.php");
+$pref_list = ['email_encrypted', 'nonfixed_feedback', 'keep_only_one_session',
+  'quiet_ssh', 'reverse_comments_order', 'stone_age_menu', 'use_bookmarks'
+];
+$pref_fb_on_set = [
+ 'stone_age_menu' =>
+   _("Stone age menu activated, it will be effective the next time "
+     . "a page is loaded")
+];
+$true_fields = ['update', 'theme_rotate_jump', 'form_email_hide'];
+foreach ($pref_list as $p)
+  $true_fields[] = "form_$p";
 extract (sane_import ('post',
   [
-    'true' =>
-      [
-        'update', 'form_keep_only_one_session', 'theme_rotate_jump',
-        'form_reverse_comments_order', 'form_stone_age_menu',
-        'form_nonfixed_feedback', 'form_use_bookmarks', 'form_email_hide',
-        'form_email_encrypted'
-      ],
+    'true' => $true_fields,
     'no_quotes' => ['form_timezone', 'user_theme']
   ]
 ));
@@ -89,35 +92,30 @@ if ($update)
         fb (_("Failed to update the database"),1);
     }
   }
+# FIXME init.php has to be included after parsing POST variables and defining
+# update_theme that may be used in theme.php that is included in init.php.
+# This isn't the most clear possible way to do these things.
 require_once ('../../include/init.php');
 require_once ('../../include/timezones.php');
+form_check ('update');
 extract (sane_import ('request', ['pass' => 'feedback']));
 session_require (['isloggedin' => 1]);
 
-if ($update)
-  {
-    function sync_preference ($pref, $note = null)
+function sync_preference ($pref)
+{
+  global $pref_fb_on_set;
+  if ($GLOBALS["form_$pref"] == "1")
     {
-      if ($GLOBALS["form_$pref"] == "1")
-        {
-          user_set_preference ($pref, 1);
-          if ($note !== null)
-            fb ($note);
-        }
-      else
-        user_unset_preference ($pref);
+      user_set_preference ($pref, 1);
+      if (array_key_exists ($pref, $pref_fb_on_set))
+        fb ($pref_fb_on_set[$pref]);
     }
-    sync_preference ('use_bookmarks');
-    sync_preference ('email_encrypted');
-    sync_preference ('nonfixed_feedback');
-    sync_preference (
-      'stone_age_menu',
-       _("Stone age menu activated, it will be effective the next time "
-         . "a page is\nloaded")
-    );
-    sync_preference ('reverse_comments_order');
-    sync_preference ('keep_only_one_session');
-  }
+  else
+    user_unset_preference ($pref);
+}
+if ($update)
+  foreach ($pref_list as $p)
+    sync_preference ($p);
 
 # Print form and links.
 site_user_header (['context' => 'account']);
@@ -131,7 +129,7 @@ print '<p>' . _("You can change all of your account features from here.")
   . "</p>\n";
 utils_get_content ("account/index_intro");
 print form_tag ();
-print '<h2>' . _("Significant Arrangements") . "</h2>\n";
+print html_h (2, _("Significant Arrangements"));
 
 print $HTML->box_top (_('Authentication Setup'));
 print '<p><a href="change.php?item=password">' . _("Change Password")
@@ -141,14 +139,7 @@ print '<p class="smaller">'
 utils_get_content ("account/index_passwd");
 print "</p>\n";
 
-# Get shared key count from DB.
-$expl_keys = explode ("###", $row_user['authorized_keys']);
-
-# If the last 'key' is empty, then it is because of a trailing separator;
-# so do not count it.
-$keynum = (sizeof ($expl_keys));
-if ($expl_keys[$keynum-1] == "")
-  $keynum--;
+$keynum = (count (account_get_authorized_keys ()));
 
 $i = 0;
 function print_box_next_item ()
@@ -212,6 +203,9 @@ print '<p class="smaller">'
       . "time, killing previous\nsessions each time you log in.");
 print "</p>\n";
 print $HTML->box_bottom ();
+$update_btn = '<p class="center"><span class="clearr" />'
+  . form_submit (_("Update")) . "</span></p>\n";
+print $update_btn;
 
 print $HTML->box_top (_('Identity Record'));
 
@@ -282,12 +276,7 @@ print '<p class="smaller">' . _("Here, you can cancel all mail notifications.")
 
 print $HTML->box_bottom ();
 
-$update_btn = '<p class="center"><span class="clearr" />'
-  . '<input type="submit" name="update" value="'
-  . _("Update") . "\" /></span></p>\n";
-print $update_btn;
-
-print "\n<h2>" . _("Secondary Arrangements") . "</h2>\n";
+print html_h (2, _("Secondary Arrangements"));
 
 print $HTML->box_top (_('Optional Features'));
 
@@ -323,7 +312,15 @@ print '<p class="smaller">'
       . "If no suitable key is available, the messages still go unencrypted.")
   . "</p>\n";
 
+$i++;
+print_box_next_item ();
+pref_cbox ('quiet_ssh', _("Quiet SSH member shell"));
+print '<p class="smaller">'
+  . _("Suppress the message that offers Savane source code when using SSH.")
+  . "</p>\n";
+
 print $HTML->box_bottom ();
+print $update_btn;
 print $HTML->box_top (_('Cosmetics Setup'));
 
 # The select box comes before the name of the category so all the clickable
@@ -418,11 +415,8 @@ print '<p class="smaller">'
    . "</p>\n";
 
 print $HTML->box_bottom ();
-
-print $update_btn;
-print "</form>\n";
-
-print "\n<h2>" . _('Account Deletion') . "</h2>\n";
+print "$update_btn</form>\n";
+print html_h (2, _('Account Deletion'));
 
 print '<p><a href="change.php?item=delete">' . _("Delete Account")
   . "</a></p>\n";
