@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -52,7 +52,7 @@ extract (sane_import ('get',
     'digits' => 'dtime',
     'preg' =>
       [
-        ['dip_addr', ',^[\d./:]+$,'],
+        ['dip_addr', ',^[[:xdigit:]./:]+$,'],
         ['dsession_hash', '/^[a-f\d]+[.]{3}$/']
       ],
   ]
