@@ -6,7 +6,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -124,15 +124,14 @@ function send_pending_user_email ($group_id, $user_id, $user_message)
   );
 }
 
-# Request for inclusion.
+$submits = ['update', 'searchgroup'];
 extract (sane_import ('post',
   [
-    'true' => 'update',
-    'hash' => 'form_id',
-    'pass' => 'form_message',
+    'true' => $submits, 'pass' => 'form_message',
     'array' => [['form_groups', ['digits', 'true']]],
   ]
 ));
+form_check ($submits);
 
 if ($update)
   {
@@ -140,11 +139,6 @@ if ($update)
       SELECT group_id FROM groups WHERE status = 'A' AND is_public = '1'
       ORDER BY group_id"
     );
-    # Check for duplicates.
-    if (!form_check ($form_id))
-      return 0;
-    $form_cleaned_already = false;
-
     while ($val = db_fetch_array ($result_upd))
       {
         if (!isset ($form_groups[$val['group_id']]))
@@ -170,11 +164,6 @@ if ($update)
         send_pending_user_email (
           $val['group_id'], $row_user['user_id'], $form_message
         );
-        if (!$form_cleaned_already)
-          {
-            form_clean ($form_id);
-            $form_cleaned_already = 1;
-          }
       }
   } # if ($update)
 
@@ -279,11 +268,12 @@ print
     . "this form.");
 print "</p>\n\n";
 
-print form_tag () . form_hidden (['action' => 'searchgroup']);
+print form_tag () . form_hidden (['searchgroup' => '1']);
 print form_input ('text', 'words', $words,
   "title=\"" . _("Group to look for") . "\" size='35'");
 print "<br /><br />\n";
-print form_submit (_("Search Groups"), "Submit", false, true);
+$int_trapisset = true;
+print form_submit (_("Search Groups"), "Submit");
 print "</form>\n\n</div><!-- end boxitem -->\n";
 
 extract (sane_import ('request', ['pass' => 'words']));
@@ -319,7 +309,7 @@ if ($words)
           _("To request inclusion in one or several groups, check the\n"
             . "boxes, write a meaningful message for group administrator\n"
             . "who will approve or discard the request, and submit the form.");
-        print "</p>\n" . form_header ($_SERVER['PHP_SELF']);
+        print "</p>\n" . form_header ();
 
         while ($val = db_fetch_array ($result_search))
           {
@@ -329,20 +319,22 @@ if ($words)
                 print _('(already a member)') . "<br />\n";
                 continue;
               }
-            print form_checkbox ("form_groups[{$val['group_id']}]")
-              . "\n<label for=\"form_groups[{$val['group_id']}]\">";
-            print "{$val['group_name']}</label><br />\n";
+            print form_checkbox ("form_groups[{$val['group_id']}]") . "\n"
+              . html_label (
+                  "form_groups[{$val['group_id']}]", $val['group_name']
+                )
+              . "<br />\n";
           }
 
-        print "<br />\n<label for='form_message'>" . _("Comments (required):")
-          . "</label><br />\n"
+        print "<br />\n"
+          . html_label ('form_message', _("Comments (required):")) . "<br />\n"
           . "<textarea name='form_message' id='form_message' cols='40'\n"
           . "rows='7'></textarea><br /><br />\n";
-        print form_submit (_("Request Inclusion"), 'update', false, true);
+        print form_submit (_("Request Inclusion"), 'update');
         print "</form>\n";
       }
     print "</div><!-- end boxitemalt -->\n";
-  }
+  } # if ($words)
 print $HTML->box_bottom (1);
 print html_splitpage (2);
 
