@@ -6,7 +6,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -48,9 +48,10 @@ require_once ('../include/form.php');
 require_once ('../include/sendmail.php');
 
 session_require (['isloggedin'=>'1']);
-
+$submits = ['confirm', 'cancel'];
 extract (sane_import ('request', ['digits' => 'quitting_group_id']));
-extract (sane_import ('post', ['true' => ['confirm', 'cancel']]));
+extract (sane_import ('post', ['true' => $submits]));
+form_check ($submits);
 
 $pending = member_check_pending (0, $quitting_group_id);
 
@@ -98,12 +99,8 @@ function notify_admins ($quitting_group_id)
         . "($user_name <$login>)\nhas chosen to quit the group.\n\n"
         . "As result, the group is orphan.\n";
     }
-  $from = "$sys_mail_replyto@$sys_mail_domain";
   $subject = "$user_name has quit the group $group_name";
-  sendmail_mail (
-    ['from' => $from, 'to' => $to],
-    ['subject' => $subject, 'body' => $message]
-  );
+  sendmail_mail (['to' => $to], ['subject' => $subject, 'body' => $message]);
 }
 
 # If we get here, the user is actually member of the group.
@@ -116,19 +113,18 @@ if ($confirm || $pending)
     if (!$pending)
       notify_admins ($quitting_group_id);
     session_redirect ($GLOBALS['sys_home'] . "my/groups.php");
+    exit (0);
   }
-else
-  {
-    site_user_header (['title' => _("Quit a group"), 'context' => 'mygroups']);
-    print form_tag ();
-    print form_hidden (["quitting_group_id" => $quitting_group_id]);
-    print '<span class="preinput">';
-    printf (_("You are about to leave the group %s, please confirm:"),
-      group_getname ($quitting_group_id)
-    );
-    print '</span>';
-    print '<div class="center"><input type="submit" name="confirm" value="'
-      . _("Confirm") . '" /> <input type="submit" name="cancel" value="'
-      . _("Cancel") . "\" /></div>\n</form>\n";
-  }
+site_user_header (['title' => _("Quit a group"), 'context' => 'mygroups']);
+print form_tag ();
+print form_hidden (["quitting_group_id" => $quitting_group_id]);
+print '<span class="preinput">';
+printf (_("You are about to leave the group %s, please confirm:"),
+  group_getname ($quitting_group_id)
+);
+print "</span>\n";
+print '<div class="center">'
+  . form_submit (_("Confirm"), "confirm") . "\n"
+  . form_submit (_("Cancel"), "cancel")
+  . "</div>\n</form>\n";
 ?>
