@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -42,24 +42,26 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 require_once ('../include/init.php');
 require_once ('../include/html.php');
-require_directory ("trackers");
+require_once ('../include/trackers/general.php');
+require_once ('../include/trackers/votes.php');
 
 extract (sane_import ('post',
   [
-    'true' => 'submit',
+    'true' => 'update',
     'array' => [['new_votes', ['digits', 'digits']]],
   ]
 ));
+form_check ('update');
 
-if (!user_isloggedin())
-  exit_not_logged_in();
-$remaining_votes = trackers_votes_user_remains_count(user_getid());
+if (!user_isloggedin ())
+  exit_not_logged_in ();
+$remaining_votes = trackers_votes_remaining ();
 
-if ($submit)
+if ($update)
   {
     $result = db_execute ("
        SELECT vote_id, tracker, item_id FROM user_votes
-       WHERE user_id = ?  ORDER BY howmuch DESC, item_id ASC LIMIT 100",
+       WHERE user_id = ? ORDER BY howmuch DESC, item_id ASC LIMIT 100",
        [user_getid ()]
     );
     unset($count);
@@ -86,7 +88,7 @@ if ($submit)
         trackers_votes_update ($new_votes_list_item_id[$vote_id],
           $new_vote, $new_votes_list_tracker[$vote_id]
         );
-    $remaining_votes = trackers_votes_user_remains_count (user_getid ());
+    $remaining_votes = trackers_votes_remaining ();
   }
 site_user_header (['context' => 'votes']);
 # Simple listing. No need of anything really fancy, there will be no more
@@ -126,16 +128,15 @@ if ($remaining_votes < 100)
           util_die ($msg);
         $res_item = db_execute ("
           SELECT summary, vote, status_id, priority, group_id
-          FROM $tr WHERE bug_id = ? LIMIT 1",
-          [$row['item_id']]
+          FROM $tr WHERE bug_id = ? LIMIT 1", [$row['item_id']]
         );
+        $res_row = db_fetch_array ($res_item);
 
         $prefix = utils_get_tracker_prefix ($tr);
         $icon = utils_get_tracker_icon ($tr);
-        $vote = db_result ($res_item, 0, 'vote');
+        $vote = $res_row['vote'];
         $color = utils_get_priority_color (
-          db_result ($res_item, 0, 'priority'),
-          db_result ($res_item, 0, 'status_id')
+          $res_row['priority'], $res_row['status_id']
         );
 
         print "<div class=\"$color\">\n"
@@ -148,17 +149,15 @@ if ($remaining_votes < 100)
           . html_image ("contexts/$icon.png",
               ['class' => "icon", 'alt' => $tr]
             )
-          . db_result ($res_item, 0, 'summary') . ', '
+          . $res_row['summary'] . ', '
           . sprintf (ngettext ("%s vote", "%s votes", $vote), $vote)
           . "&nbsp;<span class=\"xsmall\">($prefix #{$row['item_id']}, "
-          . group_getname (db_result ($res_item, 0, 'group_id'))
-          . ")</span></a></div>\n";
+          . group_getname ($res_row['group_id']) . ")</span></a></div>\n";
       }
 
-    print "<br />\n<div align=\"center\" class=\"noprint\">"
-      . '<input type="submit" name="submit" class="bold" value="'
-      . _("Submit Changes") . "\" /></div>\n</form>\n";
-    print "\n\n" . show_priority_colors_key();
+    print "<br />\n"
+      . form_footer (_("Submit Changes"));
+    print "\n\n" . show_priority_colors_key ();
   }
 $HTML->footer ([]);
 ?>
