@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -45,16 +45,17 @@ require_once ('../include/init.php');
 require_once ('../include/sendmail.php');
 require_once ('../include/news/general.php');
 
-extract (sane_import ('all',
+$submits = ['post_changes', 'approve'];
+extract (sane_import ('request',
   [
     'digits' => ['id', 'status'],
     'strings' => [['status', ['0', '4', '5']]],
-    'hash' => 'form_id',
-    'true' => ['update', 'post_changes', 'approve'],
     'specialchars' => ['summary', 'details'],
+    'true' => 'show'
   ]
 ));
-
+extract (sane_import ('post', ['true' => $submits]));
+form_check ($submits);
 if (!($group_id && member_check (0, $group_id, 'N3')))
   exit_error (_("Action unavailable: only news managers can approve news."));
 
@@ -64,14 +65,12 @@ if ($post_changes && $approve)
     [ 'id' => $id, 'status' => $status, 'summary' => $summary,
       'details' => $details]
   );
-if ($post_changes)
-  $approve = null;
 
 site_project_header (
   ['title' => _("Manage"), 'group' => $group_id, 'context' => 'news']
 );
 
-if ($approve)
+if ($show)
   {
     $result = db_execute ("
       SELECT * FROM news_bytes WHERE id = ? AND group_id = ?", [$id, $group_id]
