@@ -3,7 +3,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -42,13 +42,21 @@ require_once ('../include/init.php');
 require_once ('../include/form.php');
 require_once ('../include/news/general.php');
 
-if (!$group_id)
-  $group_id = $sys_group_id;
-
 extract (sane_import ('request',
   ['pass' => 'feedback', 'digits' => ['id', 'limit']])
 );
 
+if ($id)
+  $news_item = news_fetch_item ($id);
+
+if (!$group_id)
+  {
+    if (!empty ($news_item))
+      $group_id = $news_item['group_id'];
+    if (!$group_id)
+      $group_id = $sys_group_id;
+  }
+
 if (empty ($limit))
   $limit = 10;
 else
@@ -60,9 +68,9 @@ if (!$project->Uses ("news"))
 
 site_project_header (['group' => $group_id, 'context' => 'news']);
 
-if ($id)
+if (!empty ($news_item))
   {
-    news_show_news_item ($id);
+    news_show_news_item ($news_item);
     site_project_footer ([]);
     exit;
   }
