@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -44,12 +44,9 @@
 require_once ('../include/init.php');
 
 extract (sane_import ('post',
-  [
-    'hash' => 'form_id',
-    'true' => 'update',
-    'specialchars' => ['summary', 'details'],
-  ]
+  ['true' => 'update', 'specialchars' => ['summary', 'details']]
 ));
+form_check ('update');
 
 if (!group_restrictions_check ($group_id, "news"))
   {
@@ -61,14 +58,8 @@ if (!group_restrictions_check ($group_id, "news"))
 
 if ($update)
   {
-    $valid = form_check ($form_id);
-    if (!$summary)
-      {
-        fb (_("Title is missing"), 1);
-        $valid = 0;
-      }
     $result = false;
-    if ($valid)
+    if ($summary)
       {
         $t = time ();
         $fields = [ 'group_id' => $group_id, 'submitted_by' => user_getid (),
@@ -77,11 +68,12 @@ if ($update)
         ];
         $result = db_autoexecute ('news_bytes', $fields, DB_AUTOQUERY_INSERT);
       }
+    else
+      fb (_("Title is missing"), 1);
     if ($result)
       {
         $feedback = _("News Posted: it will need to be approved by a news "
          . "manager of this group before it shows on the front page.");
-        form_clean ($form_id);
         session_redirect (
           "{$sys_home}news/?group=$group&feedback="
           . utils_urlencode ($feedback)
@@ -100,15 +92,13 @@ site_project_header (
 print '<p class="warn">'
   . _("A news manager of this group will have to review and approve the news.")
   . "</p>\n"
-  . form_header ($_SERVER['PHP_SELF'], $form_id)
-  . form_hidden (["group_id" => $group_id])
+  . form_header () . form_hidden (["group_id" => $group_id])
   . "<span class='preinput'>" . html_label ('summary', _("Subject:"))
   . "</span><br/>&nbsp;&nbsp;\n"
-  . "<input type='text' id='summary' name='summary' value=\"$summary\" "
-  . "size='65' maxlength='80' /><br />\n"
-  . "<span class='preinput'>" . html_label ('details', _("Details"))
+  . form_input ('text', 'summary', $summary, "size='65' maxlength='80'")
+  . "<br />\n<span class='preinput'>" . html_label ('details', _("Details"))
   . markup_info ("full") . "</span><br />&nbsp;&nbsp;\n"
-  . "<textarea name='details' id='details' rows='20' cols='65' wrap='soft'>\n"
-  . "$details</textarea><br />\n" . form_footer ();
+  . form_textarea ('details', $details, "rows='20' cols='65' wrap='soft'")
+  . "<br />\n" . form_footer ();
 site_project_footer ([]);
 ?>
