@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -71,7 +71,6 @@ print form_tag (['action' => $GLOBALS['sys_home'] . 'people/editjob.php'])
   . "</b><br />\n"
   . form_textarea ('description', '', 'rows="10" cols="60" wrap="soft"')
   . "</p>\n<p>"
-  . '<input type="submit" name="add_job" value="'
-  . _("continue >>") . "\" />\n</p>\n</form>\n";
+  . form_submit (_("continue >>"), "add_job") . "\n</p>\n</form>\n";
 site_project_footer ([]);
 ?>
