@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -41,15 +41,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-require_once('../../include/init.php');
-require_directory("trackers");
+require_once ('../../include/init.php');
+require_directory ("trackers");
 
 extract (sane_import ('post',
-  [
-    'true' => 'update',
-    'digits' => 'from_group_id',
-    'artifact' => 'artifact',
-  ]
+  ['true' => 'update', 'digits' => 'from_group_id', 'artifact' => 'artifact']
 ));
 
 if (!$group_id)
@@ -58,8 +54,12 @@ if (!$group_id)
 if (!user_ismember ($group_id, 'A'))
   exit_permission_denied ();
 
-if ($update && $from_group_id != 100)
-  trackers_conf_copy ($group_id, $artifact, $from_group_id);
+if ($update && !in_array ($from_group_id, [0, 100]))
+  {
+    if (empty ($artifact))
+      exit_missing_param (['artifact']);
+    trackers_conf_copy ($group_id, $artifact, $from_group_id);
+  }
 
 site_project_header (
   [
@@ -68,19 +68,14 @@ site_project_header (
   ]
 );
 
-$print_h2 = function ($x)
-{
-  print '<h2>' . $x . "</h2>\n";
-};
-
-$print_h2 (_("Support Tracker Configuration Copy"));
-conf_form ($group_id, "support");
-$print_h2 (_("Bug Tracker Configuration Copy"));
-conf_form ($group_id, "bugs");
-$print_h2 (_("Task Tracker Configuration Copy"));
-conf_form ($group_id, "task");
-$print_h2 (_("Patch Tracker Configuration Copy"));
-conf_form ($group_id, "patch");
+print html_h (2, _("Support Tracker Configuration Copy"));
+trackers_conf_form ($group_id, "support");
+print html_h (2, _("Bug Tracker Configuration Copy"));
+trackers_conf_form ($group_id, "bugs");
+print html_h (2, _("Task Tracker Configuration Copy"));
+trackers_conf_form ($group_id, "task");
+print html_h (2, _("Patch Tracker Configuration Copy"));
+trackers_conf_form ($group_id, "patch");
 
 site_project_footer ([]);
 ?>
