@@ -6,7 +6,7 @@
 # Copyright (C) 2008 Aleix Conchillo Flaque
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -42,11 +42,9 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-require_once('../../include/init.php');
-require_once('../../include/sane.php');
-
-session_require(array('group' => $group_id,
-                      'admin_flags' => 'A'));
+require_once ('../../include/init.php');
+require_once ('../../include/sane.php');
+session_require (['group' => $group_id, 'admin_flags' => 'A']);
 
 $post_names = function ()
 {
@@ -81,8 +79,34 @@ function str_match ($needle, $haystack)
   return strpos ($haystack, $needle) !== false;
 }
 
+function field_usable ($group, $field, $field_name)
+{
+  if ($group->CanUse ($field_name))
+    return true;
+  if ($field_name == "extralink_documentation")
+    return true;
+  if ($field == "url_cvs_viewcvs_homepage" && $group->CanUse ("homepage"))
+    return true;
+  foreach (['cvs', 'arch', 'svn', 'git', 'hg', 'bzr'] as $vcs)
+    if ($field == "url_{$vcs}_viewcvs" && $group->CanUse ($vcs))
+      return true;
+  return false;
+}
+
+function type_usable ($group, $type, $field_name, $field)
+{
+  if ($type == "use")
+    return 1;
+  if ($type == "url")
+    return $group->CanModifyUrl ($field_name);
+  return
+    $type == "dir" && $field == "dir_download" && $group->CanUse ("download")
+    && $group->CanModifyDir ("download_dir");
+}
+
 $names = $post_names ();
 extract (sane_import ('post', $names));
+form_check ('update');
 
 $query = sane_import ('get',
   ['specialchars' => 'feedback', 'digits' => 'error']
@@ -92,8 +116,6 @@ if ($query['feedback'])
   fb ($query['feedback'], $query['error']);
 
 $project = project_get_object ($group_id);
-
-# If this was a submission, make updates.
 if ($update)
   {
     #FIXME: feeds the database with default values... instead of checkbox,
@@ -115,38 +137,16 @@ if ($update)
       }
 
     $cases = $get_cases ($names);
-    $upd_list = array();
+    $upd_list = [];
 
     foreach ($cases as $field)
       {
-        $field_name = substr($field, 4, strlen($field));
-        $type = substr($field, 0, 3);
-
-        if ($project->CanUse($field_name)
-            || ($field_name == "extralink_documentation")
-            || ($field == "url_cvs_viewcvs_homepage"
-                && $project->CanUse("homepage"))
-            || ($field == "url_cvs_viewcvs" && $project->CanUse("cvs"))
-            || ($field == "url_arch_viewcvs" && $project->CanUse("arch"))
-            || ($field == "url_svn_viewcvs" && $project->CanUse("svn"))
-            || ($field == "url_git_viewcvs" && $project->CanUse("git"))
-            || ($field == "url_hg_viewcvs" && $project->CanUse("hg"))
-            || ($field == "url_bzr_viewcvs" && $project->CanUse("bzr")))
-          {
-            if ($type == "use")
-              $upd_list[$field] = $$field;
-            elseif ($type == "url")
-              {
-                if ($project->CanModifyUrl($field_name))
-                  $upd_list[$field] = $$field;
-              }
-            elseif ($type == "dir" && $field == "dir_download"
-                    && $project->CanUse("download")
-                    && $project->CanModifyDir("download_dir"))
-              {
-                $upd_list[$field] = $$field;
-              }
-          }
+        $field_name = substr ($field, 4);
+        if (!field_usable ($project, $field, $field_name))
+          continue;
+        $type = substr ($field, 0, 3);
+        if (type_usable ($project, $type, $field_name, $field))
+          $upd_list[$field] = $$field;
       }
 
     if ($upd_list)
@@ -170,7 +170,9 @@ site_project_header (
   ['title' => _("Select Features"),'group' => $group_id, 'context' => 'ahome']
 );
 
-$next_td = function (&$i)
+$i = 0;
+
+$next_td = function ($i)
 {
   print ' <td class="' . utils_altrow ($i) . '">';
 };
@@ -186,7 +188,7 @@ function specific_line ($artifact, $explanation, $use, $increment=1)
     $i++;
   print "<tr>\n";
   $next_td ($i);
-  print "<label for=\"use_$artifact\">$explanation</td>\n";
+  print html_label ("use_$artifact", $explanation) . "</td>\n";
   $next_td ($i);
   # Print the checkbox to de/activate it
   # (viewcvs cannot be activated or deactivated, they are not in the menu).
@@ -219,21 +221,21 @@ function specific_line ($artifact, $explanation, $use, $increment=1)
       || str_match ("viewcvs", $artifact) || str_match ("extralink", $artifact))
     $url = $project->getUrl($artifact);
   else
-    $url = $project->getArtifactUrl($artifact);
+    $url = $project->getArtifactUrl ($artifact);
   $url = utils_specialchars_decode ($url, ENT_QUOTES);
   $extra = 'size="20" title="' . _("Alternative Address") . '"';
   print form_input ("text", "url_$artifact", $url, $extra) . $tail;
 }
 
 print '<p>';
-print _("You can activate or deactivate feature/artifact for your project. In
-some cases, depending on the system administrator's choices, you can even use
-change the URL for a feature/artifact. If the field &ldquo;alternative
-address&rdquo; is empty, the standard is used.");
+print
+  _("You can activate or deactivate feature for your group. In some cases, "
+    . "depending on the system administrator's choices, you can "
+    . "even use change the URL for a feature. If the field "
+    . "&ldquo;alternative address&rdquo; is empty, the standard is used.");
 print "</p>\n";
 
-print form_header ($_SERVER['PHP_SELF'])
-  . form_input ("hidden", "group_id", $group_id);
+print form_header () . form_hidden (["group_id" => $group_id]);
 
 print html_build_list_table_top (
   [
@@ -242,16 +244,18 @@ print html_build_list_table_top (
   ]
 );
 
-if ($project->CanUse("homepage"))
+if ($project->CanUse ("homepage"))
   {
-    specific_line("homepage", _("Homepage"), $project->Uses("homepage"));
-    specific_line("cvs_viewcvs_homepage",
-                  _("Homepage Source Code Web Browsing"), 0, 0);
+    specific_line ("homepage", _("Homepage"), $project->Uses("homepage"));
+    specific_line ("cvs_viewcvs_homepage",
+      _("Homepage Source Code Web Browsing"), 0, 0
+    );
   }
 
-if ($project->CanModifyUrl("extralink_documentation"))
-  specific_line("extralink_documentation", _("Documentation"),
-                $project->Uses("extralink_documentation"));
+if ($project->CanModifyUrl ("extralink_documentation"))
+  specific_line ("extralink_documentation", _("Documentation"),
+    $project->Uses("extralink_documentation")
+  );
 
 function specific_can_use ($project, $artifact, $explanation)
 {
@@ -260,7 +264,7 @@ function specific_can_use ($project, $artifact, $explanation)
 }
 specific_can_use ($project, "download", _("Download Area"));
 
-if ($project->CanUse("download") && $project->CanModifyDir("download_dir"))
+if ($project->CanUse ("download") && $project->CanModifyDir("download_dir"))
   {
     $i++; print '<tr>';
     $next_td ($i);
@@ -275,45 +279,30 @@ if ($project->CanUse("download") && $project->CanModifyDir("download_dir"))
     $next_td ($i);
     print ' '
       . form_input (
-          "text", "dir_download", $project->getDir("download"), 'size="20"'
+          "text", "dir_download", $project->getDir ("download"), 'size="20"'
         );
     print "</td>\n</tr>\n";
   }
 
-if ($project->CanUse("cvs") || $project->CanUse("homepage"))
+if ($project->CanUse ("cvs") || $project->CanUse ("homepage"))
   {
-    specific_line("cvs", _("CVS"), $project->Uses("cvs"));
-    specific_line("cvs_viewcvs", _("CVS Web Browsing"), 0, 0);
-  }
-if ($project->CanUse("arch"))
-  {
-    specific_line("arch", _("GNU Arch"), $project->Uses("arch"));
-    specific_line("arch_viewcvs", _("Arch Web Browsing"), 0, 0);
-  }
-
-if ($project->CanUse("svn"))
-  {
-    specific_line("svn", _("Subversion"), $project->Uses("svn"));
-    specific_line("svn_viewcvs", _("Subversion Web Browsing"), 0, 0);
-  }
-
-if ($project->CanUse("git"))
-  {
-    specific_line("git", _("Git"), $project->Uses("git"));
-    specific_line("git_viewcvs", _("Git Web Browsing"), 0, 0);
-  }
-
-if ($project->CanUse("hg"))
-  {
-    specific_line("hg", _("Mercurial"), $project->Uses("hg"));
-    specific_line("hg_viewcvs", _("Mercurial Web Browsing"), 0, 0);
-  }
-
-if ($project->CanUse("bzr"))
-  {
-    specific_line("bzr", _("Bazaar"), $project->Uses("bzr"));
-    specific_line("bzr_viewcvs", _("Bazaar Web Browsing"), 0, 0);
+    specific_line ("cvs", _("CVS"), $project->Uses ("cvs"));
+    specific_line ("cvs_viewcvs", _("CVS Web Browsing"), 0, 0);
   }
+foreach (
+  [
+    'arch' => [_("GNU Arch"), _("Arch Web Browsing")],
+    'svn' => [_("Subversion"), _("Subversion Web Browsing")],
+    'git' => [_("Git"), _("Git Web Browsing")],
+    'hg' => [_("Mercurial"), _("Mercurial Web Browsing")],
+    'bzr' => [_("Bazaar"), _("Bazaar Web Browsing")]
+  ] as $vcs => $labels
+)
+  if ($project->CanUse ($vcs))
+    {
+      specific_line ($vcs, $labels[0], $project->Uses ($vcs));
+      specific_line ("{$vcs}_viewcvs", $labels[1], 0, 0);
+    }
 
 foreach (
   [
@@ -324,7 +313,7 @@ foreach (
 )
   specific_can_use ($project, $k, $v);
 
-$HTML->box1_bottom();
-print form_footer();
-site_project_footer(array());
+print "</table>\n";
+print form_footer ();
+site_project_footer ();
 ?>
