@@ -6,7 +6,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -48,26 +48,27 @@ require_once ('../../include/gpg.php');
 $gpg_heading_level = 3;
 require (utils_get_content_filename ("gpg-sample"));
 
+$submit_buttons = [
+  'update', 'update_keyring', 'reset_keyring', 'test_keyring'
+];
+
 extract (sane_import ('post',
   [
-    'true' =>
-      [
-        'update', 'update_keyring', 'reset_keyring', 'test_keyring',
-        'upgrade_gpl',
-      ],
+    'true' => array_merge (['upgrade_gpl'], $submit_buttons),
     'pass' => ['new_keyring', 'form_longdesc'],
     'specialchars' => ['form_group_name', 'form_shortdesc'],
     'digits' => 'form_devel_status',
   ]
 ));
+form_check ($submit_buttons);
 
 session_require (['group' => $group_id, 'admin_flags' => 'A']);
 
 # Update info for page.
 $res_grp = db_execute ("SELECT * FROM groups WHERE group_id = ?", [$group_id]);
 if (db_numrows ($res_grp) < 1)
-  exit_no_group( );
-$row_grp = db_fetch_array( $res_grp);
+  exit_no_group ();
+$row_grp = db_fetch_array ($res_grp);
 
 $keyring = group_get_preference ($group_id, 'gpg_keyring');
 
@@ -124,15 +125,14 @@ site_project_header (
     'context' => 'ahome']
 );
 
-print form_header ($_SERVER['PHP_SELF'], $extra = 'name=""')
-  . form_hidden (["group_id" => $group_id]);
+print form_header () . form_hidden (["group_id" => $group_id]);
 
 $print_preinput = function ($label, $name, $markup = '')
 {
   if (!empty ($markup))
     $markup = ' ' . markup_info ($markup);
-  print "<p><span class='preinput'><label for='$name'>"
-    . "$label</label>$markup</span><br />\n&nbsp;&nbsp;&nbsp;";
+  print "<p><span class='preinput'>" . html_label ($name, $label)
+    . "$markup</span><br />\n&nbsp;&nbsp;&nbsp;";
 };
 
 $print_preinput (_("Group Name:"), 'form_group_name');
@@ -173,12 +173,7 @@ if ($project->CanUse ("devel_status"))
     print  '<select name="form_devel_status" id="form_devel_status">';
 
     foreach ($DEVEL_STATUS as $k => $v)
-      {
-        print "<option value=\"$k\"";
-        if ($k == $row_grp['devel_status'])
-          print ' selected';
-        print ">$v</option>\n";
-      }
+      print form_option ($k, $row_grp['devel_status'], $v);
     print "</select></p>\n";
   }
 
@@ -192,23 +187,17 @@ if ($project->getLicense () == 'gpl')
   {
     print '<p><span class="preinput">' . _("GNU GPL v3:")
       . "</span>\n<br />&nbsp;&nbsp;";
-    print form_checkbox ("upgrade_gpl");
-    print "\n<label for=\"upgrade_gpl\">"
-      . _("Upgrade license to &quot;GNU GPLv3 or later&quot;");
-    print "</label></p>\n";
+    print form_checkbox ("upgrade_gpl") . "\n";
+    print html_label (
+      "upgrade_gpl", _("Upgrade license to &quot;GNU GPLv3 or later&quot;")
+    );
+    print "</p>\n";
   }
 
-print form_footer ();
+print form_submit ();
 
-print "\n<h2>" . _("GPG Keys Used for Releases") . "</h2>\n";
-
-print $gpg_sample_text;
-
-print form_header ($_SERVER['PHP_SELF'])
-  . form_hidden (["group_id" => $group_id]);
-
-if ($project->getTypeBaseHost () == "savannah.gnu.org")
-  print $gpg_gnu_maintainers_note;
+print html_h (2, _("GPG Keys Used for Releases"));
+gpg_sample_output ();
 
 if (!$new_keyring)
   $new_keyring = $keyring;
