@@ -6,7 +6,7 @@
 #  Copyright (C) 2002-2006 Yves Perrin <yves.perrin--cern.ch>
 #  Copyright (C) 2014, 2016, 2017 Assaf Gordon
 #  Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-#  Copyright (C) 2013, 2014, 2017-2023 Ineiev
+#  Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -54,6 +54,7 @@ extract (sane_import ('post',
     'digits' => [['form_frequency', [0, 3]]],
   ]
 ));
+form_check ('update');
 
 if (empty ($form_news_address))
   $form_news_address = '';
@@ -87,27 +88,18 @@ site_project_header (
 );
 print form_tag () . form_hidden (['group_id' => $group_id]);
 
-function print_h2 ($x)
-{
-  print "<h2>$x</h2>\n";
-}
-
-$show_intro = 1;
 foreach ($artifacts as $art => $label)
   {
-    print_h2 ($label);
-    trackers_data_show_notification_settings ($group_id, $art, $show_intro);
-    $show_intro = 0;
+    print html_h (2, $label);
+    trackers_data_show_notification_settings ($group_id, $art);
     print "<br />\n";
   }
-print_h2 (_("News Manager Email Notification Settings"));
+print html_h (2, _("News Manager Email Notification Settings"));
 print '<span class="preinput">' . _("Carbon-Copy List:")
   . "</span><br />\n&nbsp;&nbsp;"
   . form_input ('text', 'form_news_address', $row_grp['new_news_address'],
       "size='40' maxlength='255'")
   . "<br /><br />\n";
-
-print "\n<p align='center'><input type='submit' name='update' value='"
-  . _("Update") . "' />\n</form>\n";
+print form_footer (_("Update"));
 site_project_footer ([]);
 ?>
