@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -44,16 +44,14 @@
 require_once ('../../include/init.php');
 require_once ('../../include/account.php');
 
+$submit_buttons = [
+  'update', 'update_general', 'update_delete_step1', 'update_delete_step2',
+  'add_to_squad', 'remove_from_squad'
+];
 extract (sane_import ('request', ['digits' => 'squad_id']));
 extract (sane_import ('post',
   [
-    'true' =>
-      [
-        'update', 'update_general', 'update_delete_step1',
-        'update_delete_step2', 'deletionconfirmed', 'add_to_squad',
-        'remove_from_squad',
-      ],
-    'hash' => 'form_id',
+    'true' => array_merge ($submit_buttons, ['deletionconfirmed']),
     'array' => [['user_ids', ['digits', 'digits']]],
     'digits' => ['squad_id_to_delete'],
      # form_realname is sanitized further.
@@ -65,7 +63,9 @@ extract (sane_import ('post',
 session_require (['group' => $group_id, 'admin_flags' => 'A']);
 
 if (!$group_id)
-  exit_no_group();
+  exit_no_group ();
+
+form_check ($submit_buttons);
 
 function finish_page ()
 {
@@ -104,12 +104,9 @@ function confirm_squad_deletion ($group_id, $squad_id, $realname, $squad_name)
   );
   print '<p>' . _('This action cannot be undone.') . "</p>\n";
 
-  print form_header ($_SERVER["PHP_SELF"]);
-  print form_input( "hidden", "group_id", $group_id);
-  # Do not pass the squad id as $squad_id, because if $squad_id is defined
-  # the software will try show the squad details, even if it has been
-  # removed, while we want the list of existing squads.
-  print form_input( "hidden", "squad_id_to_delete", $squad_id);
+  print form_header ();
+  print form_hidden (["group_id" => $group_id]);
+  print form_hidden (["squad_id_to_delete" => $squad_id]);
   print '<p><span class="preinput">'
     . _("Do you really want to delete this squad account?")
     . "</span></p>\n";
@@ -168,24 +165,24 @@ if ($squad_id)
           else
             # TRANSLATORS: the argument is user's name.
             $str = _("User %s is not part of the squad.");
-          fb (sprintf ($str, user_getname($user)), !$ok);
+          fb (sprintf ($str, user_getname ($user)), !$ok);
         }
 
-    site_project_header(array('title' => _("Manage Squads"),
-                              'group' => $group_id,
-                              'context' => 'ahome'));
+    site_project_header (
+      [ 'title' => _("Manage Squads"), 'group' => $group_id,
+        'context' => 'ahome']
+    );
 
-    print form_header($_SERVER["PHP_SELF"]);
-    print form_input("hidden", "group_id", $group_id);
-    print form_input("hidden", "squad_id", $squad_id);
+    print form_header ();
+    print form_hidden (["group_id" => $group_id, "squad_id" => $squad_id]);
     print '<p><span class="preinput"><label for="form_realname">'
           . _("Real Name:") . "</label></span><br />\n&nbsp;&nbsp;";
-    print form_input("text", "form_realname", $realname)
-                     . " &lt;$squad_name&gt;</p>\n";
-    print form_submit(_("Update"), "update_general") . ' '
-          . form_submit(_("Delete Squad"), "update_delete_step1") . "</form>\n";
+    print form_input ("text", "form_realname", $realname)
+      . " &lt;$squad_name&gt;</p>\n";
+    print form_submit (_("Update"), "update_general") . ' '
+      . form_submit (_("Delete Squad"), "update_delete_step1") . "</form>\n";
 
-    print '<h2>' . _("Removing members") . "</h2>\n";
+    print html_h (2, _("Removing members"));
 
     $result_delusers = db_execute ("
       SELECT user.user_id, user.user_name, user.realname
@@ -196,70 +193,69 @@ if ($squad_id)
    );
 
     print "<p>"
-. _("To remove members from the squad, select their names and push the button
-below.") . "</p>\n";
-    print form_header($_SERVER["PHP_SELF"]);
-    print form_input("hidden", "group_id", $group_id);
-    print form_input("hidden", "squad_id", $squad_id);
-    print '&nbsp;&nbsp;<select title="' . _("Users")
-          . '" name="user_ids[]" size="10" multiple="multiple">';
+      . _("To remove members from the squad, select their names and push the "
+          . "button\nbelow.")
+      . "</p>\n";
+    print form_header ();
+    print form_hidden (["group_id" => $group_id, "squad_id" => $squad_id]);
+    $sel_head = '&nbsp;&nbsp;<select title="' . _("Users")
+      . '" name="user_ids[]" size="10" multiple="multiple">';
+    $select = $sel_head;
     $exists = false;
-    $already_in_squad = array();
-    while ($thisuser = db_fetch_array($result_delusers))
+    $already_in_squad = [];
+    while ($thisuser = db_fetch_array ($result_delusers))
       {
-        print '<option value="' . $thisuser['user_id'] . '">'
-          . $thisuser['realname']
-          . ' &lt;' . $thisuser['user_name'] . "&gt;</option>\n";
+        $select .= form_option ($thisuser['user_id'], null,
+          $thisuser['realname'] . ' &lt;' . $thisuser['user_name'] . "&gt;"
+        );
         $already_in_squad[$thisuser['user_id']] = true;
         $exists = true;
       }
+    $users_none_found =
+      html_h (3, _("Users")) . "\n<p>" . _("None found") . "</p>\n";
 
-    if (!$exists)
-      print '<option>' . _("None found") . "</option>\n";
-    print '</select>';
-    print "<br />\n" . form_submit(_("Remove Members"), "remove_from_squad")
-          . "</form>\n";
-
-    print '<h2>' . _("Adding members") . "</h2>\n";
-
+    if ($exists)
+      print "$select</select><br />\n";
+    else
+      print $users_none_found;
+    print form_submit (_("Remove Members"), "remove_from_squad") . "</form>\n";
+    print html_h (2, _("Adding members"));
     $result_addusers =  db_execute ("
       SELECT user.user_id, user.user_name, user.realname
       FROM user, user_group
       WHERE
         user.user_id=user_group.user_id AND user_group.group_id = ?
         AND admin_flags <> 'P' AND admin_flags <> 'SQD'
-      ORDER BY user.user_name",
-      array($group_id)
+      ORDER BY user.user_name", [$group_id]
     );
 
     print "<p>"
-. _("To add members to the squad, select their name and push the button below.")
-. "</p>\n";
-    print form_header($_SERVER["PHP_SELF"]);
-    print form_input("hidden", "group_id", $group_id);
-    print form_input("hidden", "squad_id", $squad_id);
-    print '&nbsp;&nbsp;<select title="' . ("Users")
-      . '" name="user_ids[]" size="10" multiple="multiple">';
+      . _("To add members to the squad, select their name and push the button "
+          . "below.")
+      . "</p>\n";
+    print form_header ();
+    print form_hidden (["group_id" => $group_id, "squad_id" => $squad_id]);
+    $select = $sel_head;
     $exists = false;
-    while ($thisuser = db_fetch_array($result_addusers))
+    while ($thisuser = db_fetch_array ($result_addusers))
       {
         # Ignore if previously found as member.
-          if (array_key_exists($thisuser['user_id'], $already_in_squad))
-            continue;
-
-        print "<option value=\"{$thisuser['user_id']}\">{$thisuser['realname']}"
-          . " &lt;{$thisuser['user_name']}&gt;</option>\n";
+        if (array_key_exists ($thisuser['user_id'], $already_in_squad))
+          continue;
+        $select .= form_option ($thisuser['user_id'], null,
+          "{$thisuser['realname']}" . " &lt;{$thisuser['user_name']}&gt;"
+        );
         $exists = true;
       }
 
-    if (!$exists)
-      print '<option>' . _("None found") . "</option>\n";
-    print "</select>\n";
-    print "<br />\n" . form_submit(_("Add Members"), "add_to_squad")
-          . "</form>\n";
-    print '<h2>' . _("Setting permissions") . "</h2>\n";
+    if ($exists)
+      print "$select</select><br />\n";
+    else
+      print $users_none_found;
+    print form_submit (_("Add Members"), "add_to_squad") . "</form>\n";
+    print html_h (2, _("Setting permissions"));
     print "<p><a href=\"userperms.php?group=$group#$squad_name\">"
-          . _("Set Permissions") . "</a></p>\n";
+      . _("Set Permissions") . "</a></p>\n";
     finish_page ();
   } # if ($squad_id)
 
@@ -291,7 +287,7 @@ function validate_loginname ($form_loginname, $group)
 
 function create_squad (&$form_loginname, &$form_realname, $group)
 {
-  global $form_id, $group_id, $sys_mail_replyto, $sys_mail_domain;
+  global $group_id, $sys_mail_replyto, $sys_mail_domain;
 
   $result = db_autoexecute (
     'user',
@@ -299,13 +295,13 @@ function create_squad (&$form_loginname, &$form_realname, $group)
       'user_name' => strtolower ($group . "-" . $form_loginname),
       'user_pw' => 'ignored', 'realname' => $form_realname,
       'email' => "{$sys_mail_replyto}@{$sys_mail_domain}",
-      'add_date' => time(), 'status' => 'SQD', 'email_hide' => 1,
+      'add_date' => time (), 'status' => 'SQD', 'email_hide' => 1,
     ],
     DB_AUTOQUERY_INSERT
   );
   if (db_affected_rows ($result) <= 0)
     {
-      fb(_("Error during squad creation"));
+      fb (_("Error during squad creation"));
       return;
     }
   fb (_("Squad created"));
@@ -313,15 +309,15 @@ function create_squad (&$form_loginname, &$form_realname, $group)
   member_add ($created_squad_id, $group_id, 'SQD');
 
   # Clear variables so the form below will be empty.
-  $form_id = $form_loginname = $form_realname = null;
+  $form_loginname = $form_realname = null;
 }
 
-if ($update && form_check ($form_id))
+if ($update)
   {
     if (!$form_loginname)
-      fb(_("You must supply a username."), 1);
+      fb (_("You must supply a username."), 1);
     if (!$form_realname)
-      fb(_("You must supply a non-empty real name."), 1);
+      fb (_("You must supply a non-empty real name."), 1);
 
     if (
       $form_loginname && $form_realname
@@ -344,10 +340,10 @@ if ($update_delete_step2 && $deletionconfirmed == "yes")
     );
 
     if (!db_numrows ($delete_result))
-      exit_error(_("Squad not found"));
+      exit_error (_("Squad not found"));
 
-    fb(_("Squad deleted"));
-    member_remove($squad_id_to_delete, $group_id);
+    fb (_("Squad deleted"));
+    member_remove ($squad_id_to_delete, $group_id);
   }
 
 $result = db_execute ("
@@ -365,10 +361,11 @@ site_project_header (
 );
 
 print '<p>'
-. _("Squads can be assigned items, share permissions. Creating squads is useful
-if you want to assign some items to several members at once.") . "</p>\n";
+  . _("Squads can be assigned items, share permissions. Creating squads is "
+    . "useful\nif you want to assign some items to several members at once.")
+  . "</p>\n";
 
-print '<h2 id="form">' . _("Squad List") . "</h2>\n";
+print html_h (2, _("Squad List"), ['id' => 'form']);
 
 if ($rows < 1)
   print '<p class="warn">' . _("None found") . "</p>\n";
@@ -376,11 +373,9 @@ else
   {
     print "<ul>\n";
     while ($squad = db_fetch_array ($result))
-      {
-        print "<li><a href=\"?squad_id={$squad['user_id']}&amp;group_id="
-              . "$group_id\">{$squad['realname']} &lt;"
-              . "{$squad['user_name']}&gt;</a></li>\n";
-      }
+      print "<li><a href=\"?squad_id={$squad['user_id']}&amp;"
+        . "group_id=$group_id\">{$squad['realname']} "
+        . "&lt;{$squad['user_name']}&gt;</a></li>\n";
     print "</ul>\n";
   }
 
@@ -388,7 +383,7 @@ else
 # restriction by creating fake users, but the point is only to incitate
 # to create squads only if necessary, not to really enforce something
 # important).
-print '<h2>' . _("Create a New Squad") . "</h2>\n";
+print html_h (2, _("Create a New Squad"));
 
 $result = db_execute ("
   SELECT user_id FROM user_group
@@ -397,14 +392,15 @@ $result = db_execute ("
 );
 if ($rows < db_numrows ($result))
   {
-    print form_header ($_SERVER["PHP_SELF"] . '#form', $form_id);
-    print form_input ("hidden", "group_id", $group_id);
+    print form_header ("$php_self#form");
+    print form_hidden (["group_id" => $group_id]);
     print '<p><span class="preinput"><label for="form_loginname">'
-      . _ ("Squad Login Name:") . "</label></span>\n<br />&nbsp;&nbsp;";
-    print "$group-" . form_input("text", "form_loginname", $form_loginname)
+      . _("Squad Login Name:") . "</label></span>\n<br />&nbsp;&nbsp;";
+    print "$group-" . form_input ("text", "form_loginname", $form_loginname)
       . "</p>\n";
-    print '<p><span class="preinput"><label for="form_realname">'
-      . _("Squad Full Name:") . "</label></span>\n<br />&nbsp;&nbsp;";
+    print '<p><span class="preinput">'
+      . html_label ("form_realname", _("Squad Full Name:"))
+      . "</span>\n<br />&nbsp;&nbsp;";
     print form_input ("text", "form_realname", $form_realname) . "</p>\n";
     print form_footer ();
   }
