@@ -7,7 +7,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -178,25 +178,6 @@ site_project_header (
   ]
 );
 
-$checked = '';
-if ($detailed)
-  $checked = " selected='selected'";
-$form_opening = form_tag (['method' => 'get'], "#options");
-$form_submit = '<input class="bold" type="submit" value="'
-  . _("Apply") . '" />';
-$selector = '<select title="' . _("basic or detailed")
-  . '" name="detailed"><option value="0">'
-  # TRANSLATORS: this is used in context of "Browse with the %s memberlist."
-  . _("basic") . "</option>\n<option value='1'$checked>"
-  # TRANSLATORS: this is used in context of "Browse with the %s memberlist."
-  . _("detailed") . "</option>\n</select>\n"
-  . form_hidden (['group' => $group]);
-# TRANSLATORS: the argument is "basic" or "detailed".
-print html_show_displayoptions (
-  sprintf (_("Browse with the %s memberlist."), $selector),
-  $form_opening, $form_submit
-);
-
 $this_user = user_getid ();
 $approved_member = member_check ($this_user, $group_id);
 print '<p>';
@@ -224,6 +205,21 @@ print '<p>'
       . "are not attributed by default when joining this project.")
   . "</p>\n";
 
+$form_opening = form_tag (['method' => 'get'], "#options");
+$form_submit = '<input class="bold" type="submit" value="'
+  . _("Apply") . '" />';
+$selector = '<select title="' . _("basic or detailed")
+  # TRANSLATORS: this is used in context of "Browse with the %s memberlist."
+  . form_option ('0', $detailed, _("basic"))
+  # TRANSLATORS: this is used in context of "Browse with the %s memberlist."
+  . form_option ('1', $detailed, _("detailed")) . "</select>\n"
+  . form_hidden (['group' => $group]);
+# TRANSLATORS: the argument is "basic" or "detailed".
+print html_show_displayoptions (
+  sprintf (_("Browse with the %s memberlist."), $selector),
+  $form_opening, $form_submit
+);
+
 $members = fetch_member_list ($group_id);
 $title_arr = ["&nbsp;", _("Member")];
 if ($detailed)
