@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -47,7 +47,7 @@ extract (sane_import ('files', ['pass' => 'tarball']));
 session_require (['isloggedin' => '1']);
 $title = ['title' => _("Temporary upload")];
 
-if (!isset ($tarball))
+if (empty ($tarball['tmp_name']))
  {
    $HTML->header ($title);
    print form_tag (['enctype' => 'multipart/form-data'])
@@ -59,6 +59,10 @@ if (!isset ($tarball))
    exit (0);
  }
 
+form_check ();
+
+if (!is_uploaded_file ($tarball['tmp_name']))
+  exit (0);
 if ($tarball['error'] != 0)
   exit_error (sprintf (_("Error during upload: %s"), $tarball['error']));
 
@@ -66,13 +70,9 @@ if ($tarball['error'] != 0)
 # return $path when successful, $tmp_path otherwise.
 function try_move ($tmp_path, $path)
 {
-  $link_error_handler = function ($errno, $errstr, $errfile, $errline)
-  {
-    # Ignore warning.
-  };
-  $old_handler = set_error_handler ($link_error_handler, E_WARNING);
+  $state = utils_disable_warnings (E_WARNING);
   $res = link ($tmp_path, $path);
-  set_error_handler ($old_handler, E_WARNING);
+  utils_restore_warnings ($state);
   if (!$res) # Already exists; fallback to temporary file name.
     return $tmp_path;
   unlink ($tmp_path);
