@@ -6,7 +6,7 @@
 # Copyright (C) 2008 Aleix Conchillo Flaque
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -42,36 +42,47 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-require_once ('../include/init.php');
-require_once ('../include/vars.php');
-require_once ('../include/form.php');
-require_once ('../include/html.php');
-# Needed for group history.
-require_directory ("project");
+foreach (['init', 'vars', 'form', 'html', 'project/admin'] as $i)
+  require_once ("../include/$i.php");
 
 session_require (['group' => $sys_group_id, 'admin_flags' => 'A']);
 
 # We don't internationalize messages in this file because they are
 # for Savannah admins who use English.
 
+$submit_buttons = ['update', 'fastok', 'fastdel'];
 $post_names = function ()
 {
+  global $submit_buttons;
   $names = [
-    'true' => 'update',
+    'true' => $submit_buttons,
     'name' => 'form_name',
     'digits' => ['group_type', 'form_public'],
     'specialchars' => ['form_license', 'form_license_other'],
-    'preg' => [['form_status', '/^[A-Z]$/']]
+    'strings' => [['form_status', ['A', 'D']]]
   ];
   return $names;
 };
 
-extract (sane_import ('post', $post_names ()));
-extract (sane_import ('get',
-  ['true' => 'updatefast', 'preg' => [['status', '/^[A-Z]$/']]]
-));
+if (empty ($group_id))
+  exit_no_group ();
 
-if ($update || $updatefast)
+if (project_get_object ($group_id)->getStatus () == 'X')
+  {
+    site_admin_header (
+      ['title' => no_i18n ("Group List"), 'context' => 'admgroup']
+    );
+    print "<p>"
+      . no_i18n ("This is a special group.  No controls are provided.")
+      . "</p>\n";
+    site_admin_footer ([]);
+    exit (0);
+  }
+
+extract (sane_import ('post', $post_names ()));
+form_check ($submit_buttons);
+
+if (!form_vars_empty ($submit_buttons))
   {
     # Full details update.
     if ($update)
@@ -110,9 +121,9 @@ if ($update || $updatefast)
           DB_AUTOQUERY_UPDATE, "group_id = ?", [$group_id]
         );
       } # $update
-    if ($updatefast)
+    if ($fastok || $fastdel)
       db_execute ("UPDATE groups SET status = ? WHERE group_id = ?",
-        [$status, $group_id]
+        [$form_status, $group_id]
       );
     fb (no_i18n ("Updating group info"));
   }
@@ -136,14 +147,25 @@ utils_get_content ("admin/groupedit_intro");
 
 print '<p>';
 print "<a href='../projects/{$row_grp['unix_group_name']}'>"
-  . no_i18n ("Group public page") . "</a>";
+  . no_i18n ("Group main page") . "</a>";
 print '</p>
 ';
 
-print '<h2>' . no_i18n ("Registration Management Shortcuts") . "</h2>\n";
-print "<a href=\"$php_self?status=A&amp;updatefast=1&amp;group_id=$group_id\">"
-  . html_image ("bool/ok.orig.png", ['alt' => no_i18n ("Approve")])
-  . '</a>';
+function print_updatefast ($status, $image, $label, $name)
+{
+  global $group_id;
+  print form_tag ();
+  print form_hidden ([
+    'form_status' => $status, 'group_id' => $group_id, $name => 1
+  ]);
+  # The variables from <input type="image" /> are ignored, the previously
+  # defined <input type="hidden" /> is used instead.
+  print form_image ($image, $label, "submit_$name");
+  print "\n</form>\n<br />\n";
+}
+
+print html_h (2, no_i18n ("Registration Management Shortcuts"));
+print_updatefast ('A', 'bool/ok.orig.png', no_i18n ("Approve"), 'fastok');
 $res = db_execute (
   "SELECT COUNT(group_list_id) AS cnt FROM mail_group_list WHERE group_id = ?",
   [$group_id]
@@ -153,10 +175,7 @@ $list_row = db_fetch_array ($res);
 if (!empty ($list_row))
   $no_lists = $list_row['cnt'] < 1;
 if ($no_lists)
-  print "&nbsp;&nbsp;&nbsp;<a href=\"$php_self"
-    . "?status=D&amp;updatefast=1&amp;group_id=$group_id\">"
-    . html_image ("bool/wrong.orig.png", ['alt' => no_i18n ("Discard")])
-    . '</a>';
+  print_updatefast ('D', 'bool/wrong.orig.png', no_i18n ("Discard"), 'fastdel');
 else
   {
     $msg = sprintf (
@@ -167,9 +186,8 @@ else
     );
     print "<br />\n$msg<br />\n";
   }
-
 print form_tag ();
-print '<h2>' . no_i18n ("Detailed Interface") . "</h2>\n";
+print html_h (2, no_i18n ("Detailed Interface"));
 $HTML->box1_top (no_i18n ("General Settings"));
 
 print '<p><span class="preinput">' . no_i18n ("Group Type:")
@@ -187,7 +205,7 @@ function next_altrow ()
 $i = 0;
 next_altrow ();
 print '<p><span class="preinput"><label for="form_name">'
-  . no_i18n("System Name:") . "</label></span><br />\n";
+  . no_i18n ("System Name:") . "</label></span><br />\n";
 print '<input type="text" name="form_name" id="form_name" value="'
   . $row_grp['unix_group_name'] . '" />';
 
@@ -201,16 +219,9 @@ foreach (
   [
     'A' => no_i18n ("Active"), 'P' => no_i18n ("Pending"),
     'D' => no_i18n ("Deleted"),
-    'M' => no_i18n ("Maintenance (accessible only to superuser)"),
-    'I' => no_i18n ("Incomplete (failure during registration)"),
   ] as $k => $v
 )
-  {
-    $sel = '';
-    if ( $row_grp['status'] == $k)
-      $sel = ' selected';
-    print "<option$sel value='$k'>$v</option>\n";
-  }
+  print form_option ($k, $row_grp['status'], $v);
 print "</select>\n";
 print '<p class="warn">'
   . no_i18n (
@@ -236,15 +247,8 @@ print '<p><span class="preinput"><label for="form_public">'
       "You must clear the HTML repository field below when setting the "
       . "private flag otherwise unpredictable result will occur.")
   . "<br />\n<select name='form_public' id='form_public'>\n";
-$sel = '';
-if ($row_grp['is_public'] == 1)
-$sel = ' selected';
-print "<option$sel value='1'>" . no_i18n ("Yes") . "</option>\n";
-if ($sel == '')
-  $sel = ' selected';
-else
-  $sel = '';
-print "<option$sel value='0'>" . no_i18n ("No") . "</option>\n";
+print form_option ('1', $row_grp['is_public'], no_i18n ("Yes"));
+print form_option ('0', $row_grp['is_public'], no_i18n ("No"));
 print "</select>\n";
 
 next_altrow ();
@@ -257,15 +261,11 @@ print no_i18n (
 );
 print "<br />\n";
 print "<select name='form_license' id='form_license'>\n";
-print '<option value="none">' . no_i18n ("N/A") . "</option>\n";
-print '<option value="other">' . no_i18n ("Other license") . "</option>\n";
+print form_option ("none", null, no_i18n ("N/A"));
+print form_option ("other", null, no_i18n ("Other license"));
 
 foreach ($LICENSE_EN as $k => $v)
-  {
-    print "<OPTION value=\"$k\"";
-    if ($k == $row_grp['license']) print " selected";
-    print ">$v</option>\n";
-  }
+  print form_option ($k, $row_grp['license'], $v);
 print '</select>
 <br />
 <label for="form_license_other">';
@@ -281,12 +281,14 @@ print '<p><input type="submit" name="update" value="' . no_i18n ("Update")
 
 $HTML->box1_bottom ();
 
-print "<p><a href='triggercreation.php?group_id=$group_id'>"
-  . no_i18n (
-      "Send new group instruction email and trigger group creation "
-      . "(should be done only once)"
-    )
-  . "</a></p>\n";
+print "<p>";
+print form_tag (['action' => "triggercreation.php"]);
+print form_hidden (['group_id' => $group_id]);
+print form_submit (no_i18n (
+  "Send new group instruction email and trigger group creation "
+  . "(should be done only once)"
+));
+print "</p>\n";
 
 $HTML->box1_top (no_i18n ("Submitted Information"));
 project_admin_registration_info ($row_grp);
