@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -50,12 +50,13 @@ site_admin_header (
   ['title' => no_i18n ("Group List"), 'context' => 'admgroup']
 );
 
-extract (sane_import ('post', ['pass' => 'search', 'true' => 'groupsearch']));
 extract (sane_import ('get',
   [
     'digits' => ['offset', 'max_rows'],
     'name' => 'group_name_search',
     'preg' => [['status', '/^[A-Z]$/']],
+    'pass' => 'search',
+    'true' => 'groupsearch'
   ]
 ));
 
@@ -99,14 +100,11 @@ $abc_array = [
 
 $status_arr = [
   'A' => no_i18n ("Active"), 'P' => no_i18n ("Pending"),
-  'I' => no_i18n ("Incomplete"), 'D' => no_i18n ("Deleted"),
-  'M' => no_i18n ("Maintenance"), 'X' => no_i18n ("System internal")
+  'D' => no_i18n ("Deleted"), 'X' => no_i18n ("System internal")
 ];
 $status_proj_arr = [
   'A' => no_i18n ("Active Groups"), 'P' => no_i18n ("Pending Groups"),
-  'I' => no_i18n ("Incomplete Groups"), 'D' => no_i18n ("Deleted Groups"),
-  'M' => no_i18n ("Maintenance Groups"),
-  'X' => no_i18n ("System internal Groups")
+  'D' => no_i18n ("Deleted Groups"), 'X' => no_i18n ("System internal Groups")
 ];
 
 print '<h2>' . no_i18n ("Group Search") . "</h2>\n<p>"
@@ -120,12 +118,10 @@ print "<br />\n"
   . no_i18n ("or search by group_id, group_unix_name or group_name:");
 
 print "\n"
-  . form_tag (['name' => 'gpsrch'])
-  . form_input ('text', 'search', $search,
-     'title="' . no_i18n ("Group name") . '"') . "\n"
+  . form_tag (['name' => 'gpsrch', 'method' => 'get'])
+  . form_input ('text', 'search', $search) . "\n"
   . form_hidden (['groupsearch' => '1'])
-  . "<input type='submit' value=\"" . no_i18n ("Search") . "\" />\n"
-  . "</form>\n</p>\n";
+  . form_submit (no_i18n ("Search")) . "</form>\n</p>\n";
 
 print '<h2>' . no_i18n ("Group List") . "</h2>\n";
 
@@ -189,9 +185,12 @@ else
     for ($i = 0; $i < $rows; $i++)
       {
         $grp = db_fetch_array ($res);
+        $grp_name = $grp['group_name'];
+        if (in_array ($grp['status'], ['A', 'P']))
+          $grp_name =
+            "<a href=\"groupedit.php?group_id=$grp[group_id]\">$grp_name</a>";
         print '<tr class="' . utils_altrow ($inc++) . '">';
-        print "<td><a href=\"groupedit.php?group_id=$grp[group_id]\">"
-          . "$grp[group_name]</a></td>\n";
+        print "<td>$grp_name</td>\n";
         print "<td>$grp[unix_group_name]</td>\n";
         print '<td>' . $status_arr[$grp['status']] . "</td>\n";
         print '<td>' . ($grp['is_public']? no_i18n ("yes"): no_i18n ("no"))
