@@ -7,7 +7,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -55,24 +55,28 @@ require_once ('../include/trackers/data.php');
 session_require (['group' => '1','admin_flags' => 'A']);
 
 $actions = ['remove_user_from_group', 'update_user_group',
-  'update_user', 'add_user_to_group', 'rename'
+  'update_user', 'add_user_to_group', 'rename', 'delete', 'activate'
 ];
 
 extract (sane_import ('request',
   [
-    'digits' => ['user_id', 'comment_max_rows', 'comment_offset'],
-    'strings' => [['action', array_merge ($actions, ['delete'])],],
+    'digits' => ['user_id', 'comment_max_rows', 'comment_offset']
   ]
 ));
 extract (sane_import ('post',
   [
+    'strings' => [['action', $actions]],
     'name' => 'new_name',
+    'true' => 'update',
     'preg' => [
       ['email', '/^[a-zA-Z\d_.+-]+@(([a-zA-Z\d-])+\.)+[a-zA-Z\d]+$/'],
       ['admin_flags', '/^[A-Z\d]+$/'],
-    ],
+    ]
   ]
 ));
+form_check ('update');
+if (empty ($update))
+  $action = null;
 
 if (empty ($comment_max_rows))
   $comment_max_rows = 50;
@@ -92,7 +96,7 @@ function print_contribution_heading ($user_id)
 {
   if ($user_id == 100)
     return;
-  print "<h2>". no_i18n ("Contributions") . "</h2>\n";
+  print html_h (2, no_i18n ("Contributions"));
 }
 
 function tracker_query ($user_id, $tracker)
@@ -112,7 +116,7 @@ function tracker_query ($user_id, $tracker)
         '$tracker #', bug_id, ' (', field_name, ')</a>')
       as summary,
       old_value as details, spamscore, bug_history_id as comment_id, date
-    FROM ${tracker}_history
+    FROM {$tracker}_history
     WHERE mod_by = $user_id";
 }
 
@@ -135,7 +139,7 @@ function inclusion_requests_query ($user_name)
 function contribution_query ($user_id, $user_name, $offset, $max_rows)
 {
   $max_plus = $max_rows + 1;
-  $trackers = ['cookbook', 'bugs', 'task', 'support', 'patch'];
+  $trackers = utils_get_tracker_list ();
   $queries = [];
   foreach ($trackers as $tracker)
     $queries[] = tracker_query ($user_id, $tracker);
@@ -201,12 +205,23 @@ function list_user_contributions ($user_id, $user_name, $offset, $max_rows)
 
 function report_db_result ($result, $msg_err, $msg_ok)
 {
-  if (!$result || db_affected_rows ($result) < 1)
+  if (!$result)
     fb ($msg_err . ' ' . db_error (), 1);
   else
     fb ($msg_ok);
 }
 
+function action_activate ()
+{
+  global $user_id;
+  db_execute("UPDATE user SET status='A' WHERE user_id = ?", [$user_id]);
+}
+
+function action_delete ()
+{
+  user_delete ($GLOBALS['user_id']);
+}
+
 function action_remove_user_from_group ()
 {
   global $user_id, $group_id;
@@ -246,7 +261,8 @@ function action_update_user ()
 function action_add_user_to_group ()
 {
   global $user_id, $group_id;
-
+  if (empty ($group_id))
+    exit_no_group ();
   $result = member_add ($user_id, $group_id);
   report_db_result (
     $result, no_i18n ('Error adding user to group:'),
@@ -276,8 +292,8 @@ function rename_form ($user_id, $user_name)
     . form_hidden (['action' => 'rename', 'user_id' => $user_id])
     . "<p>Account:\n<input type='text' title=\"" . no_i18n ("New name")
     . '" name="new_name" size="22"  value="' . $user_name
-    . '" maxlength="55">' . "&nbsp;\n<input type='submit' name='update_name'"
-    . ' value="' . no_i18n ('Rename') . "\"></p>\n</form>\n";
+    . '" maxlength="55">' . "&nbsp;\n"
+    . form_submit (no_i18n ('Rename')) . "</p>\n</form>\n";
 }
 
 function email_form ($user_id, $email)
@@ -286,19 +302,16 @@ function email_form ($user_id, $email)
     . form_hidden (['action' => 'update_user', 'user_id' => $user_id])
     . "<p>Email:\n<input type='text' size='25' title=\"" . no_i18n ("Email")
     . "\" name='email' value=\"$email\" maxlength='55'>"
-    . "&nbsp;\n" . '<input type="submit" name="update_user" value="'
-    . no_i18n ('Update') . "\"></p>\n</form>\n";
+    . "&nbsp;\n" . form_submit (no_i18n ('Update')) . "</p>\n</form>\n";
 }
 
 function add_to_group_form ($user_id)
 {
   return form_tag ()
     . form_hidden (["action" => "add_user_to_group", "user_id" => $user_id])
-    . "<label for='group_id'>\n" . no_i18n ('Add to group (group_id):')
-    . "</label>\n&nbsp;\n"
-    . '<input type="text" name="group_id" id="group_id" size="17" '
-    . "/>&nbsp;\n" . '<input type="submit" name="Submit" value="'
-    . no_i18n ('Submit') . "\" />\n</form>\n\n";
+    . html_label ('group_id', no_i18n ('Add to group (group_id):'))
+    . "\n&nbsp;\n" . form_input ('text', "group_id", '',  'size="17"')
+    . "&nbsp;\n" . form_submit (no_i18n ('Update')) . "</p>\n</form>\n";
 }
 
 function change_passwd_link ($user_id)
@@ -309,14 +322,31 @@ function change_passwd_link ($user_id)
 
 function delete_account_link ($user_id)
 {
-  return '<a href="/siteadmin/userlist.php?action=delete&amp;user_id='
-    . $user_id . '">' . no_i18n ('[Delete account]') . "</a>\n\n";
+  return form_tag ()
+    . form_hidden (["action" => "delete", "user_id" => $user_id])
+    . form_submit (no_i18n ('Delete account')) . "\n</form>\n";
+}
+
+function show_status ($user_id, $status)
+{
+  $labels = ['A' => no_i18n ('Active'), 'P' => no_i18n ('Pending')];
+  $ret = "<p>Status: ";
+  if (array_key_exists ($status, $labels))
+    $ret .= $labels[$status];
+  else
+    $ret .= "[$status]";
+  if ($status == 'P')
+    $ret .= ' ' . form_tag ()
+      . form_hidden (['action' => 'activate', 'user_id' => $user_id])
+      . form_submit (no_i18n ('Activate')) . "\n</form>\n";
+  $ret .= "</p>\n";
+  return $ret;
 }
 
 function account_title ($user_id)
 {
-  return '<h2>' . no_i18n ('Account info:')
-    . " #$user_id &lt;" . user_getname ($user_id) . "&gt;</h2>\n";
+  return html_h (2,  no_i18n ('Account info:')
+    . " #$user_id &lt;" . user_getname ($user_id) . "&gt;");
 }
 
 function account_form ($user_id, $row_user)
@@ -325,6 +355,7 @@ function account_form ($user_id, $row_user)
    if ($row_user['status'] == 'SQD')
      return $ret . '<p>' . no_i18n ('This is a squad.') . "</p>\n";
   $ret .= rename_form ($user_id, $row_user['user_name']);
+  $ret .= show_status ($user_id, $row_user['status']);
   $ret .= email_form ($user_id, $row_user['email']);
   $ret .= '<p>' . change_passwd_link ($user_id) . '&nbsp;';
   $ret .= delete_account_link ($user_id) . "</p>\n";
@@ -359,13 +390,13 @@ function group_entry ($user_id, $status, $row_cat)
   if ($status == 'SQD')
     return "<p>\n<a href=\"/project/admin/squadadmin.php?"
       . "squad_id=$user_id&amp;group_id=$grp_id\">$grp_name</a></p>\n";
-  $ret = "\n<h3>$grp_name</h3>\n";
+  $ret = html_h (3, $grp_name);
   return $ret . user_group_form ($user_id, $grp_id, $row_cat['admin_flags']);
 }
 
 function list_groups ($user_id, $status)
 {
-  print '<h2>' . no_i18n ('Current Groups') . "</h2>\n";
+  print html_h (2, no_i18n ('Current Groups'));
   $res_cat = db_execute ("
     SELECT g.group_name, g.group_id, u.admin_flags FROM groups g, user_group u
     WHERE u.user_id = ? AND g.group_id = u.group_id", [$user_id]
@@ -384,15 +415,22 @@ if ($user_id == 100)
     exit;
   }
 
-$HTML->header (['title' => no_i18n ('Admin: Manage user')]);
-
 if (in_array ($action, $actions))
   {
     $f = "action_$action";
     $f ();
   }
 
+$HTML->header (['title' => no_i18n ('Admin: Manage user')]);
 $res_user = db_execute ("SELECT * FROM user WHERE user_id = ?", [$user_id]);
+if (!db_numrows ($res_user))
+  {
+    print '<p>';
+    printf (no_i18n ('User #%s not found.'), $user_id);
+    print "</p>\n";
+    $HTML->footer ([]);
+    exit;
+  }
 $row_user = db_fetch_array ($res_user);
 
 print account_form ($user_id, $row_user);
