@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -41,14 +41,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-include ("include/ac_config.php");
+$testconfig_php = true;
+require_once ("include/ac_config.php");
 $sys_debug_sqlprofiler = false;
 $sys_file_domain = '';
 $sys_linguas = "en:es";
-require_once ("include/i18n.php");
-require_once ("include/utils.php");
-require_once ("include/database.php");
-require_once ("include/mailman.php");
+foreach (['i18n', 'database', 'mailman', 'savane-git'] as $inc)
+  require_once ("include/$inc.php");
 
 function return_bytes ($v)
 {
@@ -89,13 +88,11 @@ function test_gpg ()
     "'" . $GLOBALS['sys_gpg_name'] . "' --version", $gpg_output,
      $gpg_stderr
   );
-  $dd_pre = "<dd style='border: thin dashed black; border-right: none'>"
-            ."<pre style='padding-left: 1em'>\n";
   print "<dt><code>--version</code> output</dt>\n";
-  print $dd_pre . utils_specialchars ($gpg_output) . "</pre></dd>\n";
+  print "<dd><pre>\n" . utils_specialchars ($gpg_output) . "</pre></dd>\n";
   print "<dt>Exit code</dt><dd><code>" . $gpg_result . "</code></dd>\n";
   print "<dt><code>stderr</code> output</dt>\n";
-  print $dd_pre . utils_specialchars ($gpg_stderr) . "</pre></dd>\n";
+  print "<dd><pre>\n" . utils_specialchars ($gpg_stderr) . "</pre></dd>\n";
   print "</dl>\n";
 }
 
@@ -196,6 +193,7 @@ function test_sys_upload_dir ()
   $error_handler = function ($errno, $errstr)
   {
     print "<b>unlink failed:</b> $errstr";
+    return true;
   };
   $old_handler = set_error_handler ($error_handler, E_WARNING);
   $res = unlink ($path);
@@ -209,7 +207,7 @@ function test_captcha ()
   global $sys_captchadir;
   $default_dir = '/usr/share/php';
 
-  print "<h2>Captcha</h2>\n\n";
+  print "<h3>Captcha</h3>\n\n";
   if (empty ($sys_captchadir))
     {
       print "<p><strong>sys_captchadir isn't set.</strong></p>\n";
@@ -281,7 +279,7 @@ function output_mailman_query ($q)
 
 function test_mailman ()
 {
-  print "<h2>Mailman connection</h2>";
+  print "<h3>Mailman connection</h3>";
   print "<dl>\n";
   $ver = mailman_get_version ();
   $have_version = output_mailman_version ($ver);
@@ -294,34 +292,60 @@ function test_mailman ()
       . "in \$sys_mailman_wrapper.</strong></p>\n";
 }
 
-print "<?xml version=\"1.0\" encoding=\"utf-8\"?"
+$page = "<?xml version=\"1.0\" encoding=\"utf-8\"?"
   # Separate the previous "?" from ">" to workaround broken syntax
   # highlighting in some editors.
   . ">\n";
-print "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\"
+$page .= "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\"
     \"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">\n\n";
 
-print "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en_US\">\n"
-. "<head>\n"
-. "<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\" />\n"
-. "<title>Basic configuration tests</title>\n"
-. "<link rel=\"stylesheet\" type=\"text/css\" "
-. "href=\"/css/internal/testconfig.css\" />\n"
-. "</head>\n\n"
-. "<body>\n";
+$page .= "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en_US\">\n"
+  . "<head>\n"
+  . "<meta http-equiv='content-type' content='text/html; charset=utf-8' />\n"
+  . "<title>Basic configuration tests</title>\n"
+  . "<link rel=\"stylesheet\" type=\"text/css\" "
+  . "href=\"/css/internal/testconfig.css\" />\n"
+  . "</head>\n\n"
+  . "<body>\n";
 
-print "<h1>Basic pre-tests for Savane installation</h1>\n\n";
-if (empty($inside_siteadmin))
-  print "<p>This page should help you to check whether your
-installation is properly configured. It shouldn't display any sensitive
-information, since it could give details about your setup to anybody.</p>\n";
+$page .= "<h1>Basic pre-tests for Savane installation</h1>\n\n";
+if (empty ($inside_siteadmin))
+  $page .= "<p>This page should help you to check whether your installation\n"
+    . "is properly configured. It shouldn't display any sensitive\n"
+    . "information, since it could give details about your setup\n"
+    . "to anybody.</p>\n";
 
-print "\n<h2>Basic PHP configuration</h2>\n\n";
+$page .= "\n<h2>Savane source code</h2>\n\n";
+function check_source_code ()
+{
+  $commit = git_get_commit ();
+  $cgit_url = git_get_savane_url ($commit);
+  $tarball_name = git_get_tarball_name ();
+  $tarball_url = git_get_tarball_url ();
+  $ret = "<dl>\n";
+  $ret .= "<dt>Configured Git commit</dt>\n";
+  $ret .= "<dd>{$GLOBALS['ac_git_commit']}</dd>\n";
+  $ret .= "<dt>Computed Git commit</dt>\n";
+  $ret .= "<dd><a href='$cgit_url'>$commit</a></dd>\n";
+  $ret .= "<dt>Tarball</dt>\n";
+  $ret .= "<dd><a href='$tarball_url'>$tarball_name</a></dd>\n";
+  $ret .= "<dt>Availability</dt>\n<dd>";
+  if (git_check_tarball ())
+    $ret .= "<strong>Fail.  You must make sure you offer the source code "
+      . "correctly before making the website available to other "
+      . "users.</strong>";
+  else
+    $ret .= "OK";
+  return "$ret</dd>\n</dl>\n";
+}
+$page .= check_source_code ();
 
-print "<p>PHP version: " . phpversion () . "</p>\n";
+$page .= "\n<h2>Basic PHP configuration</h2>\n\n";
+
+$page .= "<p>PHP version: " . phpversion () . "</p>\n";
 
 # cf. http://php.net/manual/en/ini.php
-$phptags = ['file_uploads' => '1'];
+$phptags = ['file_uploads' => '1', 'allow_url_fopen' => '1'];
 
 # Get all php.ini values.
 $all_inis = ini_get_all ();
@@ -329,18 +353,18 @@ $all_inis = ini_get_all ();
 define ('PHP_INI_SYSTEM', 4);
 # Cf. http://www.php.net/manual/en/ini.core.php
 
-print "\n<table border=\"1\" summary=\"PHP configuration\">\n";
-print "<tr><th>PHP Tag name</th><th>Local value</th>"
-    . "<th>Suggested value</th></tr>\n";
+$page .= "\n<table border=\"1\" summary=\"PHP configuration\">\n";
+$page .= "<tr><th>PHP Tag name</th><th>Local value</th>"
+  . "<th>Suggested value</th></tr>\n";
 $have_unset = false;
 ksort ($phptags);
 function compare_ini_vals ($tag, $good, $cmp)
 {
-  global $all_inis;
+  global $all_inis, $page;
   $gv = utils_specialchars ($good);
   if (!array_key_exists ($tag, $all_inis))
     {
-      printf (
+      $page .= sprintf (
         "<tr><td>%s</td><td class=\"unset\">Unknown*</td><td>%s</td></tr>\n",
         $tag, $gv
       );
@@ -350,16 +374,18 @@ function compare_ini_vals ($tag, $good, $cmp)
   $t = utils_specialchars ($ini_val);
   if ($cmp ($ini_val, $good))
     {
-      printf ("<tr><td>%s</td><td>%s</td><td>%s</td></tr>\n", $tag, $t, $gv);
+      $page .=
+        sprintf ("<tr><td>%s</td><td>%s</td><td>%s</td></tr>\n", $tag, $t, $gv);
       return false;
     }
-  printf ("<tr><td>%s</td><td class=\"different\">%s</td><td>%s",
-    $tag, $t, $gv);
+  $page .= sprintf (
+    "<tr><td>%s</td><td class=\"different\">%s</td><td>%s", $tag, $t, $gv
+  );
   if ($all_inis[$tag]['access'] > PHP_INI_SYSTEM)
-    print " (can be set in php.ini, .htaccess or httpd.conf)";
+    $page .= " (can be set in php.ini, .htaccess or httpd.conf)";
   else
-    print " (can be set in php.ini or httpd.conf, but not in .htaccess)";
-  print "</td></tr>\n";
+    $page .= " (can be set in php.ini or httpd.conf, but not in .htaccess)";
+  $page .= "</td></tr>\n";
   return false;
 }
 
@@ -373,27 +399,31 @@ $cmp = function ($a, $b) { return return_bytes ($a) >= return_bytes ($b); };
 foreach ($phptags as $tag => $good)
   if (compare_ini_vals ($tag, $good, $cmp))
     $have_unset = true;
-print "</table>\n\n";
+$page .= "</table>\n\n";
 if ($have_unset)
-  print "<blockquote>* This tag was not found at all. It is probably "
+  $page .= "<blockquote>* This tag was not found at all. It is probably "
     . "irrelevant to your PHP version so you may ignore this "
     . "entry.</blockquote>\n";
 
-print "\n<h2>PHP functions</h2>\n\n";
+$page .= "\n<h2>PHP functions</h2>\n\n";
 
 $phpfunctions =
   [
     'mysqli_connect' =>
-      'You must install/configure php-mysqli ! [REQUIRED]',
-    'gettext' => 'You should install/configure php with gettext support '
-      . '! [RECOMMENDED]',
+      'You must install php-mysqli ! [REQUIRED]',
+    'gettext' =>
+      'You should install PHP with gettext support '
+      . '(--with-gettext --enable-intl) ! [RECOMMENDED]',
     'strftime' => 'When this function is dropped from PHP '
       . '(deprecated in 8.1), date output is expected to slow down '
       . '! [RECOMMENDED]',
     'ctype_digit' => 'You must have a PHP version supporting ctype '
-      . '(--enable-ctype) ! [REQUIRED]'
+      . '(--enable-ctype) ! [REQUIRED]',
+    'imagettfbbox' =>
+      'Used by captcha library (--enable-gd --with-freetype) ! [RECOMMENDED]',
+    'sem_get' => 'Used in mailman interface (--enable-sysvsem) ! [REQUIRED]'
  ];
-print "<p>";
+$page .= "<p>";
 foreach ($phpfunctions as $func => $comment)
   {
     $funcs = explode ("|", $func);
@@ -405,148 +435,167 @@ foreach ($phpfunctions as $func => $comment)
           break;
         }
     if ($have_func)
-      print "function <strong>$f</strong> exists.<br />\n";
+      $page .= "function <strong>$f</strong> exists.<br />\n";
     else
-      print
+      $page .=
         "function <strong>$func</strong> not found. <em>$comment</em><br />\n";
   }
-print "</p>\n";
+$page .= "</p>\n";
 
 function test_i18n ()
 {
   i18n_setup ("es_ES.UTF-8");
-  $str = 'High';
+  $str = 'Any';
   $res = gettext ($str);
   if ($res == $str)
-    print "<strong>fail</strong>";
+    {
+      print "<strong>Fail.</strong> Check <code>locale -a</code> output,\n";
+      print "be sure to install language-pack-* in Trisquel";
+    }
   else
     print "$str => $res";
   i18n_setup ("en_US.UTF-8");
 }
 
-print "\n<h2>Apache environment vars</h2>\n\n<p>";
+$page .= "\n<h2>Apache environment vars</h2>\n\n<p>";
 if (getenv ('SAVANE_CONF'))
   {
     $conf_var = getenv ('SAVANE_CONF');
-    print "SAVANE_CONF configured to $conf_var<br />\n";
+    $page .= "SAVANE_CONF configured to $conf_var<br />\n";
   }
 if (getenv('SV_LOCAL_INC_PREFIX'))
   {
     $conf_var = getenv ('SV_LOCAL_INC_PREFIX');
-    print "SV_LOCAL_INC_PREFIX configured to $conf_var<br />\n";
+    $page .= "SV_LOCAL_INC_PREFIX configured to $conf_var<br />\n";
   }
-print "</p>\n\n<h2>Savane configuration:</h2>\n\n<p>";
+$page .= "</p>\n\n<h2>Savane configuration:</h2>\n\n<p>";
 
 if (empty ($sys_conf_file))
-  print "<strong>sys_conf_file not set!</strong>\n";
+  $page .= "<strong>sys_conf_file not set!</strong>\n";
 else
   {
-    print "sys_conf_file is set to $sys_conf_file<br />\n";
-    print "File <strong>$sys_conf_file</strong> ";
+    $page .= "sys_conf_file is set to $sys_conf_file<br />\n";
+    $page .= "File <strong>$sys_conf_file</strong> ";
 
     if (is_readable ($sys_conf_file))
-      print "exists and is readable.";
+      $page .= "exists and is readable.";
     else
-      print "does not exist or is not readable!";
+      $page .= "does not exist or is not readable!";
   }
-print "</p>\n";
+$page .= "</p>\n";
 
-if (!is_readable ($sys_conf_file))
-  print "Since $sys_conf_file does not exist or is not readable, "
-        . "this part cannot be checked.";
+function test_mysql ()
+{
+  print "\n<h3>MySQL configuration</h3>\n\n";
+  $db_err = db_connect ();
+  if ($db_err !== null)
+    {
+      print $db_err;
+      return;
+    }
+  # When sql_mode contains 'ONLY_FULL_GROUP_BY', queries like
+  # "SELECT groups.group_name, groups.group_id, groups.unix_group_name,"
+  # ...
+  # . "GROUP BY groups.unix_group_name "
+  # . "ORDER BY groups.unix_group_name"
+  # used e.g. in my/groups.php result in an error.
+  #
+  # Since MySQL 5.7, this is default. We could use ANY_VALUE ()
+  # to workaround this, but it is only introduced in 5.7,
+  # so won't work with older MySQLs.
+  $mysql_params = [
+    '@@GLOBAL.version' => null,
+    '@@GLOBAL.sql_mode' => null,
+    '@@SESSION.sql_mode' =>
+      "<em>This should</em> <strong>not</strong> <em>include</em> "
+        . "<code>ONLY_FULL_GROUP_BY,STRICT_TRANS_TABLES</code><em>.</em>"
+  ];
+  $mysql_highlight = [
+    '@@GLOBAL.sql_mode' => 'ONLY_FULL_GROUP_BY,STRICT_TRANS_TABLES',
+    '@@SESSION.sql_mode' => 'ONLY_FULL_GROUP_BY,STRICT_TRANS_TABLES'
+  ];
+  print "<dl>\n";
+  foreach ($mysql_params as $param => $comment)
+    {
+      $result = db_query ("SELECT $param");
+      $value = db_result ($result, 0, $param);
+      if (isset ($mysql_highlight[$param]))
+        {
+          $vals = explode (",", $mysql_highlight[$param]);
+          foreach ($vals as $i => $v)
+            $value = str_replace ($v, "<strong>$v</strong>", $value);
+        }
+      print "<dt>$param</dt><dd>'$value'";
+      if ($comment !== null)
+        print "<br />\n$comment";
+      print "</dd>\n";
+    }
+  print "</dl>\n";
+}
+
+function test_sysconfigs ()
+{
+  global $sys_conf_file, $page;
+  include $sys_conf_file;
+  $variables = [
+    'dbhost', 'dbname', 'dbpasswd', 'dbport', 'dbsocket', 'dbuser',
+    'default_domain', 'etc_dir', 'file_domain', 'https_host', 'incdir',
+    'url_topdir', 'www_topdir',
+    'linguas', 'localedir',
+    'mail_admin', 'mail_domain', 'mail_replyto', 'name',
+    'themedefault', 'unix_group_name', 'upload_max',
+    'watch_anon_posts', 'new_user_watch_days',
+    'mailman_wrapper', 'savane_url', 'savane_cgit'
+  ];
+  if (empty ($inside_siteadmin))
+    utils_set_csp_headers ();
+  print $page;
+  $page = '';
+
+  print "<dl>\n";
+  foreach ($variables as $tag)
+    {
+      $var = "sys_$tag";
+      $value = '<strong>unset</strong>';
+      if (isset ($GLOBALS[$var]))
+        $value = utils_specialchars (print_r ($GLOBALS[$var], true));
+      if ($var == "sys_dbpasswd")
+        $value = "**************";
+
+      printf ("<dt>%s</dt>\n<dd>%s</dd>\n", $var, $value);
+    }
+  if (!isset ($GLOBALS['sys_debug_on']))
+    $GLOBALS['sys_debug_on'] = false;
+
+  print "</dl>\n";
+  print "<p>Savane uses safe default values when variables are not set "
+    . "in the configuration file.</p>\n";
+  print "<p><img src='/file?file_id=test.png' alt='Test image'/></p>\n";
+  test_captcha ();
+  test_mailman ();
+  test_mysql ();
+
+  print "\n<h3>Other tests</h3>\n\n";
+  print "<table border=\"1\">\n";
+  print "<dl>\n";
+  test_repos ();
+  print "<dt id='sys-upload-dir'>sys_upload_dir writability</dt>\n<dd>";
+  test_sys_upload_dir ();
+  print "</dd>\n";
+  print "<dt id='i18n'>i18n</dt>\n<dd>";
+  test_i18n ();
+  print "</dd>\n";
+  print "</dl>\n";
+  test_gpg ();
+}
+
+$page .= "<h2>Configured settings</h2>\n";
+
+if (is_readable ($sys_conf_file))
+  test_sysconfigs ();
 else
-  {
-    include $sys_conf_file;
-    $variables = [
-      'default_domain', 'https_host', 'file_domain', 'dbhost', 'dbname',
-      'dbuser', 'dbpasswd', 'www_topdir', 'url_topdir', 'etc_dir', 'incdir',
-      'name', 'unix_group_name', 'themedefault', 'mail_domain', 'mail_admin',
-      'mail_replyto', 'upload_max', 'watch_anon_posts', 'new_user_watch_days',
-      'localedir', 'linguas', 'mailman_wrapper'
-    ];
-    if (empty ($inside_siteadmin))
-      utils_set_csp_headers ();
-
-    print "<table border=\"1\">\n";
-    print "<tr><th>Conf variable</th><th>Current value</th></tr>\n";
-    foreach ($variables as $tag)
-      {
-        $var = "sys_$tag";
-        $value = '<strong>unset</strong>';
-        if (isset ($GLOBALS[$var]))
-          $value = utils_specialchars (print_r ($GLOBALS[$var], true));
-        if ($var == "sys_dbpasswd")
-          $value = "**************";
-
-        printf ("<tr><td>%s</td><td>%s</td></tr>\n", $var, $value);
-      }
-    if (!isset ($GLOBALS['sys_debug_on']))
-      $GLOBALS['sys_debug_on'] = false;
-
-    print "</table>\n";
-    print "<p>Savane uses safe defaults values when variables are not set "
-      . "in the configuration file.</p>\n";
-    print "<p><img src='/file?file_id=test.png' alt='Test image'/></p>\n";
-    test_captcha ();
-    test_mailman ();
-
-    print "\n<h2>MySQL configuration</h2>\n\n";
-    if (!db_connect ())
-      print "<blockquote>Can't connect to database.</blockquote>\n";
-    else
-      {
-        # When sql_mode contains 'ONLY_FULL_GROUP_BY', queries like
-        # "SELECT groups.group_name,"
-        # . "groups.group_id,"
-        # . "groups.unix_group_name,"
-        # ...
-        # . "GROUP BY groups.unix_group_name "
-        # . "ORDER BY groups.unix_group_name"
-        # used e.g. in my/groups.php result in an error.
-        #
-        # Since MySQL 5.7, this is default. We could use ANY_VALUE ()
-        # to workaround this, but it is only introduced in 5.7,
-        # so won't work with older MySQLs.
-        $mysql_params = array ('@@GLOBAL.version' => NULL,
-                               '@@GLOBAL.sql_mode' => NULL,
-                               '@@SESSION.sql_mode' =>
-                "<em>This should</em> <strong>not</strong> <em>include</em> "
-                . "<code>ONLY_FULL_GROUP_BY,STRICT_TRANS_TABLES</code><em>.</em>");
-        $mysql_highlight = array ('@@GLOBAL.sql_mode' =>
-                                  'ONLY_FULL_GROUP_BY,STRICT_TRANS_TABLES',
-                                  '@@SESSION.sql_mode' =>
-                                  'ONLY_FULL_GROUP_BY,STRICT_TRANS_TABLES');
-        print "<dl>\n";
-        foreach ($mysql_params as $param => $comment)
-          {
-            $result = db_query ('SELECT ' . $param);
-            $value = db_result ($result, 0, $param);
-            if (isset ($mysql_highlight[$param]))
-              {
-                $vals = explode (",", $mysql_highlight[$param]);
-                foreach ($vals as $i => $v)
-                  $value = str_replace ($v, "<strong>$v</strong>", $value);
-              }
-            print "<dt>$param</dt><dd>'$value'";
-            if ($comment !== NULL)
-              print "\n$comment";
-            print "</dd>\n";
-          }
-        print "</dl>\n";
-      } # db_connect ()
-    print "\n<h2>Other tests</h2>\n\n";
-    print "<table border=\"1\">\n";
-    print "<dl>\n";
-    test_repos ();
-    print "<dt id='sys-upload-dir'>sys_upload_dir writability</dt>\n<dd>";
-    test_sys_upload_dir ();
-    print "</dd>\n";
-    print "<dt id='i18n'>i18n</dt>\n<dd>";
-    test_i18n ();
-    print "</dd>\n";
-    print "</dl>\n";
-    test_gpg ();
-  } # is_readable ($sys_conf_file)
+  print "Since $sys_conf_file does not exist or is not readable, "
+    . "this part cannot be checked.";
 
 print "\n<h2>Optional PHP configuration</h2>\n\n";
 
@@ -556,10 +605,9 @@ print "<p>The following is not required to run Savane, but could enhance\n"
   . "and report\npotentially harmful bugs.</p>\n";
 
 $phptags = [
-  'allow_url_fopen' => '0',
-  'disable_functions' => 'exec,passthru,popen,shell_exec,system',
-  'display_errors' => '1',
-  'error_reporting' => (string)(E_ALL | E_STRICT), 'log_errors' => '1',
+  'disable_functions' => 'passthru,popen,shell_exec,system',
+  'display_errors' => '1', 'error_reporting' => (string)(E_ALL),
+  'log_errors' => '1',
 ];
 
 print "\n<table border=\"1\">\n"
@@ -570,7 +618,7 @@ $cmp = function ($a, $b) { return $a === $b; };
 foreach ($phptags as $tag => $good)
   if (compare_ini_vals ($tag, $good, $cmp))
     $have_unset = true;
-print "</table>\n\n";
+print "$page</table>\n\n";
 if ($have_unset)
   print "<blockquote>* This tag was not found at all. It is probably irrelevant "
        . "to your PHP version so you may ignore this entry.</blockquote>\n\n";
