@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -51,26 +51,18 @@ require_once('include/utils.php');
 
 $timestamp = 1667230215;
 
-$test = [
-  'en_US' => 'Mon 31 Oct 2022 03:30:15 PM GMT',
-  'es_ES' =>  'lun 31 oct 2022 15:30:15 GMT',
-  'fr_FR' =>  'lun. 31 oct. 2022 15:30:15 GMT',
-  'he_IL' =>  "GMT 15:30:15 2022 אוק 31 ב'",
-  'pt_BR' =>  'seg 31 out 2022 15:30:15 GMT',
-  'ru_RU' =>  'Пн 31 окт 2022 15:30:15',
-];
+$test = ['en_US', 'es_ES', 'fr_FR', 'he_IL', 'pt_BR', 'ru_RU'];
 
 putenv ('TZ=GMT');
 $format = 'default';
-foreach ($test as $l => $v0)
-  {
-    setlocale (LC_ALL, "$l.UTF-8");
-    $v = utils_format_date ($timestamp, $format);
-    if ($v != $v0)
-      print "format: $format; locale: $l; expected: $v0; returned: $v\n";
-  }
+$l = 'en_US';
+$v0 = 'Mon 31 Oct 2022 03:30:15 PM GMT';
+setlocale (LC_ALL, "$l.UTF-8");
+$v = str_replace ('UTC', 'GMT', utils_format_date ($timestamp, $format));
+if ($v != $v0)
+  print "format: $format; locale: $l; expected: $v0; returned: $v\n";
 $format = 'minimal';
-foreach ($test as $l => $v0)
+foreach ($test as $l)
   {
     setlocale (LC_ALL, "$l.UTF-8");
     $v = utils_format_date ($timestamp, $format);
@@ -89,7 +81,7 @@ if ($tod <= $day / 2 && $tod >= $day / 2 - $delta)
 if (!$tod || $tod >= $day - $delta)
   $t0 -= 34 * 60;
 $tod = $t0 % $day;
-$m = $tod / 60;
+$m = intval($tod / 60);
 $hour = intval ($m / 60);
 $minute = $m % 60;
 foreach ($test as $l => $v0)
