@@ -5,7 +5,7 @@
 # Copyright (C) 2000-2006 Mathieu Roy
 # Copyright (C) 2014, 2016, 2017 Assaf Gordon
 # Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
-# Copyright (C) 2013, 2014, 2017-2023 Ineiev
+# Copyright (C) 2013, 2014, 2017-2024 Ineiev
 #
 # This file is part of Savane.
 #
@@ -165,21 +165,14 @@ $reference = 'account/login.php';
 $reference = 'account/lostlogin.php';
 {
   $names = [
-    'hash' => 'form_id',
     'true' => 'update',
     'pass' => ['form_pw', 'form_pw2']
   ];
-  $in = [
-    'form_id' => md5 (83521),
-    'form_pw' => '123;"45',
-    'form_pw2' => '123 45',
-  ];
+  $in = ['form_pw' => '123;"45', 'form_pw2' => '123 45'];
   $out = $in;
   $out['update'] = null;
   test_sane_import ($in, $names, $out);
 
-  $in['form_id'] = $in['form_id'] . 'A';
-  $out['form_id'] = null;
   $in['update'] = 'x';
   $out['update'] = true;
   test_sane_import ($in, $names, $out);
@@ -207,14 +200,12 @@ $reference = 'account/pending-resend.php';
 $reference = 'account/register.php';
 {
   $names = [
-    'hash' => 'form_id',
     'name' => 'form_loginname',
     'pass' => ['form_pw', 'form_pw2', 'form_realname', 'form_email'],
     'digits' => 'form_year',
     'true' => ['update', 'form_usepam']
   ];
   $in = [
-    'form_id' => md5 (289),
     'form_loginname' => 'agn',
     'update' => 'Update',
     'form_pw' => '%',
@@ -260,12 +251,11 @@ $reference = 'account/verify.php';
 {
   $names = [
     'true' => 'update',
-    'hash' => ['form_id', 'confirm_hash'],
+    'hash' => [ 'confirm_hash'],
     'name' => 'form_loginname',
     'pass' => 'form_pw'
   ];
   $in = [
-    'form_id' => md5 (4913),
     'confirm_hash' => md5 ('agn'),
     'form_loginname' => 'agn',
     'form_pw' => 0
@@ -303,6 +293,8 @@ $reference = 'css/graph-widths.php';
   $in['widths'] = '1,2,3,a';
   $out = ['widths' => null];
   test_sane_import ($in, $names, $out);
+  if (!isset ($out['widths']))
+    $out['widths'] = '';
   $w = explode (',', $out['widths']);
   $count = count ($w);
   if ($count > 1)
@@ -521,6 +513,13 @@ $reference = 'include/form.php';
   $in['group_id'] = '1234';
 
   test_sane_import ($in, $names, $out);
+  $names = ['hash' => 'form_id'];
+  $in = ['form_id' => md5 (83521)];
+  $out = $in;
+  test_sane_import ($in, $names, $out);
+  $in['form_id'] = $in['form_id'] . 'A';
+  $out['form_id'] = null;
+  test_sane_import ($in, $names, $out);
 }
 
 $reference = 'include/html.php';
@@ -816,11 +815,8 @@ $reference = 'include/trackers/general.php';
 
 $reference = 'include/trackers_run/add.php';
 {
-  $names = [
-    'hash' => 'form_id', 'array' => [['prefill', [null, 'specialchars']]]
-  ];
+  $names = ['array' => [['prefill', [null, 'specialchars']]]];
   $in = [
-    'form_id' => md5 ('a'),
     'prefill' => ['"prefill"', 'prefill', 'p<r>efill']
   ];
   $out = $in;
@@ -1040,10 +1036,10 @@ $reference = 'include/trackers_run/admin/field_values_reset.php';
   test_sane_import ($in, $names, $out);
 }
 
-$reference = 'include/trackers_run/admin/field_values_transition-ofields-update.php';
+$reference = 'include/bugs/admin/field_values_transition-ofields-update.php';
 {
   $names = ['digits' => 'transition_id'];
-  $in = ['form_id' => 'abcdef01', 'transition_id' => 'i'];
+  $in = ['form_di' => 'abcdef01', 'transition_id' => 'i'];
   $out = ['transition_id' => null];
   test_sane_import ($in, $names, $out);
   $all_fields = ['category_id', 'resolution_id', 'privacy', 'status_id'];
@@ -1238,24 +1234,22 @@ $reference = 'include/trackers_run/index.php';
   $out = $in;
   test_sane_import ($in, $names, $out);
   $names = [
-    'hash' => 'form_id',
     'pass' =>
       [
         'comment', 'additional_comment', 'depends_search',
-        'reassign_change_project_search'
+        'reassign_change_group_search'
       ],
     'digits' => ['comment_type_id', 'new_vote', 'quote_no'],
     'specialchars' => 'cc_comment',
     'preg' =>
       [
-        ['canned_response', '/^(\d+|!multiple!)$/'],
         [
           'originator_email',
           '/^[a-zA-Z0-9_.+-]+@(([a-zA-Z0-9-])+\.)+[a-zA-Z0-9]+$/'
         ],
         ['add_cc', '/^[-+_@.,;\s\da-zA-Z]*$/'],
         [
-          'reassign_change_project', '/^[-_[:alnum:]]*$/'
+          'reassign_change_group', '/^[-_[:alnum:]]*$/'
         ]
       ],
     'strings' =>
@@ -1266,7 +1260,7 @@ $reference = 'include/trackers_run/index.php';
           ['all', 'support', 'bugs', 'task', 'patch']
         ],
         [
-          'depends_search_only_project',
+          'depends_search_only_group',
           ['any', 'notany']
         ]
       ],
@@ -1285,22 +1279,20 @@ $reference = 'include/trackers_run/index.php';
       ]
   ];
   $in = [
-    'form_id' => md5 ('form_id'),
     'comment' => 'comment',
     'additional_comment' => 'a',
     'depends_search' => 'd',
-    'reassign_change_project_search' => 'r',
+    'reassign_change_group_search' => 'r',
     'comment_type_id' => 127,
     'new_vote' => 10,
     'quote_no' => 3,
     'cc_comment' => 'a',
-    'canned_response' => '!multiple!',
     'originator_email' => 'agn@test.mil',
     'add_cc' => 'agn,a@b.ca;d@e.fgh',
-    'reassign_change_project' => '0-grep_up',
+    'reassign_change_group' => '0-grep_up',
     'depends_search_only_artifact' => 'bugs',
     'reassign_change_artifact' => 'all',
-    'depends_search_only_project' => 'any',
+    'depends_search_only_group' => 'any',
     'submitreturn' => true,
     'preview' => true,
     'dependent_on_task' => [1, 2, 3],
@@ -1328,11 +1320,8 @@ $reference = 'include/trackers_run/index.php';
   $out = $in;
   $out['item_depends_on'] = null;
   test_sane_import ($in, $names, $out);
-  $names = [
-    'hash' => 'form_id', 'strings' => [['check', '1984']],
-    'pass' => 'details'
-  ];
-  $in = ['form_id' => md5(''), 'check' => '1984'];
+  $names = ['strings' => [['check', '1984']], 'pass' => 'details'];
+  $in = ['check' => '1984'];
   $out = $in;
   $out['details'] = null;
   test_sane_import ($in, $names, $out);
@@ -1341,7 +1330,7 @@ $reference = 'include/trackers_run/index.php';
   $in['check'] = 1984; $out['check'] = '1984';
   test_sane_import ($in, $names, $out);
   $names = [
-    'hash' => 'form_id', 'digits' => ['item_id'],
+    'digits' => ['item_id'],
     'strings' => [['check', '1984']], 'pass' => 'comment'
   ];
   $out['item_id'] = $in['item_id'] = 3;
@@ -1528,7 +1517,7 @@ $reference = 'my/admin/change.php';
         ['step', ['confirm', 'confirm2', 'discard']],
       ],
     'true' => ['update', 'test_gpg_key'],
-    'hash' => ['session_hash', 'confirm_hash', 'form_id'],
+    'hash' => ['session_hash', 'confirm_hash'],
   ];
   $in = $out = [
    'item' => 'realname',
@@ -1537,7 +1526,6 @@ $reference = 'my/admin/change.php';
    'test_gpg_key' => true,
    'session_hash' => md5 (5),
    'confirm_hash' => md5 (6),
-   'form_id' => md5 (7),
   ];
   test_sane_import ($in, $names, $out);
 }
@@ -1546,18 +1534,13 @@ $reference = 'my/admin/editsshkeys.php';
 {
   $names = [
     'true' => 'update',
-    'hash' => 'form_id',
-    'array' =>
-      [
-        ['form_authorized_keys', ['digits', 'no_quotes']]
-      ]
+    'array' => [['form_keys', ['digits', 'no_quotes']]]
   ];
   $in = $out = [
-    'form_id' => md5 (8),
-    'form_authorized_keys' => ['a', 'b', 'c', 3 => '"']
+    'form_keys' => ['a', 'b', 'c', 3 => '"']
   ];
   $out['update'] = null;
-  unset ($out['form_authorized_keys'][3]);
+  unset ($out['form_keys'][3]);
   test_sane_import ($in, $names, $out);
 }
 
@@ -1623,7 +1606,7 @@ $reference = 'my/admin/sessions.php';
     'digits' => 'dtime',
     'preg' =>
       [
-        ['dip_addr', ',^[\d./:]+$,'],
+        ['dip_addr', ',^[[:xdigit:]./:]+$,'],
         ['dsession_hash', '/^[a-f\d]+[.]{3}$/']
       ],
   ];
@@ -1635,6 +1618,8 @@ $reference = 'my/admin/sessions.php';
     'dsession_hash' => substr (md5 (0), 0, 6) . "..."
   ];
   test_sane_import ($in, $names, $out);
+  $in['dip_addr'] = $out['dip_addr'] = '2023:01:da8b:6fa1:b93c:f5b4:3593:26a2';
+  test_sane_import ($in, $names, $out);
   $in['func'] = 'add'; $out['func'] = null;
   test_sane_import ($in, $names, $out);
 }
@@ -1643,17 +1628,14 @@ $reference = 'my/groups.php';
 {
   $names = [
     'true' => 'update',
-    'hash' => 'form_id',
     'pass' => 'form_message',
     'array' => [['form_groups', ['digits', 'true']]],
   ];
   $in = $out = [
     'update' => true,
-    'form_id' => 'x',
     'form_message' => '<b id=\'',
     'form_groups' => ['on', 'on', 'on', 'on'],
   ];
-  $out['form_id'] = null;
   foreach ($out['form_groups'] as $k => $v)
     $out['form_groups'][$k] = true;
   test_sane_import ($in, $names, $out);
@@ -1782,12 +1764,10 @@ $reference = 'news/index.php';
 $reference = 'news/submit.php';
 {
   $names = [
-    'hash' => 'form_id',
     'true' => 'update',
     'specialchars' => ['summary', 'details'],
   ];
   $in = $out = [
-    'form_id' => md5 ('form_id'),
     'update' => true,
     'summary' => 'symmary',
     'details' => 'details',
@@ -1800,14 +1780,12 @@ $reference = 'news/approve.php';
   $names = [
     'digits' => ['id', 'status'],
     'strings' => [['status', ['0', '4', '5']]],
-    'hash' => 'form_id',
     'true' => ['update', 'post_changes', 'approve'],
     'specialchars' => ['summary', 'details'],
   ];
   $in = $out = [
     'id' => 1,
     'status' => 4,
-    'form_id' => md5 ('md5'),
     'update' => true,
     'summary' => 'sum',
     'details' => 'det'
@@ -1988,7 +1966,6 @@ $reference = 'project/admin/squadadmin.php';
         'update_delete_step2', 'deletionconfirmed', 'add_to_squad',
         'remove_from_squad',
       ],
-    'hash' => 'form_id',
     'array' => [['user_ids', ['digits', 'digits']]],
     'digits' => ['squad_id_to_delete'],
      # form_realname is sanitized further.
@@ -1997,7 +1974,7 @@ $reference = 'project/admin/squadadmin.php';
   ];
   $in = $out = [
     'update' => true, 'update_general' => true, 'add_to_squad' => true,
-    'form_id' => md5 ('update'), 'squad_id_to_delete' => 289,
+    'squad_id_to_delete' => 289,
     'user_ids' => [1, 2], 'form_realname' => 'agn', 'form_loginname' => 'agn',
   ];
   $out['update_delete_step1'] = $out['update_delete_step2']
@@ -2069,17 +2046,13 @@ $reference = 'register/upload.php';
 
 $reference = 'search/index.php';
 {
+  $tos_values = array_merge (['soft', 'people'], utils_get_tracker_list ());
   $names = [
     'digits' =>
       [ 'type', 'only_group_id', ['offset', [0, 410338673]],
         ['max_rows', [1, 4913]], ['exact', [0, 1]]
       ],
-    'strings' => [
-      [
-        'type_of_search',
-        ['soft', 'people', 'bugs', 'support', 'patch', 'cookbook', 'task'],
-      ],
-    ],
+    'strings' => [['type_of_search', $tos_values]],
     'pass' => 'words',
   ];
   $in = $out = [
@@ -2122,25 +2095,24 @@ $reference = 'sendmessage.php';
 
 $reference = 'siteadmin/groupedit.php';
 {
-  $names = ['true' => 'updatefast', 'preg' => [['status', '/^[A-Z]$/']]];
-  $in = $out = ['updatefast' => 'true', 'status' => 'P'];
-  test_sane_import ($in, $names, $out);
   $names = [
-    'true' => 'update',
+    'true' => ['update', 'fastok', 'fastdel'],
     'name' => 'form_name',
     'digits' => ['group_type', 'form_public'],
     'specialchars' => ['form_license', 'form_license_other'],
-    'preg' => [['form_status', '/^[A-Z]$/']]
+    'strings' => [['form_status', ['A', 'D']]]
   ];
   $dirs = ['cvs', 'arch', 'svn', 'git', 'hg', 'bzr', 'homepage', 'download'];
   foreach ($dirs as $d)
     $names['specialchars'][] = "form_dir_$d";
   $in = $out = [
-    'update' => true, 'form_public' => 0, 'form_status' => 'A',
+    'update' => true, 'fastok' => true,
+    'form_public' => 0, 'form_status' => 'A',
     'form_name' => 'grep', 'group_type' => 1,
   ];
+  $out['fastdel'] = false;
   foreach ($names['specialchars'] as $n)
-    $in[$n] = $out[$n] = $n;  
+    $in[$n] = $out[$n] = $n;
   test_sane_import ($in, $names, $out);
 }
 
